/* Driver template for the LEMON parser generator.
** The author disclaims copyright to this source code.
**
** This version of "lempar.c" is modified, slightly, for use by SQLite.
** The only modifications are the addition of a couple of NEVER()
** macros to disable tests that are needed in the case of a general
** LALR(1) grammar but which are always false in the
** specific grammar used by SQLite.
*/
/* First off, code is included that follows the "include" declaration
** in the input grammar file. */
#include <stdio.h>

#include "token.h"
#include "parsercontext.h"
#include "parser_helper_stubs.h"
#include "common/utils_sql.h"
#include "parser/ast/sqlitealtertable.h"
#include "parser/ast/sqliteanalyze.h"
#include "parser/ast/sqliteattach.h"
#include "parser/ast/sqlitebegintrans.h"
#include "parser/ast/sqlitecommittrans.h"
#include "parser/ast/sqlitecopy.h"
#include "parser/ast/sqlitecreateindex.h"
#include "parser/ast/sqlitecreatetable.h"
#include "parser/ast/sqlitecreatetrigger.h"
#include "parser/ast/sqlitecreateview.h"
#include "parser/ast/sqlitecreatevirtualtable.h"
#include "parser/ast/sqlitedelete.h"
#include "parser/ast/sqlitedetach.h"
#include "parser/ast/sqlitedropindex.h"
#include "parser/ast/sqlitedroptable.h"
#include "parser/ast/sqlitedroptrigger.h"
#include "parser/ast/sqlitedropview.h"
#include "parser/ast/sqliteemptyquery.h"
#include "parser/ast/sqliteinsert.h"
#include "parser/ast/sqlitepragma.h"
#include "parser/ast/sqlitereindex.h"
#include "parser/ast/sqliterelease.h"
#include "parser/ast/sqliterollback.h"
#include "parser/ast/sqlitesavepoint.h"
#include "parser/ast/sqliteselect.h"
#include "parser/ast/sqliteupdate.h"
#include "parser/ast/sqlitevacuum.h"
#include "parser/ast/sqliteexpr.h"
#include "parser/ast/sqlitecolumntype.h"
#include "parser/ast/sqliteconflictalgo.h"
#include "parser/ast/sqlitesortorder.h"
#include "parser/ast/sqliteindexedcolumn.h"
#include "parser/ast/sqliteforeignkey.h"
#include "parser/ast/sqlitewith.h"
#include <QObject>
#include <QDebug>
#include <limits.h>

#define assert(X) Q_ASSERT(X)
#define UNUSED_PARAMETER(X) (void)(X)
#define DONT_INHERIT_TOKENS(X) noTokenInheritanceFields << X
/* Next is all token values, in a form suitable for use by makeheaders.
** This section will be null unless lemon is run with the -m switch.
*/
/*
** These constants (all generated automatically by the parser generator)
** specify the various kinds of tokens (terminals) that the parser
** understands.
**
** Each symbol here is a terminal symbol in the grammar.
*/
/* Make sure the INTERFACE macro is defined.
*/
#ifndef INTERFACE
# define INTERFACE 1
#endif
/* The next thing included is series of defines which control
** various aspects of the generated parser.
**    YYCODETYPE         is the data type used for storing terminal
**                       and nonterminal numbers.  "unsigned char" is
**                       used if there are fewer than 250 terminals
**                       and nonterminals.  "int" is used otherwise.
**    YYNOCODE           is a number of type YYCODETYPE which corresponds
**                       to no legal terminal or nonterminal number.  This
**                       number is used to fill in empty slots of the hash
**                       table.
**    YYFALLBACK         If defined, this indicates that one or more tokens
**                       have fall-back values which should be used if the
**                       original value of the token will not parse.
**    YYACTIONTYPE       is the data type used for storing terminal
**                       and nonterminal numbers.  "unsigned char" is
**                       used if there are fewer than 250 rules and
**                       states combined.  "int" is used otherwise.
**    sqlite3_parseTOKENTYPE     is the data type used for minor tokens given
**                       directly to the parser from the tokenizer.
**    YYMINORTYPE        is the data type used for all minor tokens.
**                       This is typically a union of many types, one of
**                       which is sqlite3_parseTOKENTYPE.  The entry in the union
**                       for base tokens is called "yy0".
**    YYSTACKDEPTH       is the maximum depth of the parser's stack.  If
**                       zero the stack is dynamically sized using realloc()
**    sqlite3_parseARG_SDECL     A static variable declaration for the %extra_argument
**    sqlite3_parseARG_PDECL     A parameter declaration for the %extra_argument
**    sqlite3_parseARG_STORE     Code to store %extra_argument into yypParser
**    sqlite3_parseARG_FETCH     Code to extract %extra_argument from yypParser
**    YYNSTATE           the combined number of states.
**    YYNRULE            the number of rules in the grammar
**    YYERRORSYMBOL      is the code number of the error symbol.  If not
**                       defined, then do no error processing.
*/
#define YYCODETYPE unsigned short int
#define YYNOCODE 278
#define YYACTIONTYPE unsigned short int
#define YYWILDCARD 61
#define sqlite3_parseTOKENTYPE Token*
typedef union {
  int yyinit;
  sqlite3_parseTOKENTYPE yy0;
  SqliteCreateTable::Column::Constraint* yy4;
  SqliteCreateTable::Constraint* yy8;
  ParserExprList* yy13;
  QVariant* yy21;
  ParserStubAlias* yy28;
  SqliteConflictAlgo* yy30;
  ParserFullName* yy66;
  ParserCreateTableConstraintList* yy87;
  SqliteIndexedColumn* yy90;
  ParserFkConditionList* yy108;
  SqliteSelect::Core::JoinConstraint* yy117;
  ParserCreateTableColumnList* yy118;
  SqliteSelect* yy123;
  SqliteLimit* yy128;
  ParserDeferSubClause* yy131;
  ParserIndexedColumnList* yy139;
  SqliteCreateTrigger::Time* yy152;
  SqliteSelect::CompoundOperator* yy168;
  SqliteSelect::Core::SingleSource* yy173;
  QString* yy211;
  ParserQueryList* yy214;
  ParserStubExplain* yy225;
  SqliteSortOrder* yy226;
  bool* yy237;
  ParserStubInsertOrReplace* yy250;
  ParserResultColumnList* yy263;
  SqliteForeignKey::Condition* yy271;
  SqliteColumnType* yy299;
  ParserStubTransDetails* yy300;
  SqliteCreateTrigger::Event* yy309;
  SqliteForeignKey::Condition::Reaction* yy312;
  ParserOtherSourceList* yy359;
  SqliteWith* yy367;
  SqliteSelect::Core::JoinSource* yy373;
  SqliteExpr::LikeOp* yy374;
  int* yy376;
  ParserSetValueList* yy381;
  SqliteQuery* yy399;
  SqliteCreateTrigger::Scope* yy409;
  ParserExprNestedList* yy416;
  SqliteCreateTable::Column* yy425;
  ParserStringList* yy445;
  ParserCreateTableColumnConstraintList* yy449;
  SqliteSelect::Core* yy468;
  ParserIndexedBy* yy472;
  SqliteSelect::Core::JoinOp* yy473;
  SqliteExpr* yy490;
  ParserOrderByList* yy495;
  SqliteInitially* yy498;
} YYMINORTYPE;
#ifndef YYSTACKDEPTH
#define YYSTACKDEPTH 100
#endif
#define sqlite3_parseARG_SDECL ParserContext* parserContext;
#define sqlite3_parseARG_PDECL ,ParserContext* parserContext
#define sqlite3_parseARG_FETCH ParserContext* parserContext = yypParser->parserContext
#define sqlite3_parseARG_STORE yypParser->parserContext = parserContext
#define YYNSTATE 725
#define YYNRULE 424
#define YYFALLBACK 1
#define YY_NO_ACTION      (YYNSTATE+YYNRULE+2)
#define YY_ACCEPT_ACTION  (YYNSTATE+YYNRULE+1)
#define YY_ERROR_ACTION   (YYNSTATE+YYNRULE)

#define GET_CONTEXT yyParser* yypParser = pParser; sqlite3_parseARG_FETCH

/* The yyzerominor constant is used to initialize instances of
** YYMINORTYPE objects to zero. */
static const YYMINORTYPE yyzerominor = { 0 };

/* Define the yytestcase() macro to be a no-op if is not already defined
** otherwise.
**
** Applications can choose to define yytestcase() in the %include section
** to a macro that can assist in verifying code coverage.  For production
** code the yytestcase() macro should be turned off.  But it is useful
** for testing.
*/
#ifndef yytestcase
# define yytestcase(X)
#endif


/* Next are the tables used to determine what action to take based on the
** current state and lookahead token.  These tables are used to implement
** functions that take a state number and lookahead value and return an
** action integer.
**
** Suppose the action integer is N.  Then the action is determined as
** follows
**
**   0 <= N < YYNSTATE                  Shift N.  That is, push the lookahead
**                                      token onto the stack and goto state N.
**
**   YYNSTATE <= N < YYNSTATE+YYNRULE   Reduce by rule N-YYNSTATE.
**
**   N == YYNSTATE+YYNRULE              A syntax error has occurred.
**
**   N == YYNSTATE+YYNRULE+1            The parser accepts its input.
**
**   N == YYNSTATE+YYNRULE+2            No such action.  Denotes unused
**                                      slots in the yy_action[] table.
**
** The action table is constructed as a single large table named yy_action[].
** Given state S and lookahead X, the action is computed as
**
**      yy_action[ yy_shift_ofst[S] + X ]
**
** If the index value yy_shift_ofst[S]+X is out of range or if the value
** yy_lookahead[yy_shift_ofst[S]+X] is not equal to X or if yy_shift_ofst[S]
** is equal to YY_SHIFT_USE_DFLT, it means that the action is not in the table
** and that yy_default[S] should be used instead.
**
** The formula above is for computing the action when the lookahead is
** a terminal symbol.  If the lookahead is a non-terminal (as occurs after
** a reduce action) then the yy_reduce_ofst[] array is used in place of
** the yy_shift_ofst[] array and YY_REDUCE_USE_DFLT is used in place of
** YY_SHIFT_USE_DFLT.
**
** The following are the tables generated in this section:
**
**  yy_action[]        A single table containing all actions.
**  yy_lookahead[]     A table containing the lookahead for each entry in
**                     yy_action.  Used to detect hash collisions.
**  yy_shift_ofst[]    For each state, the offset into yy_action for
**                     shifting terminals.
**  yy_reduce_ofst[]   For each state, the offset into yy_action for
**                     shifting non-terminals after a reduce.
**  yy_default[]       Default action for each state.
*/
#define YY_ACTTAB_COUNT (2271)
static const YYACTIONTYPE yy_action[] = {
 /*     0 */   432,  565,  566,  717,   50,   50,   49,   49,   49,   48,
 /*    10 */   215,  420,   53,   53,   53,   53,   28,   51,   51,   51,
 /*    20 */    51,   50,   50,   49,   49,   49,   48,  215,  717, 1026,
 /*    30 */  1026,  336,  666,  665,   53,   53,   53,   53,  425,   51,
 /*    40 */    51,   51,   51,   50,   50,   49,   49,   49,   48,  215,
 /*    50 */   722,   81,  205,  204,  203,  672,  592,  592, 1026, 1026,
 /*    60 */    41, 1026, 1026, 1026, 1026, 1026, 1026, 1026, 1026, 1026,
 /*    70 */  1026, 1026,  639, 1026, 1026, 1026, 1026,   38,   39, 1026,
 /*    80 */  1026, 1026, 1026, 1026,   40,  432,  529,  285,  717,   56,
 /*    90 */   108,  684,    3,  717,  668,  301,  420,  678,  661,  417,
 /*   100 */   716,   67,  688,  430,  552,  715,  714,  691,  130,  331,
 /*   110 */    60,  377,  374,  373,  678,  690,  689,  688,  674,  507,
 /*   120 */    61,  216,  717,  425,   49,   49,   49,   48,  215,  372,
 /*   130 */   715,  714,  212,  131, 1143, 1143,  242,  629,  246,  674,
 /*   140 */   672,  421,  685,   48,  215,   41,  508,  510,  678,  509,
 /*   150 */     9,  678,   33,  669,  144,   95,  281,  380,  276,  379,
 /*   160 */   132,  674,   38,   39,  609,  229,  228,    7,  356,   40,
 /*   170 */   885,  717,  403,  717,  274,  484,  685,    3,  885,  529,
 /*   180 */   248,  610,  678,   68,  417,  885,  411,  688,  430,  209,
 /*   190 */   715,  714,  691,  684,  457,  715,  714,  717,  209,  678,
 /*   200 */   690,  689,  688,  663,  662,  432,  453,  459,  460,  458,
 /*   210 */   306,  486,  507,   61,  717,  885,  420,  885,  885,  492,
 /*   220 */   725,  716,  320,  885,  715,  714,  461,  462,  885,  885,
 /*   230 */   885,  885,  885,  678,  297,    9,  678,  772,  669,  508,
 /*   240 */   510,  687,  509,  425,  717,  339,  244,   51,   51,   51,
 /*   250 */    51,   50,   50,   49,   49,   49,   48,  215,  543,  570,
 /*   260 */   672,  357,  713,  283,  688,   41,  544,  711,  448,  691,
 /*   270 */   445,  577,  712,  715,  714,  715,  714,  690,  689,  688,
 /*   280 */   492,  576,   38,   39,  449,  448,  512,  445,  487,   40,
 /*   290 */   947,  463,  661,  389,  497,  603,  602,    3,  947,  715,
 /*   300 */   714,  230,  678,  684,  417,  947,   13,  688,  430,  723,
 /*   310 */    17,  617,  691,  448,  513,  445,  715,  714,   81,  678,
 /*   320 */   690,  689,  688,  307, 1135,  679,  460,  654,  618,  360,
 /*   330 */   774, 1135, 1028, 1028,   89,  947,    1,  947,  947,  716,
 /*   340 */   110,  595,  716,  617,  461,  342,  715,  714,  947,  947,
 /*   350 */   947,  947, 1080,  678,  692,    9,  678,  497,  669,  693,
 /*   360 */   717,   54,   55,  427,  295, 1028, 1028,  681,  681,   52,
 /*   370 */    52,   53,   53,   53,   53,  717,   51,   51,   51,   51,
 /*   380 */    50,   50,   49,   49,   49,   48,  215,  432,  496,  382,
 /*   390 */   717,  553,  347,  254,  363,  258,  298,  139,  420,  218,
 /*   400 */   539,   69,  286,  287,  716,  684,  143,  231,  390,  343,
 /*   410 */   661,   54,   55,  427,  295,  716,  716,  681,  681,   52,
 /*   420 */    52,   53,   53,   53,   53,  425,   51,   51,   51,   51,
 /*   430 */    50,   50,   49,   49,   49,   48,  215,  684,  954,  608,
 /*   440 */   628,  692,  672,  663,  662,  585,  693,   41,  429,  207,
 /*   450 */   601,  491,  388,  954,  130,  652,  499,  377,  374,  373,
 /*   460 */   500,  431,  715,  714,   38,   39,  651,  199,  198,  673,
 /*   470 */   186,   40,  932,  699,  685,  372,  717,  715,  714,    3,
 /*   480 */   932,  351,   57,  653,  678,  616,  417,  932,  135,  688,
 /*   490 */   430,   59,  688,  157,  691,  717,  680,  691,  340, 1046,
 /*   500 */   954,  678,  690,  689,  688,  690,  689,  688,  685,  419,
 /*   510 */   666,  665,  724,    2, 1028, 1028,  636,  932,  208,  932,
 /*   520 */   932,   43,  386,  141,  294,  615,  611,  264,  284,  267,
 /*   530 */   932,  139,  932,  932,  122,  678,  400,    9,  678,  684,
 /*   540 */   669,  716,  142,   54,   55,  427,  295, 1028, 1028,  681,
 /*   550 */   681,   52,   52,   53,   53,   53,   53,  339,   51,   51,
 /*   560 */    51,   51,   50,   50,   49,   49,   49,   48,  215,  652,
 /*   570 */    91,  299,  483,  483,  628,  717,  661,  717,  715,  714,
 /*   580 */   651,   18,  717,  605,  717,   37,  677,  399,  311,  717,
 /*   590 */    34,  535,  535, 1028, 1028,  427,  295,  715,  714,  681,
 /*   600 */   681,   52,   52,   53,   53,   53,   53,  234,   51,   51,
 /*   610 */    51,   51,   50,   50,   49,   49,   49,   48,  215, 1027,
 /*   620 */  1027,  723,   54,   55,  427,  295, 1028, 1028,  681,  681,
 /*   630 */    52,   52,   53,   53,   53,   53,   42,   51,   51,   51,
 /*   640 */    51,   50,   50,   49,   49,   49,   48,  215, 1027, 1027,
 /*   650 */  1027, 1027, 1027, 1027, 1027, 1027, 1027, 1027, 1027, 1027,
 /*   660 */  1027, 1027,  717, 1027, 1027, 1027, 1027, 1027, 1027, 1027,
 /*   670 */  1027, 1027, 1027, 1027, 1028, 1028,  718,  715,  714,  715,
 /*   680 */   714,  454,  324,  201,  715,  714,  715,  714,  321,  695,
 /*   690 */   315,  715,  714,  658,  554,  214,  676,   46,  568,   32,
 /*   700 */    81,   88,  675,   54,   55,  427,  295, 1028, 1028,  681,
 /*   710 */   681,   52,   52,   53,   53,   53,   53, 1095,   51,   51,
 /*   720 */    51,   51,   50,   50,   49,   49,   49,   48,  215,   54,
 /*   730 */    55,  427,  295,  667,  423,  681,  681,   52,   52,   53,
 /*   740 */    53,   53,   53,  454,   51,   51,   51,   51,   50,   50,
 /*   750 */    49,   49,   49,   48,  215,  358,  955,  656,  643, 1150,
 /*   760 */   154,  436,    2,  487,  715,  714,  350,   54,   55,  427,
 /*   770 */   295,  955,  484,  681,  681,   52,   52,   53,   53,   53,
 /*   780 */    53,  160,   51,   51,   51,   51,   50,   50,   49,   49,
 /*   790 */    49,   48,  215,  600, 1095,   22,  717,  280,  307, 1134,
 /*   800 */    34,  717,  501,  502,  353,  629, 1134,  306,  485,  697,
 /*   810 */   268,  717,  229,  228,  337,  279,  717,  558,  955,   54,
 /*   820 */    55,  427,  295,  716,  717,  681,  681,   52,   52,   53,
 /*   830 */    53,   53,   53,  655,   51,   51,   51,   51,   50,   50,
 /*   840 */    49,   49,   49,   48,  215,  432, 1109,   81,  717,  225,
 /*   850 */   663,  662,   54,   55,  427,  295,  420,  153,  681,  681,
 /*   860 */    52,   52,   53,   53,   53,   53,  641,   51,   51,   51,
 /*   870 */    51,   50,   50,   49,   49,   49,   48,  215,  586,   89,
 /*   880 */   717,  231,  390,  425,   15,  717,  694,  413,   13,  895,
 /*   890 */   721,  207,  601,  617,  388,  435,   81,  574,  715,  714,
 /*   900 */   672,  272,  553,  715,  714,   41,  529,  537,   89,   14,
 /*   910 */   618,  698,   69,  715,  714,  716,   13,  209,  715,  714,
 /*   920 */   359,  617,   38,   39,  159,  617,  715,  714,  645,   40,
 /*   930 */  1143, 1143,  717,  345,  222,  674,  540,    3,  618,  469,
 /*   940 */    61,  285,  678,  625,  417,  473,  716,  688,  430,   45,
 /*   950 */   715,  714,  691,  617,  716,  416,  674,  402,  581,  678,
 /*   960 */   690,  689,  688,  429,  901,  901,  468,  467,  284,  466,
 /*   970 */   629,   81,  706,  633,  495,  580,  431,  526,  674, 1143,
 /*   980 */  1143,  716,  715,  714,  673,   92,  716,  715,  714,   91,
 /*   990 */   473,  401,  438,  678,  526,    9,  678,  370,  669,  409,
 /*  1000 */    54,   55,  427,  295,   89,  505,  681,  681,   52,   52,
 /*  1010 */    53,   53,   53,   53,  620,   51,   51,   51,   51,   50,
 /*  1020 */    50,   49,   49,   49,   48,  215,  717,  638,  311,  717,
 /*  1030 */   406,  658,  418,  214,  715,  714,   90,  642,  131,  334,
 /*  1040 */   415,  644,   54,   55,  427,  295,  451,  640,  681,  681,
 /*  1050 */    52,   52,   53,   53,   53,   53,  158,   51,   51,   51,
 /*  1060 */    51,   50,   50,   49,   49,   49,   48,  215,  369,   54,
 /*  1070 */    55,  427,  295,   12,  451,  681,  681,   52,   52,   53,
 /*  1080 */    53,   53,   53,  633,   51,   51,   51,   51,   50,   50,
 /*  1090 */    49,   49,   49,   48,  215,   36,  716,    8,  209,   54,
 /*  1100 */    55,  427,  295,   34,  589,  681,  681,   52,   52,   53,
 /*  1110 */    53,   53,   53,  704,   51,   51,   51,   51,   50,   50,
 /*  1120 */    49,   49,   49,   48,  215,   87,  138,  320,  715,  714,
 /*  1130 */   412,  715,  714,  274,  572,   54,   55,  427,  295,   30,
 /*  1140 */   624,  681,  681,   52,   52,   53,   53,   53,   53,  326,
 /*  1150 */    51,   51,   51,   51,   50,   50,   49,   49,   49,   48,
 /*  1160 */   215,  408,  717,  137,   91,   54,   55,  427,  295,  614,
 /*  1170 */   271,  681,  681,   52,   52,   53,   53,   53,   53,  465,
 /*  1180 */    51,   51,   51,   51,   50,   50,   49,   49,   49,   48,
 /*  1190 */   215,  136,  716,  538,  612,   91,   99,   54,   55,  427,
 /*  1200 */   295,   23,  607,  681,  681,   52,   52,   53,   53,   53,
 /*  1210 */    53,  395,   51,   51,   51,   51,   50,   50,   49,   49,
 /*  1220 */    49,   48,  215,  533, 1110,  516,  717,   91,   54,   55,
 /*  1230 */   427,  295,  141,  393,  681,  681,   52,   52,   53,   53,
 /*  1240 */    53,   53,    5,   51,   51,   51,   51,   50,   50,   49,
 /*  1250 */    49,   49,   48,  215,  717, 1108,  606,   91,  717,  476,
 /*  1260 */    54,   55,  427,  295,  715,  714,  681,  681,   52,   52,
 /*  1270 */    53,   53,   53,   53,  684,   51,   51,   51,   51,   50,
 /*  1280 */    50,   49,   49,   49,   48,  215,  684,   54,   58,  427,
 /*  1290 */   295,  476,  717,  681,  681,   52,   52,   53,   53,   53,
 /*  1300 */    53,  633,   51,   51,   51,   51,   50,   50,   49,   49,
 /*  1310 */    49,   48,  215,  432,  716,  251,  518,  604, 1035,   11,
 /*  1320 */   107,  629,   36,  531,  420,   55,  427,  295,  715,  714,
 /*  1330 */   681,  681,   52,   52,   53,   53,   53,   53,  224,   51,
 /*  1340 */    51,   51,   51,   50,   50,   49,   49,   49,   48,  215,
 /*  1350 */    91,  425,  717,  583,  531,  582,  715,  714,  429,   20,
 /*  1360 */   715,  714,  429,  684,  429,  619,  384,  352,  672,  562,
 /*  1370 */   387,  431,  623,   41,  489,  431,  684,  431,  657,  673,
 /*  1380 */   186,  308,  717,  673,  186,  673,  186,  622,  684,  470,
 /*  1390 */    38,   39,  599,  597,  715,  714,  432,   40,  719,  683,
 /*  1400 */    91,  830,  634,  596,   91,    3,  571,  420,  541,  591,
 /*  1410 */   678,  716,  417,  391,  385,  688,  430,  332,  707,  333,
 /*  1420 */   691,  525,  429,  582,  717,   65,  429,  678,  690,  689,
 /*  1430 */   688,  716,  316,  717,  425,  431,  316,  564,  316,  431,
 /*  1440 */   717,  590,  376,  673,  186,   64,  429,  673,  186,  429,
 /*  1450 */   273,  672,   19,  470,  715,  714,   41,  371,  378,  431,
 /*  1460 */   684,  678,  431,    9,  678,  684,  669,  673,  186,  563,
 /*  1470 */   673,   92,  717,   38,   39,   63,  648,  391,  383,  432,
 /*  1480 */    40,  391,  392,  129,  715,  714,  717,  279,    3,  270,
 /*  1490 */   420,  367,  613,  678,  705,  417,  316,  534,  688,  430,
 /*  1500 */   316,  404,    4,  691,  717,  553,  717,  716,  156,  284,
 /*  1510 */   678,  690,  689,  688,  441,   69,  325,  425,  716,  630,
 /*  1520 */   316,  717,  716,  642,  125,   79,  715,  714,  703,   27,
 /*  1530 */    26,   85,  517,   77,  672,  715,  714,  520,  447,   41,
 /*  1540 */   717,  716,  715,  714,  678,  549,    9,  678,  717,  669,
 /*  1550 */   511,  329,  700,  506,  520,  354,   38,   39,  504,  702,
 /*  1560 */    83,  432,  684,   40,  265,  716,  447,  286,  266,  226,
 /*  1570 */   141,    3,  420,  556,  715,  714,  678,  716,  417,  696,
 /*  1580 */   716,  688,  430,  515,  686,  422,  691,  717,  715,  714,
 /*  1590 */   498,  429,  716,  678,  690,  689,  688,  716,  716,  425,
 /*  1600 */   515,  480,  335,  439,  431,  253,  715,  714,  715,  714,
 /*  1610 */   119,  479,  673,  194,  250,  260,  672,  717,  480,  220,
 /*  1620 */   439,   41,  717,  715,  714,   10,  152,  678,  716,    9,
 /*  1630 */   678,  161,  669, 1036,  286,  594,  456,  455,   38,   39,
 /*  1640 */    72,  111,  715,  714,  432,   40,  635,  716,  646,  429,
 /*  1650 */   715,  714,  338,    3, 1038,  420,  437,  209,  678,  716,
 /*  1660 */   417,  202,  431,  688,  430,  642,  429,   96,  691,  221,
 /*  1670 */   673,  181,  631,  717,  223,  678,  690,  689,  688,  431,
 /*  1680 */   717,  429,  425,  206,   86,  716,  717,  673,  185,  715,
 /*  1690 */   714,  319,  626,  257,  431,  429,  522,  219,  720,  672,
 /*  1700 */   530,  559,  673,  189,   41,  716,  716,  318,  431,  678,
 /*  1710 */   710,    9,  678,  717,  669,  646,  673,  187,  490,  715,
 /*  1720 */   714,   38,   39,  642,  715,  714,  432,  150,   40,  134,
 /*  1730 */   709,  542,  429,  717,  149,  429,    3,  420,  708,  286,
 /*  1740 */   642,  678,  716,  417,  434,  431,  688,  430,  431,  286,
 /*  1750 */   429,  691,  716,  673,  195,  642,  673,  193,  678,  690,
 /*  1760 */   689,  688,  716,  431,  425,  398,  256,  621,  368,  642,
 /*  1770 */   255,  673,  196,  147,  328,  715,  714,  429,  716,  716,
 /*  1780 */   716,  672,  715,  714,  327,   82,   41,  433,  715,  714,
 /*  1790 */   431,   16,  678,  701,    9,  678,  598,  669,  673,  200,
 /*  1800 */   503,  532,  145,   38,   39,  215,  642,  232,  432,  642,
 /*  1810 */    40,   47,  671,  247,   31,  715,  714,  482,    3,  420,
 /*  1820 */   646,  275,  475,  678,  642,  417,  716,  528,  715,  430,
 /*  1830 */   646,  569,  429,  691,  716,  715,  714,  550,  231,  291,
 /*  1840 */   678,  690,  689,  688,  716,  431,  425,  524,  245,   18,
 /*  1850 */   716,  642,  478,  673,  233,   98,  290,  239,  243,  217,
 /*  1860 */   429,  716,  474,  672,  717,  241,   35,  405,  238,  471,
 /*  1870 */   303,  716,  289,  431,  678,  288,    9,  678,  716,  669,
 /*  1880 */   235,  673,  296,  670,  322,   38,   39,  414,  102,   44,
 /*  1890 */   717,  300,   40,  716,  407,  302,  148,   66,  227,  151,
 /*  1900 */     3,  213,   81,  269,   97,  678,  642,  417,  410,  140,
 /*  1910 */   688,  430,  717,  262,  429,  691,  716,  361,  109,  348,
 /*  1920 */   394,  390,  678,  690,  689,  688,  716,  431,  584,  429,
 /*  1930 */   716,  429,  716,  429,  642,  673,  192,  593,  133,  304,
 /*  1940 */   717,  146,  431,  381,  431,  579,  431,  429,  277,  429,
 /*  1950 */   673,  184,  673,  172,  673,  163,  678,  578,    9,  678,
 /*  1960 */   431,  669,  431,  330,  429,  575,  715,  714,  673,  171,
 /*  1970 */   673,  183,  717,  574,  717,  573,  429,  431,  317,  310,
 /*  1980 */   548,  555,  443,  547,  546,  673,  188,  429,  642,  431,
 /*  1990 */   545,  309,  715,  714,  536,  716,  128,  673,  314,  428,
 /*  2000 */   431,   80,  127,  642,  519,  642,  429,  642,  673,  313,
 /*  2010 */   366,  429,  716,  341,  715,  714,  717,  106,  429,  431,
 /*  2020 */   211,  642,  261,  642,  431,  472,  493,  673,  312,  126,
 /*  2030 */   717,  431,  673,  170,  355,  429,  282,   25,  642,  673,
 /*  2040 */    93,  429,  715,  714,  124,  527,  429,  263,  431,  716,
 /*  2050 */   642,  429,  252,   78,  431,  105,  673,  169,  249,  431,
 /*  2060 */   716,  642,  673,  168,  431,  716,  429,  673,  166,  429,
 /*  2070 */    84,  716,  673,  165,  715,  714,  715,  714,  717,  431,
 /*  2080 */   642,  717,  431,  429,  123,  642,  444,  673,  182,  429,
 /*  2090 */   673,  164,  642,  240,  236,  364,  431,  717,  121,  464,
 /*  2100 */   429,  717,  431,  477,  673,  190,  716,  716,  717,  642,
 /*  2110 */   673,  191,  442,  431,  429,  642,  155,  429,  715,  714,
 /*  2120 */   642,  673,  174,  717,  429,  642,  514,  431,  429,  237,
 /*  2130 */   431,  429,  715,  714,  429,  673,  173,  431,  673,  175,
 /*  2140 */   642,  431,  716,  642,  431,  673,  178,  431,  429,  673,
 /*  2150 */    94,  349,  673,  177,  429,  673,  176,  642,  104,  120,
 /*  2160 */   494,  431,  103,  642,  429,  346,  118,  431,  344,  673,
 /*  2170 */   180,  117,   76,   75,  642,  673,  179,  431,  647,  116,
 /*  2180 */   715,  714,   74,  715,  714,  673,  167,  115,  642,   73,
 /*  2190 */   114,  642,  481,  643,  323,  113,  397,   24,  642,  715,
 /*  2200 */   714,  452,  642,  715,  714,  642,   21,  450,  642,  431,
 /*  2210 */   715,  714,  101,  100,  446,  112,   62,  673,   70,  440,
 /*  2220 */   162,  292,  642,  664,  552,  715,  714,  570,  642,  632,
 /*  2230 */   426,  650,  637,  627,  278,  197,  375,  660,  642,  259,
 /*  2240 */   362,  523,    6,  305,  682,  659,  649,  557,  210,  521,
 /*  2250 */    29,  365,  424,  293,   71,  567,  561,  560,  488,  588,
 /*  2260 */   587,   81,  551, 1151, 1151, 1151, 1151, 1151, 1151, 1151,
 /*  2270 */   642,
};
static const YYCODETYPE yy_lookahead[] = {
 /*     0 */     4,  110,  111,    4,   81,   82,   83,   84,   85,   86,
 /*    10 */    87,   15,   72,   73,   74,   75,   76,   77,   78,   79,
 /*    20 */    80,   81,   82,   83,   84,   85,   86,   87,    4,   33,
 /*    30 */    34,  194,  195,  196,   72,   73,   74,   75,   42,   77,
 /*    40 */    78,   79,   80,   81,   82,   83,   84,   85,   86,   87,
 /*    50 */    89,   55,  124,  125,  126,   59,   33,   34,   62,   63,
 /*    60 */    64,   65,   66,   67,   68,   69,   70,   71,   72,   73,
 /*    70 */    74,   75,  104,   77,   78,   79,   80,   81,   82,   83,
 /*    80 */    84,   85,   86,   87,   88,    4,  185,  177,    4,   66,
 /*    90 */    67,    4,   96,    4,   97,   93,   15,  101,  261,  103,
 /*   100 */   190,  104,  106,  107,  105,  106,  107,  111,  109,   64,
 /*   110 */   142,  112,  113,  114,  118,  119,  120,  121,    5,  218,
 /*   120 */   219,   96,    4,   42,   83,   84,   85,   86,   87,  130,
 /*   130 */   106,  107,   87,   34,  138,  139,   51,  191,   53,   26,
 /*   140 */    59,   28,  118,   86,   87,   64,  245,  246,  152,  248,
 /*   150 */   154,  155,  123,  157,  109,  110,  111,  112,  113,  114,
 /*   160 */   115,   48,   81,   82,   83,   81,   82,  266,  267,   88,
 /*   170 */    89,    4,  143,    4,  129,   61,  152,   96,   97,  185,
 /*   180 */    95,  235,  101,   96,  103,  104,  276,  106,  107,  252,
 /*   190 */   106,  107,  111,  106,  110,  106,  107,    4,  252,  118,
 /*   200 */   119,  120,  121,  119,  120,    4,  269,  123,  177,  125,
 /*   210 */    96,   97,  218,  219,    4,  134,   15,  136,  137,  101,
 /*   220 */     0,  190,  123,  142,  106,  107,  195,  196,  147,  148,
 /*   230 */   149,  150,  151,  152,   97,  154,  155,   99,  157,  245,
 /*   240 */   246,  152,  248,   42,    4,   25,  161,   77,   78,   79,
 /*   250 */    80,   81,   82,   83,   84,   85,   86,   87,  205,  206,
 /*   260 */    59,  267,   19,  104,  106,   64,  213,   24,  101,  111,
 /*   270 */   101,   19,   29,  106,  107,  106,  107,  119,  120,  121,
 /*   280 */   162,   29,   81,   82,  117,  118,   23,  118,   61,   88,
 /*   290 */    89,  260,  261,  134,  101,  136,  137,   96,   97,  106,
 /*   300 */   107,  225,  101,    4,  103,  104,   96,  106,  107,   89,
 /*   310 */   234,  101,  111,  146,   45,  146,  106,  107,   55,  118,
 /*   320 */   119,  120,  121,   96,   97,   23,  177,   97,  118,  177,
 /*   330 */    99,  104,   33,   34,  104,  134,   96,  136,  137,  190,
 /*   340 */    99,  101,  190,  133,  195,  196,  106,  107,  147,  148,
 /*   350 */   149,  150,   89,  152,  135,  154,  155,  164,  157,  140,
 /*   360 */     4,   62,   63,   64,   65,   66,   67,   68,   69,   70,
 /*   370 */    71,   72,   73,   74,   75,    4,   77,   78,   79,   80,
 /*   380 */    81,   82,   83,   84,   85,   86,   87,    4,   50,   83,
 /*   390 */     4,  177,   54,  124,  125,  126,  182,   98,   15,  247,
 /*   400 */   186,  187,  177,  177,  190,  106,   99,  138,  139,  260,
 /*   410 */   261,   62,   63,   64,   65,  190,  190,   68,   69,   70,
 /*   420 */    71,   72,   73,   74,   75,   42,   77,   78,   79,   80,
 /*   430 */    81,   82,   83,   84,   85,   86,   87,    4,   89,   83,
 /*   440 */   141,  135,   59,  119,  120,   59,  140,   64,  177,  220,
 /*   450 */   221,  113,  223,  104,  109,    9,    7,  112,  113,  114,
 /*   460 */    11,  190,  106,  107,   81,   82,   20,   81,   82,  198,
 /*   470 */   199,   88,   89,  102,  118,  130,    4,  106,  107,   96,
 /*   480 */    97,   32,   96,  258,  101,  104,  103,  104,  107,  106,
 /*   490 */   107,   96,  106,   98,  111,    4,  111,  111,   58,  161,
 /*   500 */   151,  118,  119,  120,  121,  119,  120,  121,  152,  194,
 /*   510 */   195,  196,  172,  173,   33,   34,   97,  134,   96,  136,
 /*   520 */   137,   40,  251,  104,  253,  144,  145,   51,  177,   53,
 /*   530 */   147,   98,  149,  150,  104,  152,  185,  154,  155,  106,
 /*   540 */   157,  190,  104,   62,   63,   64,   65,   66,   67,   68,
 /*   550 */    69,   70,   71,   72,   73,   74,   75,   25,   77,   78,
 /*   560 */    79,   80,   81,   82,   83,   84,   85,   86,   87,    9,
 /*   570 */   219,   95,  100,  101,  141,    4,  261,    4,  106,  107,
 /*   580 */    20,  151,    4,   97,    4,  104,   97,  236,  237,    4,
 /*   590 */   104,  100,  101,   33,   34,   64,   65,  106,  107,   68,
 /*   600 */    69,   70,   71,   72,   73,   74,   75,  167,   77,   78,
 /*   610 */    79,   80,   81,   82,   83,   84,   85,   86,   87,   33,
 /*   620 */    34,   89,   62,   63,   64,   65,   66,   67,   68,   69,
 /*   630 */    70,   71,   72,   73,   74,   75,   96,   77,   78,   79,
 /*   640 */    80,   81,   82,   83,   84,   85,   86,   87,   62,   63,
 /*   650 */    64,   65,   66,   67,   68,   69,   70,   71,   72,   73,
 /*   660 */    74,   75,    4,   77,   78,   79,   80,   81,   82,   83,
 /*   670 */    84,   85,   86,   87,   33,   34,   91,  106,  107,  106,
 /*   680 */   107,  101,  272,  273,  106,  107,  106,  107,  179,  116,
 /*   690 */   188,  106,  107,  191,  192,  193,   97,  158,  127,  160,
 /*   700 */    55,   43,   97,   62,   63,   64,   65,   66,   67,   68,
 /*   710 */    69,   70,   71,   72,   73,   74,   75,   12,   77,   78,
 /*   720 */    79,   80,   81,   82,   83,   84,   85,   86,   87,   62,
 /*   730 */    63,   64,   65,   97,  156,   68,   69,   70,   71,   72,
 /*   740 */    73,   74,   75,  163,   77,   78,   79,   80,   81,   82,
 /*   750 */    83,   84,   85,   86,   87,  110,   89,   97,  100,  170,
 /*   760 */   171,  172,  173,   61,  106,  107,  257,   62,   63,   64,
 /*   770 */    65,  104,   61,   68,   69,   70,   71,   72,   73,   74,
 /*   780 */    75,   96,   77,   78,   79,   80,   81,   82,   83,   84,
 /*   790 */    85,   86,   87,   97,   89,   38,    4,  111,   96,   97,
 /*   800 */   104,    4,  124,  125,  126,  191,  104,   96,   97,  197,
 /*   810 */   177,    4,   81,   82,  181,  129,    4,  205,  151,   62,
 /*   820 */    63,   64,   65,  190,    4,   68,   69,   70,   71,   72,
 /*   830 */    73,   74,   75,   97,   77,   78,   79,   80,   81,   82,
 /*   840 */    83,   84,   85,   86,   87,    4,   89,   55,    4,  235,
 /*   850 */   119,  120,   62,   63,   64,   65,   15,  104,   68,   69,
 /*   860 */    70,   71,   72,   73,   74,   75,  201,   77,   78,   79,
 /*   870 */    80,   81,   82,   83,   84,   85,   86,   87,  190,  104,
 /*   880 */     4,  138,  139,   42,   71,    4,  198,   98,   96,   97,
 /*   890 */   169,  220,  221,  101,  223,  174,   55,  122,  106,  107,
 /*   900 */    59,   97,  177,  106,  107,   64,  185,  100,  104,   96,
 /*   910 */   118,  186,  187,  106,  107,  190,   96,  252,  106,  107,
 /*   920 */   249,  101,   81,   82,   96,  133,  106,  107,   97,   88,
 /*   930 */   138,  139,    4,  177,  209,    5,  211,   96,  118,  218,
 /*   940 */   219,  177,  101,  146,  103,  101,  190,  106,  107,  159,
 /*   950 */   106,  107,  111,  133,  190,  185,   26,   30,   28,  118,
 /*   960 */   119,  120,  121,  177,  144,  145,  245,  246,  177,  248,
 /*   970 */   191,   55,   91,  177,  162,   45,  190,  101,   48,  138,
 /*   980 */   139,  190,  106,  107,  198,  199,  190,  106,  107,  219,
 /*   990 */   146,   64,  271,  152,  118,  154,  155,   97,  157,   98,
 /*  1000 */    62,   63,   64,   65,  104,   89,   68,   69,   70,   71,
 /*  1010 */    72,   73,   74,   75,  235,   77,   78,   79,   80,   81,
 /*  1020 */    82,   83,   84,   85,   86,   87,    4,  236,  237,    4,
 /*  1030 */   244,  191,  192,  193,  106,  107,   98,  251,   34,  243,
 /*  1040 */   276,   97,   62,   63,   64,   65,  118,  201,   68,   69,
 /*  1050 */    70,   71,   72,   73,   74,   75,   96,   77,   78,   79,
 /*  1060 */    80,   81,   82,   83,   84,   85,   86,   87,   64,   62,
 /*  1070 */    63,   64,   65,   13,  146,   68,   69,   70,   71,   72,
 /*  1080 */    73,   74,   75,  177,   77,   78,   79,   80,   81,   82,
 /*  1090 */    83,   84,   85,   86,   87,  104,  190,   13,  252,   62,
 /*  1100 */    63,   64,   65,  104,   97,   68,   69,   70,   71,   72,
 /*  1110 */    73,   74,   75,   91,   77,   78,   79,   80,   81,   82,
 /*  1120 */    83,   84,   85,   86,   87,   96,   13,  123,  106,  107,
 /*  1130 */   185,  106,  107,  129,   97,   62,   63,   64,   65,  159,
 /*  1140 */    30,   68,   69,   70,   71,   72,   73,   74,   75,  243,
 /*  1150 */    77,   78,   79,   80,   81,   82,   83,   84,   85,   86,
 /*  1160 */    87,  185,    4,   97,  219,   62,   63,   64,   65,  144,
 /*  1170 */    97,   68,   69,   70,   71,   72,   73,   74,   75,  177,
 /*  1180 */    77,   78,   79,   80,   81,   82,   83,   84,   85,   86,
 /*  1190 */    87,   97,  190,  185,  144,  219,   99,   62,   63,   64,
 /*  1200 */    65,   98,   83,   68,   69,   70,   71,   72,   73,   74,
 /*  1210 */    75,   99,   77,   78,   79,   80,   81,   82,   83,   84,
 /*  1220 */    85,   86,   87,  185,   89,   97,    4,  219,   62,   63,
 /*  1230 */    64,   65,  104,  104,   68,   69,   70,   71,   72,   73,
 /*  1240 */    74,   75,   96,   77,   78,   79,   80,   81,   82,   83,
 /*  1250 */    84,   85,   86,   87,    4,   89,   97,  219,    4,  101,
 /*  1260 */    62,   63,   64,   65,  106,  107,   68,   69,   70,   71,
 /*  1270 */    72,   73,   74,   75,    4,   77,   78,   79,   80,   81,
 /*  1280 */    82,   83,   84,   85,   86,   87,    4,   62,   63,   64,
 /*  1290 */    65,  133,    4,   68,   69,   70,   71,   72,   73,   74,
 /*  1300 */    75,  177,   77,   78,   79,   80,   81,   82,   83,   84,
 /*  1310 */    85,   86,   87,    4,  190,   97,  185,  135,  158,   96,
 /*  1320 */    17,  191,  104,  101,   15,   63,   64,   65,  106,  107,
 /*  1330 */    68,   69,   70,   71,   72,   73,   74,   75,   38,   77,
 /*  1340 */    78,   79,   80,   81,   82,   83,   84,   85,   86,   87,
 /*  1350 */   219,   42,    4,  214,  132,  216,  106,  107,  177,   96,
 /*  1360 */   106,  107,  177,    4,  177,  235,  185,  243,   59,    6,
 /*  1370 */   185,  190,  118,   64,   97,  190,  106,  190,  108,  198,
 /*  1380 */   199,  104,    4,  198,  199,  198,  199,  133,  106,  101,
 /*  1390 */    81,   82,   97,   97,  106,  107,    4,   88,  177,  117,
 /*  1400 */   219,   97,  152,   97,  219,   96,   97,   15,  104,   97,
 /*  1410 */   101,  190,  103,  232,  233,  106,  107,  232,  177,  232,
 /*  1420 */   111,  214,  177,  216,    4,   96,  177,  118,  119,  120,
 /*  1430 */   121,  190,  251,    4,   42,  190,  251,   14,  251,  190,
 /*  1440 */     4,   97,   38,  198,  199,   96,  177,  198,  199,  177,
 /*  1450 */    97,   59,   96,  165,  106,  107,   64,   38,   35,  190,
 /*  1460 */     4,  152,  190,  154,  155,  106,  157,  198,  199,   46,
 /*  1470 */   198,  199,    4,   81,   82,   96,  117,  232,  233,    4,
 /*  1480 */    88,  232,  233,  115,  106,  107,    4,  129,   96,   97,
 /*  1490 */    15,   64,  144,  101,  177,  103,  251,  103,  106,  107,
 /*  1500 */   251,  232,   12,  111,    4,  177,    4,  190,   98,  177,
 /*  1510 */   118,  119,  120,  121,  186,  187,  244,   42,  190,  141,
 /*  1520 */   251,    4,  190,  251,  123,  142,  106,  107,  177,   71,
 /*  1530 */    71,  128,  139,  153,   59,  106,  107,  101,  118,   64,
 /*  1540 */     4,  190,  106,  107,  152,  116,  154,  155,    4,  157,
 /*  1550 */    89,  128,  177,   89,  118,   22,   81,   82,   47,   91,
 /*  1560 */    39,    4,  106,   88,  177,  190,  146,  177,  181,  237,
 /*  1570 */   104,   96,   15,  117,  106,  107,  101,  190,  103,  177,
 /*  1580 */   190,  106,  107,  101,  177,  177,  111,    4,  106,  107,
 /*  1590 */    39,  177,  190,  118,  119,  120,  121,  190,  190,   42,
 /*  1600 */   118,  101,  212,  101,  190,  161,  106,  107,  106,  107,
 /*  1610 */   123,  103,  198,  199,   95,  177,   59,    4,  118,  181,
 /*  1620 */   118,   64,    4,  106,  107,   96,  143,  152,  190,  154,
 /*  1630 */   155,   96,  157,  158,  177,  118,   97,   97,   81,   82,
 /*  1640 */    95,   93,  106,  107,    4,   88,  177,  190,  258,  177,
 /*  1650 */   106,  107,   37,   96,   97,   15,   36,  252,  101,  190,
 /*  1660 */   103,  273,  190,  106,  107,  251,  177,  189,  111,  212,
 /*  1670 */   198,  199,  177,    4,  204,  118,  119,  120,  121,  190,
 /*  1680 */     4,  177,   42,  238,  204,  190,    4,  198,  199,  106,
 /*  1690 */   107,  275,  177,  177,  190,  177,  152,  181,  176,   59,
 /*  1700 */   164,  118,  198,  199,   64,  190,  190,  275,  190,  152,
 /*  1710 */   176,  154,  155,    4,  157,  258,  198,  199,  100,  106,
 /*  1720 */   107,   81,   82,  251,  106,  107,    4,   90,   88,  177,
 /*  1730 */   176,  118,  177,    4,  178,  177,   96,   15,   49,  177,
 /*  1740 */   251,  101,  190,  103,  176,  190,  106,  107,  190,  177,
 /*  1750 */   177,  111,  190,  198,  199,  251,  198,  199,  118,  119,
 /*  1760 */   120,  121,  190,  190,   42,  177,  177,  177,   60,  251,
 /*  1770 */   181,  198,  199,  178,  212,  106,  107,  177,  190,  190,
 /*  1780 */   190,   59,  106,  107,  212,  180,   64,  183,  106,  107,
 /*  1790 */   190,  104,  152,  184,  154,  155,   64,  157,  198,  199,
 /*  1800 */   118,  132,   56,   81,   82,   87,  251,  254,    4,  251,
 /*  1810 */    88,  252,  221,  177,  158,  106,  107,  181,   96,   15,
 /*  1820 */   258,  177,  146,  101,  251,  103,  190,  118,  106,  107,
 /*  1830 */   258,  177,  177,  111,  190,  106,  107,  177,  138,  227,
 /*  1840 */   118,  119,  120,  121,  190,  190,   42,  118,  177,  151,
 /*  1850 */   190,  251,  181,  198,  199,    8,  228,   10,  177,   12,
 /*  1860 */   177,  190,  181,   59,    4,  177,  149,  148,   21,  181,
 /*  1870 */    23,  190,  229,  190,  152,  230,  154,  155,  190,  157,
 /*  1880 */   177,  198,  199,  231,  181,   81,   82,  203,   41,  150,
 /*  1890 */     4,   44,   88,  190,  147,   48,   49,   96,  259,   52,
 /*  1900 */    96,   87,   55,  177,   57,  101,  251,  103,  203,  241,
 /*  1910 */   106,  107,    4,  177,  177,  111,  190,  177,   99,  177,
 /*  1920 */   223,  139,  118,  119,  120,  121,  190,  190,  200,  177,
 /*  1930 */   190,  177,  190,  177,  251,  198,  199,  241,   99,   92,
 /*  1940 */     4,   94,  190,  123,  190,  200,  190,  177,  200,  177,
 /*  1950 */   198,  199,  198,  199,  198,  199,  152,  208,  154,  155,
 /*  1960 */   190,  157,  190,   31,  177,  202,  106,  107,  198,  199,
 /*  1970 */   198,  199,    4,  122,    4,  200,  177,  190,  131,  203,
 /*  1980 */   200,  208,  177,  200,  200,  198,  199,  177,  251,  190,
 /*  1990 */   200,  203,  106,  107,  241,  190,   99,  198,  199,  177,
 /*  2000 */   190,  180,   99,  251,  118,  251,  177,  251,  198,  199,
 /*  2010 */   203,  177,  190,  166,  106,  107,    4,  180,  177,  190,
 /*  2020 */   241,  251,  264,  251,  190,  165,  118,  198,  199,   99,
 /*  2030 */     4,  190,  198,  199,   27,  177,  177,  158,  251,  198,
 /*  2040 */   199,  177,  106,  107,   99,  227,  177,  177,  190,  190,
 /*  2050 */   251,  177,  177,  215,  190,   62,  198,  199,  177,  190,
 /*  2060 */   190,  251,  198,  199,  190,  190,  177,  198,  199,  177,
 /*  2070 */    96,  190,  198,  199,  106,  107,  106,  107,    4,  190,
 /*  2080 */   251,    4,  190,  177,   99,  251,  118,  198,  199,  177,
 /*  2090 */   198,  199,  251,  177,  177,  265,  190,    4,   99,  163,
 /*  2100 */   177,    4,  190,  133,  198,  199,  190,  190,    4,  251,
 /*  2110 */   198,  199,  100,  190,  177,  251,  250,  177,  106,  107,
 /*  2120 */   251,  198,  199,    4,  177,  251,  215,  190,  177,  177,
 /*  2130 */   190,  177,  106,  107,  177,  198,  199,  190,  198,  199,
 /*  2140 */   251,  190,  190,  251,  190,  198,  199,  190,  177,  198,
 /*  2150 */   199,  241,  198,  199,  177,  198,  199,  251,  180,   99,
 /*  2160 */   227,  190,  180,  251,  177,  241,   99,  190,   60,  198,
 /*  2170 */   199,   99,  217,  217,  251,  198,  199,  190,  152,   99,
 /*  2180 */   106,  107,  217,  106,  107,  198,  199,   99,  251,  217,
 /*  2190 */    99,  251,  118,  100,  241,   99,  177,  268,  251,  106,
 /*  2200 */   107,   18,  251,  106,  107,  251,  268,  241,  251,  190,
 /*  2210 */   106,  107,   99,   99,  241,   99,  270,  198,  199,   16,
 /*  2220 */   224,  226,  251,  261,  105,  106,  107,  206,  251,  152,
 /*  2230 */   255,  201,  240,  242,  201,  210,  202,  261,  251,  242,
 /*  2240 */   242,  227,  224,  175,  191,  191,  191,  191,  262,  152,
 /*  2250 */   256,  263,  216,  222,  239,  207,  207,  207,  274,  198,
 /*  2260 */   198,   55,  211,  277,  277,  277,  277,  277,  277,  277,
 /*  2270 */   251,
};
#define YY_SHIFT_USE_DFLT (-110)
#define YY_SHIFT_COUNT (435)
#define YY_SHIFT_MIN   (-109)
#define YY_SHIFT_MAX   (2206)
static const short yy_shift_ofst[] = {
 /*     0 */   532,   -4, 1847,  841,  916, 1557, 1557,  263,  383, 1475,
 /*    10 */  1722, 1640, 1640,  792,   84,   84,   -1,   81,  201, 1392,
 /*    20 */  1309, 1640, 1640, 1640, 1640, 1640, 1640, 1640, 1640, 1640,
 /*    30 */  1640, 1640, 1640, 1640, 1640, 1640, 1640, 1640, 1640, 1640,
 /*    40 */  1640, 1640, 1640, 1640, 1640, 1640, 1640, 1640, 1640, 1640,
 /*    50 */  1640, 1640, 1640, 1640, 1640, 1640, 1640, 1640, 1804, 2119,
 /*    60 */   820,  269, 2119, 2026, 2026, 2026, 2026,  731,  731, 1270,
 /*    70 */   299,  210, 1502, 1288,  844, 1158, 1500, 1482, 1436,  876,
 /*    80 */  1222,  658,  491, 2077, 2077, 2097, 1004, 2077, 2093, 2026,
 /*    90 */  1270,  743,  560,  560,  757,  386,   45,  167,  169,  356,
 /*   100 */  1420,  928,  580,  472,  118,  930,  193,  930,  240, 1254,
 /*   110 */    24, 2012, 1968, 1936, 1860, 1676, 1970, 2074, 1618, 1908,
 /*   120 */   812, 1886, 1544, 1729, 1709, 1682, 1536, 1669,  807, 1613,
 /*   130 */  1429,  571, 1583, 1517, 1348, 1025,  433,  433,  797, 1378,
 /*   140 */   433, 1250,  578,   89,  573,  371,  338, 1468, 1022,  881,
 /*   150 */   585, 2104, 2104, 2104,  220,  645, 2206, 2206, 2206, 2206,
 /*   160 */  2206, -110, -110,  481,  641,  641,  641,  641,  641,  641,
 /*   170 */   641,  641,  641,  667,  349,  705, 1166, 1135, 1103, 1073,
 /*   180 */  1037, 1007,  980,  938,  790, 1225, 1198, 1262,  531,  531,
 /*   190 */   -60,  -38,  -38,  -38,  -38,  170,  -77,  345,  158,  158,
 /*   200 */    41,  702,  227, 1423, 1423, 1423,  381,  159,  113,   23,
 /*   210 */   678,  449, 1456, 1359,   87, 1282,  306,  243,  430,  927,
 /*   220 */   927,  775, 1304,   99,  446,  927,   29,  446,  324,  324,
 /*   230 */   -32,  219,  539,   57, 2203, 2116, 2114, 2113, 2183, 2183,
 /*   240 */  2096, 2091, 2108, 2088, 2108, 2080, 2108, 2072, 2108, 2067,
 /*   250 */  1708, 1698, 2060, 1708, 1993, 1974, 1999, 1985, 1993, 1698,
 /*   260 */  1945, 1879, 2007, 1930, 1708, 1903, 1801, 1708, 1897, 1801,
 /*   270 */  1820, 1820, 1820, 1820, 1932, 1801, 1820, 1851, 1820, 1932,
 /*   280 */  1820, 1820, 1839, 1782, 1819, 1801, 1814, 1801, 1739, 1747,
 /*   290 */  1717, 1719, 1698, 1700, 1656, 1732, 1718, 1746, 1687, 1708,
 /*   300 */  1689, 1689, 1637, 1637, 1637, 1637, -110, -110, -110, -110,
 /*   310 */  -110, -110, -110, -110, -110, -110,  586,   85,  711,  114,
 /*   320 */   -72,  476,  440,  813, 1277, 1218, 1128,  900,  804, -109,
 /*   330 */   252,  686,  696,  486,  419,  230,   -3,  395, 1620, 1615,
 /*   340 */  1548, 1545, 1540, 1539, 1508, 1535, 1483, 1519, 1529, 1487,
 /*   350 */  1444, 1551, 1466, 1521, 1511, 1533, 1464, 1461, 1393, 1380,
 /*   360 */  1459, 1458, 1403, 1383, 1490, 1401, 1410, 1394, 1427, 1358,
 /*   370 */  1368, 1379, 1419, 1356, 1349, 1353, 1329, 1404, 1363, 1263,
 /*   380 */  1300, 1303, 1344, 1312, 1306, 1296, 1160, 1295, 1129, 1182,
 /*   390 */  1223,  999, 1159, 1146, 1129, 1119, 1112, 1097, 1050, 1094,
 /*   400 */  1066, 1110, 1113, 1029,  999, 1084,  991, 1060,  944,  960,
 /*   410 */   901,  753,  831,  828,  789,  753,  736,  685,  660,  636,
 /*   420 */   540,  605,  599,  489,  438,  422,  302,  385,  307,  241,
 /*   430 */   231,  138,   25,  137,    2,  -39,
};
#define YY_REDUCE_USE_DFLT (-164)
#define YY_REDUCE_COUNT (315)
#define YY_REDUCE_MIN   (-163)
#define YY_REDUCE_MAX   (2068)
static const short yy_reduce_ofst[] = {
 /*     0 */   589, 1181,  721, 1185,  -99, 1249, 1245,   -6, 1269,  271,
 /*    10 */  1272, 1187,  786,  351,  149,   31,  725, 2019, 1987, 1977,
 /*    20 */  1971, 1957, 1954, 1951, 1947, 1940, 1937, 1923, 1912, 1906,
 /*    30 */  1892, 1889, 1874, 1869, 1864, 1858, 1841, 1834, 1829, 1810,
 /*    40 */  1799, 1787, 1772, 1770, 1756, 1754, 1752, 1737, 1683, 1655,
 /*    50 */  1600, 1573, 1558, 1555, 1518, 1504, 1489, 1472, 1414,  214,
 /*    60 */   791,  671, 1328, 1572, 1562, 1457, 1390,  315, -163,  502,
 /*    70 */   -54, 1332, 1703, 1688, 1681, 1671, 1636, 1589, 1516, 1438,
 /*    80 */  1387,  764,  633, 1124,  906,  152,   53,  796,  -90,  225,
 /*    90 */   840,  229,  846,  665,  -63,  688,  612, 1952, 1917, 1822,
 /*   100 */  1590, 1590, 1916, 1881, 1875, 1207, 1870, 1139, 1859, 1590,
 /*   110 */  1822, 1805, 1590, 1590, 1590, 1590, 1590, 1590, 1590, 1742,
 /*   120 */  1590, 1590, 1740, 1590, 1590, 1736, 1590, 1590, 1590, 1726,
 /*   130 */  1660, 1654, 1644, 1590, 1588, 1552, 1130,  779, 1515, 1495,
 /*   140 */   614, 1469, 1408, 1407, 1402, 1375,  509, 1351, 1317, 1241,
 /*   150 */  1221, 1002,  756,  226,  340, 1131, 1038, 1008,  976,  945,
 /*   160 */   770,  410,   76, 1405, 1405, 1405, 1405, 1405, 1405, 1405,
 /*   170 */  1405, 1405, 1405, 1405, 1405, 1405, 1405, 1405, 1405, 1405,
 /*   180 */  1405, 1405, 1405, 1405, 1405, 1405, 1405, 1405, 1405, 1405,
 /*   190 */  1405, 1405, 1405, 1405, 1405, 1405, 1405, 2051, 2062, 2061,
 /*   200 */  1405, 1984, 1984, 2050, 2049, 2048, 2015, 2031, 2036, 1994,
 /*   210 */  1988, 1986, 2056, 2055, 2054, 2053, 2018, 2068, 2014, 1998,
 /*   220 */  1997, 2034, 2025, 2021, 2033, 1991, 1992, 2030, 1976, 1962,
 /*   230 */  1995, 1996, 1975, 1405, 1946, 1753, 1973, 1966, 1938, 1929,
 /*   240 */  1953, 1753, 1972, 1753, 1965, 1753, 1956, 1753, 1955, 1924,
 /*   250 */  1982, 1933, 1910, 1978, 1911, 1866, 1753, 1753, 1838, 1818,
 /*   260 */  1753, 1830, 1758, 1779, 1837, 1753, 1807, 1821, 1753, 1788,
 /*   270 */  1790, 1784, 1783, 1780, 1773, 1776, 1775, 1763, 1748, 1749,
 /*   280 */  1745, 1728, 1696, 1697, 1668, 1705, 1639, 1684, 1652, 1645,
 /*   290 */  1643, 1628, 1612, 1591, 1553, 1559, 1405, 1609, 1604, 1605,
 /*   300 */  1595, 1556, 1568, 1554, 1534, 1522, 1432, 1416, 1388, 1480,
 /*   310 */  1470, 1445, 1405, 1405, 1405, 1478,
};
static const YYACTIONTYPE yy_default[] = {
 /*     0 */   730, 1038, 1143, 1026, 1143, 1026, 1026, 1143, 1026, 1026,
 /*    10 */  1026, 1026, 1026,  901, 1149, 1149, 1149, 1026, 1026, 1026,
 /*    20 */  1026, 1026, 1026, 1026, 1026, 1026, 1026, 1026, 1026, 1026,
 /*    30 */  1026, 1026, 1026, 1026, 1026, 1026, 1026, 1026, 1026, 1026,
 /*    40 */  1026, 1026, 1026, 1026, 1026, 1026, 1026, 1026, 1026, 1026,
 /*    50 */  1026, 1026, 1026, 1026, 1026, 1026, 1026, 1026,  978, 1149,
 /*    60 */   895, 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149,  775,
 /*    70 */   891,  901, 1149, 1149, 1149, 1149, 1149,  963,  950,  941,
 /*    80 */  1149, 1149, 1149,  973,  973,  956,  843,  973, 1149, 1149,
 /*    90 */  1149, 1149,  929,  929, 1028, 1149,  767, 1113, 1118,  976,
 /*   100 */  1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149,  902,
 /*   110 */   976, 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149,
 /*   120 */  1149,  964,  957,  951,  942, 1149, 1149, 1149, 1149, 1149,
 /*   130 */  1149, 1149, 1149, 1149, 1149, 1149,  891,  891, 1149, 1149,
 /*   140 */   891, 1149, 1149,  977, 1149, 1149,  764, 1149, 1149, 1149,
 /*   150 */   736, 1059, 1149, 1149,  730, 1143, 1143, 1143, 1143, 1143,
 /*   160 */  1143, 1136,  881,  936, 1032, 1033,  907,  946, 1039,  934,
 /*   170 */   938,  937, 1031, 1028, 1028, 1028, 1028, 1028, 1028, 1028,
 /*   180 */  1028, 1028, 1028, 1028, 1028, 1028, 1028, 1001, 1013, 1000,
 /*   190 */  1008, 1009, 1012, 1003, 1017, 1002, 1004, 1149, 1149, 1149,
 /*   200 */  1005, 1149, 1149, 1149, 1149, 1149,  894,  865, 1149, 1149,
 /*   210 */  1149, 1087, 1149, 1149,  777, 1149,  879,  739,  945,  919,
 /*   220 */   919,  810,  834,  799,  929,  919,  909,  929, 1149, 1149,
 /*   230 */   892,  879, 1034, 1006, 1127,  910,  910,  910, 1112, 1112,
 /*   240 */   910,  910,  856,  910,  856,  910,  856,  910,  856,  910,
 /*   250 */   761,  945,  910,  761,  847,  969,  910,  910,  847,  945,
 /*   260 */   910, 1094, 1092,  910,  761,  910, 1047,  761,  910, 1047,
 /*   270 */   845,  845,  845,  845,  826, 1047,  845,  810,  845,  826,
 /*   280 */   845,  845,  910, 1149,  910, 1047, 1053, 1047,  935,  923,
 /*   290 */   933,  930,  945, 1149, 1149, 1028, 1007,  758,  829,  761,
 /*   300 */   747,  747,  735,  735,  735,  735, 1140, 1140, 1136,  812,
 /*   310 */   812,  897, 1016, 1015, 1014,  786, 1040, 1149, 1149, 1149,
 /*   320 */  1149, 1149, 1149, 1061, 1149, 1149, 1149, 1149, 1149, 1149,
 /*   330 */  1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149,  731,
 /*   340 */  1149, 1149, 1149, 1149, 1149, 1130, 1149, 1149, 1149, 1149,
 /*   350 */  1149, 1149, 1091, 1090, 1149, 1149, 1149, 1149, 1149, 1149,
 /*   360 */  1149, 1149, 1149, 1149, 1079, 1149, 1149, 1149, 1149, 1149,
 /*   370 */  1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149,
 /*   380 */  1149, 1149, 1149, 1149, 1149,  980, 1027, 1149,  868,  870,
 /*   390 */  1149, 1037, 1149, 1149,  869, 1149, 1149, 1149, 1149, 1149,
 /*   400 */  1149, 1149, 1149, 1149,  931, 1149,  924, 1149, 1149, 1149,
 /*   410 */  1149, 1145, 1149, 1149, 1149, 1144, 1149, 1149, 1149, 1149,
 /*   420 */  1149, 1149, 1149, 1149, 1149, 1149,  979, 1029,  993, 1149,
 /*   430 */   992,  991,  770, 1149,  745, 1149,  727,  732, 1129, 1126,
 /*   440 */  1128, 1123, 1124, 1122, 1125, 1121, 1119, 1120, 1117, 1115,
 /*   450 */  1114, 1116, 1111, 1107, 1067, 1065, 1063, 1072, 1071, 1070,
 /*   460 */  1069, 1068, 1064, 1062, 1066, 1060,  960,  948,  939,  863,
 /*   470 */  1106, 1104, 1105, 1058, 1056, 1057,  862,  861,  860,  855,
 /*   480 */   854,  853,  852, 1133, 1142, 1141, 1139, 1138, 1137, 1131,
 /*   490 */  1132, 1045, 1044, 1042, 1041, 1043,  763, 1083, 1086, 1085,
 /*   500 */  1084, 1089, 1088, 1081, 1093, 1098, 1097, 1102, 1101, 1100,
 /*   510 */  1099, 1096, 1078,  968,  967,  965,  970,  962,  961,  966,
 /*   520 */   953,  959,  958,  949,  952,  848,  944,  940,  943,  864,
 /*   530 */  1082,  859,  858,  857,  762,  757,  912,  756,  755,  766,
 /*   540 */   832,  833,  841,  844,  839,  842,  838,  837,  836,  840,
 /*   550 */   835,  831,  769,  768,  776,  825,  803,  801,  800,  804,
 /*   560 */   817,  816,  823,  822,  821,  820,  819,  815,  818,  814,
 /*   570 */   813,  805,  798,  797,  811,  796,  828,  827,  824,  795,
 /*   580 */   851,  850,  849,  846,  794,  793,  792,  791,  790,  789,
 /*   590 */   999,  998, 1030, 1021,  982,  981, 1020, 1018, 1029, 1019,
 /*   600 */   990,  866,  873,  872,  871,  875,  876,  886,  884,  883,
 /*   610 */   882,  918,  917,  916,  915,  914,  913,  906,  904,  900,
 /*   620 */   899,  911,  905,  903,  921,  922,  920,  898,  890,  888,
 /*   630 */   889,  887,  975,  972,  974,  971,  908,  896,  893,  880,
 /*   640 */   926,  925, 1027, 1148, 1146, 1147, 1050, 1052, 1055, 1054,
 /*   650 */  1051,  928,  927, 1049, 1048, 1022,  997,  782,  780,  781,
 /*   660 */  1075, 1074, 1077, 1076, 1073,  784,  783,  779,  778,  995,
 /*   670 */   874,  867,  989,  988, 1103, 1024, 1025,  987,  983, 1023,
 /*   680 */  1011, 1010,  996,  986,  771,  984,  994,  985,  809,  808,
 /*   690 */   807,  806,  878,  877,  788,  802,  787,  785,  765,  760,
 /*   700 */   759,  754,  752,  749,  751,  748,  753,  750,  746,  744,
 /*   710 */   743,  742,  741,  740,  774,  773,  772,  770,  738,  737,
 /*   720 */   734,  733,  729,  728,  726,
};

/* The next table maps tokens into fallback tokens.  If a construct
** like the following:
**
**      %fallback ID X Y Z.
**
** appears in the grammar, then ID becomes a fallback token for X, Y,
** and Z.  Whenever one of the tokens X, Y, or Z is input to the parser
** but it does not parse, the type of the token is changed to ID and
** the parse is retried before an error is thrown.
*/
#ifdef YYFALLBACK
static const YYCODETYPE yyFallback[] = {
    0,  /*          $ => nothing */
    0,  /*    ILLEGAL => nothing */
    0,  /*    COMMENT => nothing */
    0,  /*      SPACE => nothing */
    0,  /*         ID => nothing */
    4,  /*      ABORT => ID */
    4,  /*     ACTION => ID */
    4,  /*      AFTER => ID */
    4,  /*    ANALYZE => ID */
    4,  /*        ASC => ID */
    4,  /*     ATTACH => ID */
    4,  /*     BEFORE => ID */
    4,  /*      BEGIN => ID */
    4,  /*         BY => ID */
    4,  /*    CASCADE => ID */
    4,  /*       CAST => ID */
    4,  /*   COLUMNKW => ID */
    4,  /*   CONFLICT => ID */
    4,  /*   DATABASE => ID */
    4,  /*   DEFERRED => ID */
    4,  /*       DESC => ID */
    4,  /*     DETACH => ID */
    4,  /*       EACH => ID */
    4,  /*        END => ID */
    4,  /*  EXCLUSIVE => ID */
    4,  /*    EXPLAIN => ID */
    4,  /*       FAIL => ID */
    4,  /*        FOR => ID */
    4,  /*     IGNORE => ID */
    4,  /*  IMMEDIATE => ID */
    4,  /*    INDEXED => ID */
    4,  /*  INITIALLY => ID */
    4,  /*    INSTEAD => ID */
    4,  /*    LIKE_KW => ID */
    4,  /*      MATCH => ID */
    4,  /*         NO => ID */
    4,  /*       PLAN => ID */
    4,  /*      QUERY => ID */
    4,  /*        KEY => ID */
    4,  /*         OF => ID */
    4,  /*     OFFSET => ID */
    4,  /*     PRAGMA => ID */
    4,  /*      RAISE => ID */
    4,  /*  RECURSIVE => ID */
    4,  /*    RELEASE => ID */
    4,  /*    REPLACE => ID */
    4,  /*   RESTRICT => ID */
    4,  /*        ROW => ID */
    4,  /*   ROLLBACK => ID */
    4,  /*  SAVEPOINT => ID */
    4,  /*       TEMP => ID */
    4,  /*    TRIGGER => ID */
    4,  /*     VACUUM => ID */
    4,  /*       VIEW => ID */
    4,  /*    VIRTUAL => ID */
    4,  /*       WITH => ID */
    4,  /*    WITHOUT => ID */
    4,  /*    REINDEX => ID */
    4,  /*     RENAME => ID */
    4,  /*   CTIME_KW => ID */
    4,  /*         IF => ID */
};
#endif /* YYFALLBACK */

/* The following structure represents a single element of the
** parser's stack.  Information stored includes:
**
**   +  The state number for the parser at this level of the stack.
**
**   +  The value of the token stored at this level of the stack.
**      (In other words, the "major" token.)
**
**   +  The semantic value stored at this level of the stack.  This is
**      the information used by the action routines in the grammar.
**      It is sometimes called the "minor" token.
*/
struct yyStackEntry {
  YYACTIONTYPE stateno;  /* The state-number */
  YYCODETYPE major;      /* The major token value.  This is the code
                         ** number for the token at this stack level */
  YYMINORTYPE minor;     /* The user-supplied minor token value.  This
                         ** is the value of the token  */
  QList<Token*>* tokens = nullptr;
};
typedef struct yyStackEntry yyStackEntry;

/* The state of the parser is completely contained in an instance of
** the following structure */
struct yyParser {
  int yyidx;                    /* Index of top element in stack */
#ifdef YYTRACKMAXSTACKDEPTH
  int yyidxMax;                 /* Maximum value of yyidx */
#endif
  int yyerrcnt;                 /* Shifts left before out of the error */
  sqlite3_parseARG_SDECL                /* A place to hold %extra_argument */
#if YYSTACKDEPTH<=0
  int yystksz;                  /* Current side of the stack */
  yyStackEntry *yystack;        /* The parser's stack */
#else
  yyStackEntry yystack[YYSTACKDEPTH];  /* The parser's stack */
#endif
};
typedef struct yyParser yyParser;

#ifndef NDEBUG
#include <stdio.h>
static FILE *yyTraceFILE = 0;
static char *yyTracePrompt = 0;
#endif /* NDEBUG */

void *sqlite3_parseCopyParserState(void* other)
{
  yyParser *pParser;
  yyParser *otherParser = (yyParser*)other;

  // Copy parser
  pParser = (yyParser*)malloc((size_t)sizeof(yyParser));
  memcpy(pParser, other, (size_t)sizeof(yyParser));

#if YYSTACKDEPTH<=0
  // Copy stack
  int stackSize = sizeof(yyStackEntry) * pParser->yystksz;
  pParser->yystack = malloc((size_t)stackSize);
  memcpy(pParser->yystack, ((yyParser*)other)->yystack, (size_t)stackSize);
#endif

  for (int i = 0; i <= pParser->yyidx; i++)
  {
      pParser->yystack[i].tokens = new QList<Token*>();
      *(pParser->yystack[i].tokens) = *(otherParser->yystack[i].tokens);
  }

  return pParser;
}

void sqlite3_parseAddToken(void* other, Token* token)
{
    yyParser *otherParser = (yyParser*)other;
    if (otherParser->yyidx < 0)
        return; // Nothing on stack yet. Might happen when parsing just whitespaces, nothing else.

    otherParser->yystack[otherParser->yyidx].tokens->append(token);
}

void sqlite3_parseRestoreParserState(void* saved, void* target)
{
  yyParser *pParser = (yyParser*)target;
  yyParser *savedParser = (yyParser*)saved;

  for (int i = 0; i <= pParser->yyidx; i++)
      delete pParser->yystack[i].tokens;

  memcpy(pParser, saved, (size_t)sizeof(yyParser));

  for (int i = 0; i <= savedParser->yyidx; i++)
  {
      pParser->yystack[i].tokens = new QList<Token*>();
      *(pParser->yystack[i].tokens) = *(savedParser->yystack[i].tokens);
  }

#if YYSTACKDEPTH<=0
  // Copy stack
  int stackSize = sizeof(yyStackEntry) * pParser->yystksz;
  pParser->yystack = relloc(pParser->yystack, (size_t)stackSize);
  memcpy(pParser->yystack, ((yyParser*)saved)->yystack, (size_t)stackSize);
#endif
}

void sqlite3_parseFreeSavedState(void* other)
{
    yyParser *pParser = (yyParser*)other;
    for (int i = 0; i <= pParser->yyidx; i++)
        delete pParser->yystack[i].tokens;

#if YYSTACKDEPTH<=0
    free(pParser->yystack);
#endif
    free(other);
}

#ifndef NDEBUG
/*
** Turn parser tracing on by giving a stream to which to write the trace
** and a prompt to preface each trace message.  Tracing is turned off
** by making either argument NULL
**
** Inputs:
** <ul>
** <li> A FILE* to which trace output should be written.
**      If NULL, then tracing is turned off.
** <li> A prefix string written at the beginning of every
**      line of trace output.  If NULL, then tracing is
**      turned off.
** </ul>
**
** Outputs:
** None.
*/
void sqlite3_parseTrace(FILE *TraceFILE, char *zTracePrompt){
  yyTraceFILE = TraceFILE;
  yyTracePrompt = zTracePrompt;
  if( yyTraceFILE==0 ) yyTracePrompt = 0;
  else if( yyTracePrompt==0 ) yyTraceFILE = 0;
}
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing shifts, the names of all terminals and nonterminals
** are required.  The following table supplies these names */
static const char *const yyTokenName[] = {
  "$",             "ILLEGAL",       "COMMENT",       "SPACE",       
  "ID",            "ABORT",         "ACTION",        "AFTER",       
  "ANALYZE",       "ASC",           "ATTACH",        "BEFORE",      
  "BEGIN",         "BY",            "CASCADE",       "CAST",        
  "COLUMNKW",      "CONFLICT",      "DATABASE",      "DEFERRED",    
  "DESC",          "DETACH",        "EACH",          "END",         
  "EXCLUSIVE",     "EXPLAIN",       "FAIL",          "FOR",         
  "IGNORE",        "IMMEDIATE",     "INDEXED",       "INITIALLY",   
  "INSTEAD",       "LIKE_KW",       "MATCH",         "NO",          
  "PLAN",          "QUERY",         "KEY",           "OF",          
  "OFFSET",        "PRAGMA",        "RAISE",         "RECURSIVE",   
  "RELEASE",       "REPLACE",       "RESTRICT",      "ROW",         
  "ROLLBACK",      "SAVEPOINT",     "TEMP",          "TRIGGER",     
  "VACUUM",        "VIEW",          "VIRTUAL",       "WITH",        
  "WITHOUT",       "REINDEX",       "RENAME",        "CTIME_KW",    
  "IF",            "ANY",           "OR",            "AND",         
  "NOT",           "IS",            "BETWEEN",       "IN",          
  "ISNULL",        "NOTNULL",       "NE",            "EQ",          
  "GT",            "LE",            "LT",            "GE",          
  "ESCAPE",        "BITAND",        "BITOR",         "LSHIFT",      
  "RSHIFT",        "PLUS",          "MINUS",         "STAR",        
  "SLASH",         "REM",           "CONCAT",        "COLLATE",     
  "BITNOT",        "SEMI",          "TRANSACTION",   "ID_TRANS",    
  "COMMIT",        "TO",            "CREATE",        "TABLE",       
  "LP",            "RP",            "AS",            "DOT",         
  "ID_TAB_NEW",    "ID_DB",         "CTX_ROWID_KW",  "EXISTS",      
  "COMMA",         "ID_COL_NEW",    "STRING",        "JOIN_KW",     
  "ID_COL_TYPE",   "CONSTRAINT",    "DEFAULT",       "NULL",        
  "PRIMARY",       "UNIQUE",        "CHECK",         "REFERENCES",  
  "ID_CONSTR",     "ID_COLLATE",    "ID_TAB",        "INTEGER",     
  "FLOAT",         "BLOB",          "AUTOINCR",      "ON",          
  "INSERT",        "DELETE",        "UPDATE",        "ID_FK_MATCH", 
  "SET",           "DEFERRABLE",    "FOREIGN",       "DROP",        
  "ID_VIEW_NEW",   "ID_VIEW",       "UNION",         "ALL",         
  "EXCEPT",        "INTERSECT",     "SELECT",        "VALUES",      
  "DISTINCT",      "ID_ALIAS",      "FROM",          "USING",       
  "JOIN",          "ID_JOIN_OPTS",  "ID_IDX",        "ORDER",       
  "GROUP",         "HAVING",        "LIMIT",         "WHERE",       
  "ID_COL",        "INTO",          "CASE",          "ID_FN",       
  "ID_ERR_MSG",    "VARIABLE",      "WHEN",          "THEN",        
  "ELSE",          "INDEX",         "ID_IDX_NEW",    "ID_PRAGMA",   
  "ID_TRIG_NEW",   "ID_TRIG",       "ALTER",         "ADD",         
  "error",         "cmd",           "input",         "cmdlist",     
  "ecmd",          "explain",       "cmdx",          "transtype",   
  "trans_opt",     "nm",            "savepoint_opt",  "temp",        
  "ifnotexists",   "fullname",      "columnlist",    "conslist_opt",
  "table_options",  "select",        "column",        "columnid",    
  "type",          "carglist",      "id",            "ids",         
  "typetoken",     "typename",      "signed",        "plus_num",    
  "minus_num",     "ccons",         "term",          "expr",        
  "onconf",        "sortorder",     "autoinc",       "idxlist_opt", 
  "refargs",       "defer_subclause",  "refarg",        "refact",      
  "init_deferred_pred_opt",  "conslist",      "tconscomma",    "tcons",       
  "idxlist",       "defer_subclause_opt",  "resolvetype",   "orconf",      
  "raisetype",     "ifexists",      "select_stmt",   "with",        
  "selectnowith",  "oneselect",     "multiselect_op",  "values",      
  "distinct",      "selcollist",    "from",          "where_opt",   
  "groupby_opt",   "having_opt",    "orderby_opt",   "limit_opt",   
  "nexprlist",     "exprlist",      "sclp",          "as",          
  "joinsrc",       "singlesrc",     "seltablist",    "joinop",      
  "joinconstr_opt",  "dbnm",          "indexed_opt",   "inscollist",  
  "sortlist",      "delete_stmt",   "update_stmt",   "setlist",     
  "insert_stmt",   "insert_cmd",    "inscollist_opt",  "exprx",       
  "not_opt",       "case_operand",  "case_exprlist",  "case_else",   
  "likeop",        "uniqueflag",    "idxlist_single",  "collate",     
  "nmnum",         "number",        "trigger_time",  "trigger_event",
  "foreach_clause",  "when_clause",   "trigger_cmd_list",  "trigger_cmd", 
  "database_kw_opt",  "key_opt",       "kwcolumn_opt",  "create_vtab", 
  "vtabarglist",   "vtabarg",       "vtabargtoken",  "anylist",     
  "wqlist",      
};
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing reduce actions, the names of all rules are required.
*/
static const char *const yyRuleName[] = {
 /*   0 */ "input ::= cmdlist",
 /*   1 */ "cmdlist ::= cmdlist ecmd",
 /*   2 */ "cmdlist ::= ecmd",
 /*   3 */ "ecmd ::= SEMI",
 /*   4 */ "ecmd ::= explain cmdx SEMI",
 /*   5 */ "explain ::=",
 /*   6 */ "explain ::= EXPLAIN",
 /*   7 */ "explain ::= EXPLAIN QUERY PLAN",
 /*   8 */ "cmdx ::= cmd",
 /*   9 */ "cmd ::= BEGIN transtype trans_opt",
 /*  10 */ "trans_opt ::=",
 /*  11 */ "trans_opt ::= TRANSACTION",
 /*  12 */ "trans_opt ::= TRANSACTION nm",
 /*  13 */ "trans_opt ::= TRANSACTION ID_TRANS",
 /*  14 */ "transtype ::=",
 /*  15 */ "transtype ::= DEFERRED",
 /*  16 */ "transtype ::= IMMEDIATE",
 /*  17 */ "transtype ::= EXCLUSIVE",
 /*  18 */ "cmd ::= COMMIT trans_opt",
 /*  19 */ "cmd ::= END trans_opt",
 /*  20 */ "cmd ::= ROLLBACK trans_opt",
 /*  21 */ "savepoint_opt ::= SAVEPOINT",
 /*  22 */ "savepoint_opt ::=",
 /*  23 */ "cmd ::= SAVEPOINT nm",
 /*  24 */ "cmd ::= RELEASE savepoint_opt nm",
 /*  25 */ "cmd ::= ROLLBACK trans_opt TO savepoint_opt nm",
 /*  26 */ "cmd ::= SAVEPOINT ID_TRANS",
 /*  27 */ "cmd ::= RELEASE savepoint_opt ID_TRANS",
 /*  28 */ "cmd ::= ROLLBACK trans_opt TO savepoint_opt ID_TRANS",
 /*  29 */ "cmd ::= CREATE temp TABLE ifnotexists fullname LP columnlist conslist_opt RP table_options",
 /*  30 */ "cmd ::= CREATE temp TABLE ifnotexists fullname AS select",
 /*  31 */ "cmd ::= CREATE temp TABLE ifnotexists nm DOT ID_TAB_NEW",
 /*  32 */ "cmd ::= CREATE temp TABLE ifnotexists ID_DB|ID_TAB_NEW",
 /*  33 */ "table_options ::=",
 /*  34 */ "table_options ::= WITHOUT nm",
 /*  35 */ "table_options ::= WITHOUT CTX_ROWID_KW",
 /*  36 */ "ifnotexists ::=",
 /*  37 */ "ifnotexists ::= IF NOT EXISTS",
 /*  38 */ "temp ::= TEMP",
 /*  39 */ "temp ::=",
 /*  40 */ "columnlist ::= columnlist COMMA column",
 /*  41 */ "columnlist ::= column",
 /*  42 */ "column ::= columnid type carglist",
 /*  43 */ "columnid ::= nm",
 /*  44 */ "columnid ::= ID_COL_NEW",
 /*  45 */ "id ::= ID",
 /*  46 */ "ids ::= ID|STRING",
 /*  47 */ "nm ::= id",
 /*  48 */ "nm ::= STRING",
 /*  49 */ "nm ::= JOIN_KW",
 /*  50 */ "type ::=",
 /*  51 */ "type ::= typetoken",
 /*  52 */ "typetoken ::= typename",
 /*  53 */ "typetoken ::= typename LP signed RP",
 /*  54 */ "typetoken ::= typename LP signed COMMA signed RP",
 /*  55 */ "typename ::= ids",
 /*  56 */ "typename ::= typename ids",
 /*  57 */ "typename ::= ID_COL_TYPE",
 /*  58 */ "signed ::= plus_num",
 /*  59 */ "signed ::= minus_num",
 /*  60 */ "carglist ::= carglist ccons",
 /*  61 */ "carglist ::=",
 /*  62 */ "ccons ::= CONSTRAINT nm",
 /*  63 */ "ccons ::= DEFAULT term",
 /*  64 */ "ccons ::= DEFAULT LP expr RP",
 /*  65 */ "ccons ::= DEFAULT PLUS term",
 /*  66 */ "ccons ::= DEFAULT MINUS term",
 /*  67 */ "ccons ::= DEFAULT id",
 /*  68 */ "ccons ::= DEFAULT CTIME_KW",
 /*  69 */ "ccons ::= NULL onconf",
 /*  70 */ "ccons ::= NOT NULL onconf",
 /*  71 */ "ccons ::= PRIMARY KEY sortorder onconf autoinc",
 /*  72 */ "ccons ::= UNIQUE onconf",
 /*  73 */ "ccons ::= CHECK LP expr RP",
 /*  74 */ "ccons ::= REFERENCES nm idxlist_opt refargs",
 /*  75 */ "ccons ::= defer_subclause",
 /*  76 */ "ccons ::= COLLATE ids",
 /*  77 */ "ccons ::= CONSTRAINT ID_CONSTR",
 /*  78 */ "ccons ::= COLLATE ID_COLLATE",
 /*  79 */ "ccons ::= REFERENCES ID_TAB",
 /*  80 */ "ccons ::= CHECK LP RP",
 /*  81 */ "term ::= NULL",
 /*  82 */ "term ::= INTEGER",
 /*  83 */ "term ::= FLOAT",
 /*  84 */ "term ::= STRING|BLOB",
 /*  85 */ "autoinc ::=",
 /*  86 */ "autoinc ::= AUTOINCR",
 /*  87 */ "refargs ::=",
 /*  88 */ "refargs ::= refargs refarg",
 /*  89 */ "refarg ::= MATCH nm",
 /*  90 */ "refarg ::= ON INSERT refact",
 /*  91 */ "refarg ::= ON DELETE refact",
 /*  92 */ "refarg ::= ON UPDATE refact",
 /*  93 */ "refarg ::= MATCH ID_FK_MATCH",
 /*  94 */ "refact ::= SET NULL",
 /*  95 */ "refact ::= SET DEFAULT",
 /*  96 */ "refact ::= CASCADE",
 /*  97 */ "refact ::= RESTRICT",
 /*  98 */ "refact ::= NO ACTION",
 /*  99 */ "defer_subclause ::= NOT DEFERRABLE init_deferred_pred_opt",
 /* 100 */ "defer_subclause ::= DEFERRABLE init_deferred_pred_opt",
 /* 101 */ "init_deferred_pred_opt ::=",
 /* 102 */ "init_deferred_pred_opt ::= INITIALLY DEFERRED",
 /* 103 */ "init_deferred_pred_opt ::= INITIALLY IMMEDIATE",
 /* 104 */ "conslist_opt ::=",
 /* 105 */ "conslist_opt ::= COMMA conslist",
 /* 106 */ "conslist ::= conslist tconscomma tcons",
 /* 107 */ "conslist ::= tcons",
 /* 108 */ "tconscomma ::= COMMA",
 /* 109 */ "tconscomma ::=",
 /* 110 */ "tcons ::= CONSTRAINT nm",
 /* 111 */ "tcons ::= PRIMARY KEY LP idxlist autoinc RP onconf",
 /* 112 */ "tcons ::= UNIQUE LP idxlist RP onconf",
 /* 113 */ "tcons ::= CHECK LP expr RP onconf",
 /* 114 */ "tcons ::= FOREIGN KEY LP idxlist RP REFERENCES nm idxlist_opt refargs defer_subclause_opt",
 /* 115 */ "tcons ::= CONSTRAINT ID_CONSTR",
 /* 116 */ "tcons ::= FOREIGN KEY LP idxlist RP REFERENCES ID_TAB",
 /* 117 */ "tcons ::= CHECK LP RP onconf",
 /* 118 */ "defer_subclause_opt ::=",
 /* 119 */ "defer_subclause_opt ::= defer_subclause",
 /* 120 */ "onconf ::=",
 /* 121 */ "onconf ::= ON CONFLICT resolvetype",
 /* 122 */ "orconf ::=",
 /* 123 */ "orconf ::= OR resolvetype",
 /* 124 */ "resolvetype ::= raisetype",
 /* 125 */ "resolvetype ::= IGNORE",
 /* 126 */ "resolvetype ::= REPLACE",
 /* 127 */ "cmd ::= DROP TABLE ifexists fullname",
 /* 128 */ "cmd ::= DROP TABLE ifexists nm DOT ID_TAB",
 /* 129 */ "cmd ::= DROP TABLE ifexists ID_DB|ID_TAB",
 /* 130 */ "ifexists ::= IF EXISTS",
 /* 131 */ "ifexists ::=",
 /* 132 */ "cmd ::= CREATE temp VIEW ifnotexists fullname idxlist_opt AS select",
 /* 133 */ "cmd ::= CREATE temp VIEW ifnotexists nm DOT ID_VIEW_NEW",
 /* 134 */ "cmd ::= CREATE temp VIEW ifnotexists ID_DB|ID_VIEW_NEW",
 /* 135 */ "cmd ::= DROP VIEW ifexists fullname",
 /* 136 */ "cmd ::= DROP VIEW ifexists nm DOT ID_VIEW",
 /* 137 */ "cmd ::= DROP VIEW ifexists ID_DB|ID_VIEW",
 /* 138 */ "cmd ::= select_stmt",
 /* 139 */ "select_stmt ::= select",
 /* 140 */ "select ::= with selectnowith",
 /* 141 */ "selectnowith ::= oneselect",
 /* 142 */ "selectnowith ::= selectnowith multiselect_op oneselect",
 /* 143 */ "selectnowith ::= values",
 /* 144 */ "selectnowith ::= selectnowith COMMA values",
 /* 145 */ "multiselect_op ::= UNION",
 /* 146 */ "multiselect_op ::= UNION ALL",
 /* 147 */ "multiselect_op ::= EXCEPT",
 /* 148 */ "multiselect_op ::= INTERSECT",
 /* 149 */ "oneselect ::= SELECT distinct selcollist from where_opt groupby_opt having_opt orderby_opt limit_opt",
 /* 150 */ "values ::= VALUES LP nexprlist RP",
 /* 151 */ "values ::= values COMMA LP exprlist RP",
 /* 152 */ "distinct ::= DISTINCT",
 /* 153 */ "distinct ::= ALL",
 /* 154 */ "distinct ::=",
 /* 155 */ "sclp ::= selcollist COMMA",
 /* 156 */ "sclp ::=",
 /* 157 */ "selcollist ::= sclp expr as",
 /* 158 */ "selcollist ::= sclp STAR",
 /* 159 */ "selcollist ::= sclp nm DOT STAR",
 /* 160 */ "selcollist ::= sclp",
 /* 161 */ "selcollist ::= sclp ID_TAB DOT STAR",
 /* 162 */ "as ::= AS nm",
 /* 163 */ "as ::= ids",
 /* 164 */ "as ::= AS ID_ALIAS",
 /* 165 */ "as ::= ID_ALIAS",
 /* 166 */ "as ::=",
 /* 167 */ "from ::=",
 /* 168 */ "from ::= FROM joinsrc",
 /* 169 */ "joinsrc ::= singlesrc seltablist",
 /* 170 */ "joinsrc ::=",
 /* 171 */ "seltablist ::= seltablist joinop singlesrc joinconstr_opt",
 /* 172 */ "seltablist ::=",
 /* 173 */ "singlesrc ::= nm dbnm as indexed_opt",
 /* 174 */ "singlesrc ::= LP select RP as",
 /* 175 */ "singlesrc ::= LP joinsrc RP as",
 /* 176 */ "singlesrc ::=",
 /* 177 */ "singlesrc ::= nm DOT",
 /* 178 */ "singlesrc ::= nm DOT ID_TAB",
 /* 179 */ "singlesrc ::= ID_DB|ID_TAB",
 /* 180 */ "singlesrc ::= nm DOT ID_VIEW",
 /* 181 */ "singlesrc ::= ID_DB|ID_VIEW",
 /* 182 */ "joinconstr_opt ::= ON expr",
 /* 183 */ "joinconstr_opt ::= USING LP inscollist RP",
 /* 184 */ "joinconstr_opt ::=",
 /* 185 */ "dbnm ::=",
 /* 186 */ "dbnm ::= DOT nm",
 /* 187 */ "fullname ::= nm dbnm",
 /* 188 */ "joinop ::= COMMA",
 /* 189 */ "joinop ::= JOIN",
 /* 190 */ "joinop ::= JOIN_KW JOIN",
 /* 191 */ "joinop ::= JOIN_KW nm JOIN",
 /* 192 */ "joinop ::= JOIN_KW nm nm JOIN",
 /* 193 */ "joinop ::= ID_JOIN_OPTS",
 /* 194 */ "indexed_opt ::=",
 /* 195 */ "indexed_opt ::= INDEXED BY nm",
 /* 196 */ "indexed_opt ::= NOT INDEXED",
 /* 197 */ "indexed_opt ::= INDEXED BY ID_IDX",
 /* 198 */ "orderby_opt ::=",
 /* 199 */ "orderby_opt ::= ORDER BY sortlist",
 /* 200 */ "sortlist ::= sortlist COMMA expr sortorder",
 /* 201 */ "sortlist ::= expr sortorder",
 /* 202 */ "sortorder ::= ASC",
 /* 203 */ "sortorder ::= DESC",
 /* 204 */ "sortorder ::=",
 /* 205 */ "groupby_opt ::=",
 /* 206 */ "groupby_opt ::= GROUP BY nexprlist",
 /* 207 */ "groupby_opt ::= GROUP BY",
 /* 208 */ "having_opt ::=",
 /* 209 */ "having_opt ::= HAVING expr",
 /* 210 */ "limit_opt ::=",
 /* 211 */ "limit_opt ::= LIMIT expr",
 /* 212 */ "limit_opt ::= LIMIT expr OFFSET expr",
 /* 213 */ "limit_opt ::= LIMIT expr COMMA expr",
 /* 214 */ "cmd ::= delete_stmt",
 /* 215 */ "delete_stmt ::= with DELETE FROM fullname indexed_opt where_opt",
 /* 216 */ "delete_stmt ::= with DELETE FROM",
 /* 217 */ "delete_stmt ::= with DELETE FROM nm DOT",
 /* 218 */ "delete_stmt ::= with DELETE FROM nm DOT ID_TAB",
 /* 219 */ "delete_stmt ::= with DELETE FROM ID_DB|ID_TAB",
 /* 220 */ "where_opt ::=",
 /* 221 */ "where_opt ::= WHERE expr",
 /* 222 */ "where_opt ::= WHERE",
 /* 223 */ "cmd ::= update_stmt",
 /* 224 */ "update_stmt ::= with UPDATE orconf fullname indexed_opt SET setlist where_opt",
 /* 225 */ "update_stmt ::= with UPDATE orconf",
 /* 226 */ "update_stmt ::= with UPDATE orconf nm DOT",
 /* 227 */ "update_stmt ::= with UPDATE orconf nm DOT ID_TAB",
 /* 228 */ "update_stmt ::= with UPDATE orconf ID_DB|ID_TAB",
 /* 229 */ "setlist ::= setlist COMMA nm EQ expr",
 /* 230 */ "setlist ::= nm EQ expr",
 /* 231 */ "setlist ::=",
 /* 232 */ "setlist ::= setlist COMMA",
 /* 233 */ "setlist ::= setlist COMMA ID_COL",
 /* 234 */ "setlist ::= ID_COL",
 /* 235 */ "cmd ::= insert_stmt",
 /* 236 */ "insert_stmt ::= with insert_cmd INTO fullname inscollist_opt select",
 /* 237 */ "insert_stmt ::= with insert_cmd INTO fullname inscollist_opt DEFAULT VALUES",
 /* 238 */ "insert_stmt ::= with insert_cmd INTO",
 /* 239 */ "insert_stmt ::= with insert_cmd INTO nm DOT",
 /* 240 */ "insert_stmt ::= with insert_cmd INTO ID_DB|ID_TAB",
 /* 241 */ "insert_stmt ::= with insert_cmd INTO nm DOT ID_TAB",
 /* 242 */ "insert_cmd ::= INSERT orconf",
 /* 243 */ "insert_cmd ::= REPLACE",
 /* 244 */ "inscollist_opt ::=",
 /* 245 */ "inscollist_opt ::= LP inscollist RP",
 /* 246 */ "inscollist ::= inscollist COMMA nm",
 /* 247 */ "inscollist ::= nm",
 /* 248 */ "inscollist ::=",
 /* 249 */ "inscollist ::= inscollist COMMA ID_COL",
 /* 250 */ "inscollist ::= ID_COL",
 /* 251 */ "exprx ::= nm DOT",
 /* 252 */ "exprx ::= nm DOT nm DOT",
 /* 253 */ "exprx ::= expr not_opt BETWEEN expr AND",
 /* 254 */ "exprx ::= CASE case_operand case_exprlist case_else",
 /* 255 */ "exprx ::= expr not_opt IN LP exprlist",
 /* 256 */ "exprx ::= expr not_opt IN ID_DB",
 /* 257 */ "exprx ::= expr not_opt IN nm DOT ID_TAB",
 /* 258 */ "exprx ::= ID_DB|ID_TAB|ID_COL|ID_FN",
 /* 259 */ "exprx ::= nm DOT ID_TAB|ID_COL",
 /* 260 */ "exprx ::= nm DOT nm DOT ID_COL",
 /* 261 */ "exprx ::= expr COLLATE ID_COLLATE",
 /* 262 */ "exprx ::= RAISE LP raisetype COMMA ID_ERR_MSG RP",
 /* 263 */ "exprx ::= term",
 /* 264 */ "exprx ::= CTIME_KW",
 /* 265 */ "exprx ::= LP nexprlist RP",
 /* 266 */ "exprx ::= id",
 /* 267 */ "exprx ::= JOIN_KW",
 /* 268 */ "exprx ::= nm DOT nm",
 /* 269 */ "exprx ::= nm DOT nm DOT nm",
 /* 270 */ "exprx ::= VARIABLE",
 /* 271 */ "exprx ::= expr COLLATE ids",
 /* 272 */ "exprx ::= CAST LP expr AS typetoken RP",
 /* 273 */ "exprx ::= ID LP distinct exprlist RP",
 /* 274 */ "exprx ::= ID LP STAR RP",
 /* 275 */ "exprx ::= expr AND expr",
 /* 276 */ "exprx ::= expr OR expr",
 /* 277 */ "exprx ::= expr LT|GT|GE|LE expr",
 /* 278 */ "exprx ::= expr EQ|NE expr",
 /* 279 */ "exprx ::= expr BITAND|BITOR|LSHIFT|RSHIFT expr",
 /* 280 */ "exprx ::= expr PLUS|MINUS expr",
 /* 281 */ "exprx ::= expr STAR|SLASH|REM expr",
 /* 282 */ "exprx ::= expr CONCAT expr",
 /* 283 */ "exprx ::= expr not_opt likeop expr",
 /* 284 */ "exprx ::= expr not_opt likeop expr ESCAPE expr",
 /* 285 */ "exprx ::= expr ISNULL|NOTNULL",
 /* 286 */ "exprx ::= expr NOT NULL",
 /* 287 */ "exprx ::= expr IS not_opt expr",
 /* 288 */ "exprx ::= NOT expr",
 /* 289 */ "exprx ::= BITNOT expr",
 /* 290 */ "exprx ::= MINUS expr",
 /* 291 */ "exprx ::= PLUS expr",
 /* 292 */ "exprx ::= expr not_opt BETWEEN expr AND expr",
 /* 293 */ "exprx ::= expr not_opt IN LP exprlist RP",
 /* 294 */ "exprx ::= LP select RP",
 /* 295 */ "exprx ::= expr not_opt IN LP select RP",
 /* 296 */ "exprx ::= expr not_opt IN nm dbnm",
 /* 297 */ "exprx ::= EXISTS LP select RP",
 /* 298 */ "exprx ::= CASE case_operand case_exprlist case_else END",
 /* 299 */ "exprx ::= RAISE LP IGNORE RP",
 /* 300 */ "exprx ::= RAISE LP raisetype COMMA nm RP",
 /* 301 */ "expr ::=",
 /* 302 */ "expr ::= exprx",
 /* 303 */ "not_opt ::=",
 /* 304 */ "not_opt ::= NOT",
 /* 305 */ "likeop ::= LIKE_KW|MATCH",
 /* 306 */ "case_exprlist ::= case_exprlist WHEN expr THEN expr",
 /* 307 */ "case_exprlist ::= WHEN expr THEN expr",
 /* 308 */ "case_else ::= ELSE expr",
 /* 309 */ "case_else ::=",
 /* 310 */ "case_operand ::= exprx",
 /* 311 */ "case_operand ::=",
 /* 312 */ "exprlist ::= nexprlist",
 /* 313 */ "exprlist ::=",
 /* 314 */ "nexprlist ::= nexprlist COMMA expr",
 /* 315 */ "nexprlist ::= exprx",
 /* 316 */ "cmd ::= CREATE uniqueflag INDEX ifnotexists nm dbnm ON nm LP sortlist RP where_opt",
 /* 317 */ "cmd ::= CREATE uniqueflag INDEX ifnotexists nm dbnm ON ID_TAB",
 /* 318 */ "cmd ::= CREATE uniqueflag INDEX ifnotexists nm DOT ID_IDX_NEW",
 /* 319 */ "cmd ::= CREATE uniqueflag INDEX ifnotexists ID_DB|ID_IDX_NEW",
 /* 320 */ "uniqueflag ::= UNIQUE",
 /* 321 */ "uniqueflag ::=",
 /* 322 */ "idxlist_opt ::=",
 /* 323 */ "idxlist_opt ::= LP idxlist RP",
 /* 324 */ "idxlist ::= idxlist COMMA idxlist_single",
 /* 325 */ "idxlist ::= idxlist_single",
 /* 326 */ "idxlist_single ::= nm collate sortorder",
 /* 327 */ "idxlist_single ::= ID_COL",
 /* 328 */ "collate ::=",
 /* 329 */ "collate ::= COLLATE ids",
 /* 330 */ "collate ::= COLLATE ID_COLLATE",
 /* 331 */ "cmd ::= DROP INDEX ifexists fullname",
 /* 332 */ "cmd ::= DROP INDEX ifexists nm DOT ID_IDX",
 /* 333 */ "cmd ::= DROP INDEX ifexists ID_DB|ID_IDX",
 /* 334 */ "cmd ::= VACUUM",
 /* 335 */ "cmd ::= VACUUM nm",
 /* 336 */ "cmd ::= PRAGMA nm dbnm",
 /* 337 */ "cmd ::= PRAGMA nm dbnm EQ nmnum",
 /* 338 */ "cmd ::= PRAGMA nm dbnm LP nmnum RP",
 /* 339 */ "cmd ::= PRAGMA nm dbnm EQ minus_num",
 /* 340 */ "cmd ::= PRAGMA nm dbnm LP minus_num RP",
 /* 341 */ "cmd ::= PRAGMA nm DOT ID_PRAGMA",
 /* 342 */ "cmd ::= PRAGMA ID_DB|ID_PRAGMA",
 /* 343 */ "nmnum ::= plus_num",
 /* 344 */ "nmnum ::= nm",
 /* 345 */ "nmnum ::= ON",
 /* 346 */ "nmnum ::= DELETE",
 /* 347 */ "nmnum ::= DEFAULT",
 /* 348 */ "plus_num ::= PLUS number",
 /* 349 */ "plus_num ::= number",
 /* 350 */ "minus_num ::= MINUS number",
 /* 351 */ "number ::= INTEGER",
 /* 352 */ "number ::= FLOAT",
 /* 353 */ "cmd ::= CREATE temp TRIGGER ifnotexists nm dbnm trigger_time trigger_event ON nm foreach_clause when_clause BEGIN trigger_cmd_list END",
 /* 354 */ "cmd ::= CREATE temp TRIGGER ifnotexists nm dbnm trigger_time trigger_event ON nm foreach_clause when_clause",
 /* 355 */ "cmd ::= CREATE temp TRIGGER ifnotexists nm dbnm trigger_time trigger_event ON nm foreach_clause when_clause BEGIN trigger_cmd_list",
 /* 356 */ "cmd ::= CREATE temp TRIGGER ifnotexists nm dbnm trigger_time trigger_event ON ID_TAB",
 /* 357 */ "cmd ::= CREATE temp TRIGGER ifnotexists nm DOT ID_TRIG_NEW",
 /* 358 */ "cmd ::= CREATE temp TRIGGER ifnotexists ID_DB|ID_TRIG_NEW",
 /* 359 */ "trigger_time ::= BEFORE",
 /* 360 */ "trigger_time ::= AFTER",
 /* 361 */ "trigger_time ::= INSTEAD OF",
 /* 362 */ "trigger_time ::=",
 /* 363 */ "trigger_event ::= DELETE",
 /* 364 */ "trigger_event ::= INSERT",
 /* 365 */ "trigger_event ::= UPDATE",
 /* 366 */ "trigger_event ::= UPDATE OF inscollist",
 /* 367 */ "foreach_clause ::=",
 /* 368 */ "foreach_clause ::= FOR EACH ROW",
 /* 369 */ "when_clause ::=",
 /* 370 */ "when_clause ::= WHEN expr",
 /* 371 */ "trigger_cmd_list ::= trigger_cmd_list trigger_cmd SEMI",
 /* 372 */ "trigger_cmd_list ::= trigger_cmd SEMI",
 /* 373 */ "trigger_cmd_list ::= SEMI",
 /* 374 */ "trigger_cmd ::= update_stmt",
 /* 375 */ "trigger_cmd ::= insert_stmt",
 /* 376 */ "trigger_cmd ::= delete_stmt",
 /* 377 */ "trigger_cmd ::= select_stmt",
 /* 378 */ "raisetype ::= ROLLBACK|ABORT|FAIL",
 /* 379 */ "cmd ::= DROP TRIGGER ifexists fullname",
 /* 380 */ "cmd ::= DROP TRIGGER ifexists nm DOT ID_TRIG",
 /* 381 */ "cmd ::= DROP TRIGGER ifexists ID_DB|ID_TRIG",
 /* 382 */ "cmd ::= ATTACH database_kw_opt expr AS expr key_opt",
 /* 383 */ "cmd ::= DETACH database_kw_opt expr",
 /* 384 */ "key_opt ::=",
 /* 385 */ "key_opt ::= KEY expr",
 /* 386 */ "database_kw_opt ::= DATABASE",
 /* 387 */ "database_kw_opt ::=",
 /* 388 */ "cmd ::= REINDEX",
 /* 389 */ "cmd ::= REINDEX nm dbnm",
 /* 390 */ "cmd ::= REINDEX ID_COLLATE",
 /* 391 */ "cmd ::= REINDEX nm DOT ID_TAB|ID_IDX",
 /* 392 */ "cmd ::= REINDEX ID_DB|ID_IDX|ID_TAB",
 /* 393 */ "cmd ::= ANALYZE",
 /* 394 */ "cmd ::= ANALYZE nm dbnm",
 /* 395 */ "cmd ::= ANALYZE nm DOT ID_TAB|ID_IDX",
 /* 396 */ "cmd ::= ANALYZE ID_DB|ID_IDX|ID_TAB",
 /* 397 */ "cmd ::= ALTER TABLE fullname RENAME TO nm",
 /* 398 */ "cmd ::= ALTER TABLE fullname ADD kwcolumn_opt column",
 /* 399 */ "cmd ::= ALTER TABLE fullname RENAME TO ID_TAB_NEW",
 /* 400 */ "cmd ::= ALTER TABLE nm DOT ID_TAB",
 /* 401 */ "cmd ::= ALTER TABLE ID_DB|ID_TAB",
 /* 402 */ "kwcolumn_opt ::=",
 /* 403 */ "kwcolumn_opt ::= COLUMNKW",
 /* 404 */ "cmd ::= create_vtab",
 /* 405 */ "create_vtab ::= CREATE VIRTUAL TABLE ifnotexists nm dbnm USING nm",
 /* 406 */ "create_vtab ::= CREATE VIRTUAL TABLE ifnotexists nm dbnm USING nm LP vtabarglist RP",
 /* 407 */ "create_vtab ::= CREATE VIRTUAL TABLE ifnotexists nm DOT ID_TAB_NEW",
 /* 408 */ "create_vtab ::= CREATE VIRTUAL TABLE ifnotexists ID_DB|ID_TAB_NEW",
 /* 409 */ "vtabarglist ::= vtabarg",
 /* 410 */ "vtabarglist ::= vtabarglist COMMA vtabarg",
 /* 411 */ "vtabarg ::=",
 /* 412 */ "vtabarg ::= vtabarg vtabargtoken",
 /* 413 */ "vtabargtoken ::= ANY",
 /* 414 */ "vtabargtoken ::= LP anylist RP",
 /* 415 */ "anylist ::=",
 /* 416 */ "anylist ::= anylist LP anylist RP",
 /* 417 */ "anylist ::= anylist ANY",
 /* 418 */ "with ::=",
 /* 419 */ "with ::= WITH wqlist",
 /* 420 */ "with ::= WITH RECURSIVE wqlist",
 /* 421 */ "wqlist ::= nm idxlist_opt AS LP select RP",
 /* 422 */ "wqlist ::= wqlist COMMA nm idxlist_opt AS LP select RP",
 /* 423 */ "wqlist ::= ID_TAB_NEW",
};
#endif /* NDEBUG */


#if YYSTACKDEPTH<=0
/*
** Try to increase the size of the parser stack.
*/
static void yyGrowStack(yyParser *p){
  int newSize;
  yyStackEntry *pNew;

  newSize = p->yystksz*2 + 100;
  pNew = realloc(p->yystack, newSize*sizeof(pNew[0]));
  if( pNew ){
    p->yystack = pNew;
    p->yystksz = newSize;
#ifndef NDEBUG
    if( yyTraceFILE ){
      fprintf(yyTraceFILE,"%sStack grows to %d entries!\n",
              yyTracePrompt, p->yystksz);
    }
#endif
  }
}
#endif

/*
** This function allocates a new parser.
** The only argument is a pointer to a function which works like
** malloc.
**
** Inputs:
** A pointer to the function used to allocate memory.
**
** Outputs:
** A pointer to a parser.  This pointer is used in subsequent calls
** to sqlite3_parse and sqlite3_parseFree.
*/
void *sqlite3_parseAlloc(void *(*mallocProc)(size_t)){
  yyParser *pParser;
  pParser = (yyParser*)(*mallocProc)( (size_t)sizeof(yyParser) );
  if( pParser ){
    pParser->yyidx = -1;
#ifdef YYTRACKMAXSTACKDEPTH
    pParser->yyidxMax = 0;
#endif
#if YYSTACKDEPTH<=0
    pParser->yystack = NULL;
    pParser->yystksz = 0;
    yyGrowStack(pParser);
#endif
  }
  return pParser;
}

/* The following function deletes the value associated with a
** symbol.  The symbol can be either a terminal or nonterminal.
** "yymajor" is the symbol code, and "yypminor" is a pointer to
** the value.
*/
static void yy_destructor(
  yyParser *yypParser,    /* The parser */
  YYCODETYPE yymajor,     /* Type code for object to destroy */
  YYMINORTYPE *yypminor   /* The object to be destroyed */
){
  sqlite3_parseARG_FETCH;
  if (parserContext->executeRules)
  {
      switch( yymajor ){
        /* Here is inserted the actions which take place when a
        ** terminal or non-terminal is destroyed.  This can happen
        ** when the symbol is popped from the stack during a
        ** reduce or during error processing or when a parser is
        ** being destroyed before it is finished parsing.
        **
        ** Note: during a reduce, the only symbols destroyed are those
        ** which appear on the RHS of the rule, but which are not used
        ** inside the C code.
        */
    case 169: /* cmd */
    case 172: /* ecmd */
    case 174: /* cmdx */
    case 218: /* select_stmt */
    case 245: /* delete_stmt */
    case 246: /* update_stmt */
    case 248: /* insert_stmt */
    case 267: /* trigger_cmd */
    case 271: /* create_vtab */
{
delete (yypminor->yy399);
}
      break;
    case 173: /* explain */
{
delete (yypminor->yy225);
}
      break;
    case 175: /* transtype */
    case 176: /* trans_opt */
{
delete (yypminor->yy300);
}
      break;
    case 177: /* nm */
    case 184: /* table_options */
    case 187: /* columnid */
    case 190: /* id */
    case 191: /* ids */
    case 193: /* typename */
    case 241: /* dbnm */
    case 259: /* collate */
    case 273: /* vtabarg */
    case 274: /* vtabargtoken */
    case 275: /* anylist */
{
delete (yypminor->yy211);
}
      break;
    case 178: /* savepoint_opt */
    case 180: /* ifnotexists */
    case 202: /* autoinc */
    case 210: /* tconscomma */
    case 217: /* ifexists */
    case 252: /* not_opt */
    case 257: /* uniqueflag */
    case 268: /* database_kw_opt */
    case 270: /* kwcolumn_opt */
{
delete (yypminor->yy237);
}
      break;
    case 179: /* temp */
    case 224: /* distinct */
{
delete (yypminor->yy376);
}
      break;
    case 181: /* fullname */
{
delete (yypminor->yy66);
}
      break;
    case 182: /* columnlist */
{
delete (yypminor->yy118);
}
      break;
    case 183: /* conslist_opt */
    case 209: /* conslist */
{
delete (yypminor->yy87);
}
      break;
    case 185: /* select */
    case 220: /* selectnowith */
{
delete (yypminor->yy123);
}
      break;
    case 186: /* column */
{
delete (yypminor->yy425);
}
      break;
    case 188: /* type */
    case 192: /* typetoken */
{
delete (yypminor->yy299);
}
      break;
    case 189: /* carglist */
{
delete (yypminor->yy449);
}
      break;
    case 194: /* signed */
    case 195: /* plus_num */
    case 196: /* minus_num */
    case 198: /* term */
    case 260: /* nmnum */
    case 261: /* number */
{
delete (yypminor->yy21);
}
      break;
    case 197: /* ccons */
{
delete (yypminor->yy4);
}
      break;
    case 199: /* expr */
    case 227: /* where_opt */
    case 229: /* having_opt */
    case 251: /* exprx */
    case 253: /* case_operand */
    case 255: /* case_else */
{
delete (yypminor->yy490);
}
      break;
    case 200: /* onconf */
    case 214: /* resolvetype */
    case 215: /* orconf */
{
delete (yypminor->yy30);
}
      break;
    case 201: /* sortorder */
{
delete (yypminor->yy226);
}
      break;
    case 203: /* idxlist_opt */
    case 212: /* idxlist */
{
delete (yypminor->yy139);
}
      break;
    case 204: /* refargs */
{
delete (yypminor->yy108);
}
      break;
    case 205: /* defer_subclause */
    case 213: /* defer_subclause_opt */
{
delete (yypminor->yy131);
}
      break;
    case 206: /* refarg */
{
delete (yypminor->yy271);
}
      break;
    case 207: /* refact */
{
delete (yypminor->yy312);
}
      break;
    case 208: /* init_deferred_pred_opt */
{
delete (yypminor->yy498);
}
      break;
    case 211: /* tcons */
{
delete (yypminor->yy8);
}
      break;
    case 219: /* with */
    case 276: /* wqlist */
{
delete (yypminor->yy367);
}
      break;
    case 221: /* oneselect */
{
delete (yypminor->yy468);
}
      break;
    case 222: /* multiselect_op */
{
delete (yypminor->yy168);
}
      break;
    case 223: /* values */
{
delete (yypminor->yy416);
}
      break;
    case 225: /* selcollist */
    case 234: /* sclp */
{
delete (yypminor->yy263);
}
      break;
    case 226: /* from */
    case 236: /* joinsrc */
{
delete (yypminor->yy373);
}
      break;
    case 228: /* groupby_opt */
    case 232: /* nexprlist */
    case 233: /* exprlist */
    case 254: /* case_exprlist */
{
delete (yypminor->yy13);
}
      break;
    case 230: /* orderby_opt */
    case 244: /* sortlist */
{
delete (yypminor->yy495);
}
      break;
    case 231: /* limit_opt */
{
delete (yypminor->yy128);
}
      break;
    case 235: /* as */
{
delete (yypminor->yy28);
}
      break;
    case 237: /* singlesrc */
{
delete (yypminor->yy173);
}
      break;
    case 238: /* seltablist */
{
delete (yypminor->yy359);
}
      break;
    case 239: /* joinop */
{
delete (yypminor->yy473);
}
      break;
    case 240: /* joinconstr_opt */
{
delete (yypminor->yy117);
}
      break;
    case 242: /* indexed_opt */
{
delete (yypminor->yy472);
}
      break;
    case 243: /* inscollist */
    case 250: /* inscollist_opt */
    case 272: /* vtabarglist */
{
delete (yypminor->yy445);
}
      break;
    case 247: /* setlist */
{
delete (yypminor->yy381);
}
      break;
    case 249: /* insert_cmd */
{
delete (yypminor->yy250);
}
      break;
    case 256: /* likeop */
{
delete (yypminor->yy374);
}
      break;
    case 258: /* idxlist_single */
{
delete (yypminor->yy90);
}
      break;
    case 262: /* trigger_time */
{
delete (yypminor->yy152);
}
      break;
    case 263: /* trigger_event */
{
delete (yypminor->yy309);
}
      break;
    case 264: /* foreach_clause */
{
delete (yypminor->yy409);
}
      break;
    case 265: /* when_clause */
    case 269: /* key_opt */
{
if ((yypminor->yy490)) delete (yypminor->yy490);
}
      break;
    case 266: /* trigger_cmd_list */
{
delete (yypminor->yy214);
}
      break;
        default:  break;   /* If no destructor action specified: do nothing */
      }
  }
}

/*
** Pop the parser's stack once.
**
** If there is a destructor routine associated with the token which
** is popped from the stack, then call it.
**
** Return the major token number for the symbol popped.
*/
static int yy_pop_parser_stack(yyParser *pParser){
  YYCODETYPE yymajor;
  yyStackEntry *yytos = &pParser->yystack[pParser->yyidx];

  /* There is no mechanism by which the parser stack can be popped below
  ** empty in SQLite.  */
  if( pParser->yyidx<0 ) return 0;
#ifndef NDEBUG
  if( yyTraceFILE && pParser->yyidx>=0 ){
    fprintf(yyTraceFILE,"%sPopping %s\n",
      yyTracePrompt,
      yyTokenName[yytos->major]);
  }
#endif
  yymajor = yytos->major;
  yy_destructor(pParser, yymajor, &yytos->minor);
  delete yytos->tokens;
  yytos->tokens = nullptr;
  pParser->yyidx--;
  return yymajor;
}

/*
** Deallocate and destroy a parser.  Destructors are all called for
** all stack elements before shutting the parser down.
**
** Inputs:
** <ul>
** <li>  A pointer to the parser.  This should be a pointer
**       obtained from sqlite3_parseAlloc.
** <li>  A pointer to a function used to reclaim memory obtained
**       from malloc.
** </ul>
*/
void sqlite3_parseFree(
  void *p,                    /* The parser to be deleted */
  void (*freeProc)(void*)     /* Function used to reclaim memory */
){
  yyParser *pParser = (yyParser*)p;
  /* In SQLite, we never try to destroy a parser that was not successfully
  ** created in the first place. */
  if( pParser==0 ) return;
  while( pParser->yyidx>=0 ) yy_pop_parser_stack(pParser);
#if YYSTACKDEPTH<=0
  free(pParser->yystack);
#endif
  (*freeProc)((void*)pParser);
}

/*
** Return the peak depth of the stack for a parser.
*/
#ifdef YYTRACKMAXSTACKDEPTH
int sqlite3_parseStackPeak(void *p){
  yyParser *pParser = (yyParser*)p;
  return pParser->yyidxMax;
}
#endif

/*
** Find the appropriate action for a parser given the terminal
** look-ahead token iLookAhead.
**
** If the look-ahead token is YYNOCODE, then check to see if the action is
** independent of the look-ahead.  If it is, return the action, otherwise
** return YY_NO_ACTION.
*/
static int yy_find_shift_action(
  yyParser *pParser,        /* The parser */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
  int stateno = pParser->yystack[pParser->yyidx].stateno;
  GET_CONTEXT;

  if( stateno>YY_SHIFT_COUNT
   || (i = yy_shift_ofst[stateno])==YY_SHIFT_USE_DFLT ){
    return yy_default[stateno];
  }
  assert( iLookAhead!=YYNOCODE );
  i += iLookAhead;
  if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
    if( iLookAhead>0 ){
#ifdef YYFALLBACK
      YYCODETYPE iFallback;            /* Fallback token */
      if( iLookAhead<sizeof(yyFallback)/sizeof(yyFallback[0])
             && (iFallback = yyFallback[iLookAhead])!=0
             && parserContext->doFallbacks ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE, "%sFALLBACK %s => %s\n",
             yyTracePrompt, yyTokenName[iLookAhead], yyTokenName[iFallback]);
        }
#endif
        return yy_find_shift_action(pParser, iFallback);
      }
#endif
#ifdef YYWILDCARD
      {
        int j = i - iLookAhead + YYWILDCARD;
        if(
#if YY_SHIFT_MIN+YYWILDCARD<0
          j>=0 &&
#endif
#if YY_SHIFT_MAX+YYWILDCARD>=YY_ACTTAB_COUNT
          j<YY_ACTTAB_COUNT &&
#endif
          yy_lookahead[j]==YYWILDCARD
        ){
#ifndef NDEBUG
          if( yyTraceFILE ){
            fprintf(yyTraceFILE, "%sWILDCARD %s => %s\n",
               yyTracePrompt, yyTokenName[iLookAhead], yyTokenName[YYWILDCARD]);
          }
#endif /* NDEBUG */
          return yy_action[j];
        }
      }
#endif /* YYWILDCARD */
    }
    return yy_default[stateno];
  }else{
    return yy_action[i];
  }
}

/*
** Find the appropriate action for a parser given the non-terminal
** look-ahead token iLookAhead.
**
** If the look-ahead token is YYNOCODE, then check to see if the action is
** independent of the look-ahead.  If it is, return the action, otherwise
** return YY_NO_ACTION.
*/
static int yy_find_reduce_action(
  int stateno,              /* Current state number */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
#ifdef YYERRORSYMBOL
  if( stateno>YY_REDUCE_COUNT ){
    return yy_default[stateno];
  }
#else
  assert( stateno<=YY_REDUCE_COUNT );
#endif
  i = yy_reduce_ofst[stateno];
  assert( i!=YY_REDUCE_USE_DFLT );
  assert( iLookAhead!=YYNOCODE );
  i += iLookAhead;
#ifdef YYERRORSYMBOL
  if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
    return yy_default[stateno];
  }
#else
  assert( i>=0 && i<YY_ACTTAB_COUNT );
  assert( yy_lookahead[i]==iLookAhead );
#endif
  return yy_action[i];
}

/*
** The following routine is called if the stack overflows.
*/
static void yyStackOverflow(yyParser *yypParser, YYMINORTYPE *yypMinor){
   sqlite3_parseARG_FETCH;
   yypParser->yyidx--;
#ifndef NDEBUG
   if( yyTraceFILE ){
     fprintf(yyTraceFILE,"%sStack Overflow!\n",yyTracePrompt);
   }
#endif
   while( yypParser->yyidx>=0 ) yy_pop_parser_stack(yypParser);
   /* Here code is inserted which will execute if the parser
   ** stack every overflows */

    UNUSED_PARAMETER(yypMinor);
    parserContext->error(QObject::tr("Parser stack overflow"));
   sqlite3_parseARG_STORE; /* Suppress warning about unused %extra_argument var */
}

/*
** Perform a shift action.
*/
static void yy_shift(
  yyParser *yypParser,          /* The parser to be shifted */
  int yyNewState,               /* The new state to shift in */
  int yyMajor,                  /* The major token to shift in */
  YYMINORTYPE *yypMinor         /* Pointer to the minor token to shift in */
){
  yyStackEntry *yytos;
  yypParser->yyidx++;
#ifdef YYTRACKMAXSTACKDEPTH
  if( yypParser->yyidx>yypParser->yyidxMax ){
    yypParser->yyidxMax = yypParser->yyidx;
  }
#endif
#if YYSTACKDEPTH>0
  if( yypParser->yyidx>=YYSTACKDEPTH ){
    yyStackOverflow(yypParser, yypMinor);
    return;
  }
#else
  if( yypParser->yyidx>=yypParser->yystksz ){
    yyGrowStack(yypParser);
    if( yypParser->yyidx>=yypParser->yystksz ){
      yyStackOverflow(yypParser, yypMinor);
      return;
    }
  }
#endif
  yytos = &yypParser->yystack[yypParser->yyidx];
  yytos->stateno = (YYACTIONTYPE)yyNewState;
  yytos->major = (YYCODETYPE)yyMajor;
  yytos->minor = *yypMinor;
  yytos->tokens = new QList<Token*>();
#ifndef NDEBUG
  if( yyTraceFILE && yypParser->yyidx>0 ){
    int i;
    fprintf(yyTraceFILE,"%sShift %d\n",yyTracePrompt,yyNewState);
    fprintf(yyTraceFILE,"%sStack:",yyTracePrompt);
    for(i=1; i<=yypParser->yyidx; i++)
      fprintf(yyTraceFILE," %s",yyTokenName[yypParser->yystack[i].major]);
    fprintf(yyTraceFILE,"\n");
  }
#endif
}

/* The following table contains information about every rule that
** is used during the reduce.
*/
static const struct {
  YYCODETYPE lhs;         /* Symbol on the left-hand side of the rule */
  unsigned char nrhs;     /* Number of right-hand side symbols in the rule */
} yyRuleInfo[] = {
  { 170, 1 },
  { 171, 2 },
  { 171, 1 },
  { 172, 1 },
  { 172, 3 },
  { 173, 0 },
  { 173, 1 },
  { 173, 3 },
  { 174, 1 },
  { 169, 3 },
  { 176, 0 },
  { 176, 1 },
  { 176, 2 },
  { 176, 2 },
  { 175, 0 },
  { 175, 1 },
  { 175, 1 },
  { 175, 1 },
  { 169, 2 },
  { 169, 2 },
  { 169, 2 },
  { 178, 1 },
  { 178, 0 },
  { 169, 2 },
  { 169, 3 },
  { 169, 5 },
  { 169, 2 },
  { 169, 3 },
  { 169, 5 },
  { 169, 10 },
  { 169, 7 },
  { 169, 7 },
  { 169, 5 },
  { 184, 0 },
  { 184, 2 },
  { 184, 2 },
  { 180, 0 },
  { 180, 3 },
  { 179, 1 },
  { 179, 0 },
  { 182, 3 },
  { 182, 1 },
  { 186, 3 },
  { 187, 1 },
  { 187, 1 },
  { 190, 1 },
  { 191, 1 },
  { 177, 1 },
  { 177, 1 },
  { 177, 1 },
  { 188, 0 },
  { 188, 1 },
  { 192, 1 },
  { 192, 4 },
  { 192, 6 },
  { 193, 1 },
  { 193, 2 },
  { 193, 1 },
  { 194, 1 },
  { 194, 1 },
  { 189, 2 },
  { 189, 0 },
  { 197, 2 },
  { 197, 2 },
  { 197, 4 },
  { 197, 3 },
  { 197, 3 },
  { 197, 2 },
  { 197, 2 },
  { 197, 2 },
  { 197, 3 },
  { 197, 5 },
  { 197, 2 },
  { 197, 4 },
  { 197, 4 },
  { 197, 1 },
  { 197, 2 },
  { 197, 2 },
  { 197, 2 },
  { 197, 2 },
  { 197, 3 },
  { 198, 1 },
  { 198, 1 },
  { 198, 1 },
  { 198, 1 },
  { 202, 0 },
  { 202, 1 },
  { 204, 0 },
  { 204, 2 },
  { 206, 2 },
  { 206, 3 },
  { 206, 3 },
  { 206, 3 },
  { 206, 2 },
  { 207, 2 },
  { 207, 2 },
  { 207, 1 },
  { 207, 1 },
  { 207, 2 },
  { 205, 3 },
  { 205, 2 },
  { 208, 0 },
  { 208, 2 },
  { 208, 2 },
  { 183, 0 },
  { 183, 2 },
  { 209, 3 },
  { 209, 1 },
  { 210, 1 },
  { 210, 0 },
  { 211, 2 },
  { 211, 7 },
  { 211, 5 },
  { 211, 5 },
  { 211, 10 },
  { 211, 2 },
  { 211, 7 },
  { 211, 4 },
  { 213, 0 },
  { 213, 1 },
  { 200, 0 },
  { 200, 3 },
  { 215, 0 },
  { 215, 2 },
  { 214, 1 },
  { 214, 1 },
  { 214, 1 },
  { 169, 4 },
  { 169, 6 },
  { 169, 4 },
  { 217, 2 },
  { 217, 0 },
  { 169, 8 },
  { 169, 7 },
  { 169, 5 },
  { 169, 4 },
  { 169, 6 },
  { 169, 4 },
  { 169, 1 },
  { 218, 1 },
  { 185, 2 },
  { 220, 1 },
  { 220, 3 },
  { 220, 1 },
  { 220, 3 },
  { 222, 1 },
  { 222, 2 },
  { 222, 1 },
  { 222, 1 },
  { 221, 9 },
  { 223, 4 },
  { 223, 5 },
  { 224, 1 },
  { 224, 1 },
  { 224, 0 },
  { 234, 2 },
  { 234, 0 },
  { 225, 3 },
  { 225, 2 },
  { 225, 4 },
  { 225, 1 },
  { 225, 4 },
  { 235, 2 },
  { 235, 1 },
  { 235, 2 },
  { 235, 1 },
  { 235, 0 },
  { 226, 0 },
  { 226, 2 },
  { 236, 2 },
  { 236, 0 },
  { 238, 4 },
  { 238, 0 },
  { 237, 4 },
  { 237, 4 },
  { 237, 4 },
  { 237, 0 },
  { 237, 2 },
  { 237, 3 },
  { 237, 1 },
  { 237, 3 },
  { 237, 1 },
  { 240, 2 },
  { 240, 4 },
  { 240, 0 },
  { 241, 0 },
  { 241, 2 },
  { 181, 2 },
  { 239, 1 },
  { 239, 1 },
  { 239, 2 },
  { 239, 3 },
  { 239, 4 },
  { 239, 1 },
  { 242, 0 },
  { 242, 3 },
  { 242, 2 },
  { 242, 3 },
  { 230, 0 },
  { 230, 3 },
  { 244, 4 },
  { 244, 2 },
  { 201, 1 },
  { 201, 1 },
  { 201, 0 },
  { 228, 0 },
  { 228, 3 },
  { 228, 2 },
  { 229, 0 },
  { 229, 2 },
  { 231, 0 },
  { 231, 2 },
  { 231, 4 },
  { 231, 4 },
  { 169, 1 },
  { 245, 6 },
  { 245, 3 },
  { 245, 5 },
  { 245, 6 },
  { 245, 4 },
  { 227, 0 },
  { 227, 2 },
  { 227, 1 },
  { 169, 1 },
  { 246, 8 },
  { 246, 3 },
  { 246, 5 },
  { 246, 6 },
  { 246, 4 },
  { 247, 5 },
  { 247, 3 },
  { 247, 0 },
  { 247, 2 },
  { 247, 3 },
  { 247, 1 },
  { 169, 1 },
  { 248, 6 },
  { 248, 7 },
  { 248, 3 },
  { 248, 5 },
  { 248, 4 },
  { 248, 6 },
  { 249, 2 },
  { 249, 1 },
  { 250, 0 },
  { 250, 3 },
  { 243, 3 },
  { 243, 1 },
  { 243, 0 },
  { 243, 3 },
  { 243, 1 },
  { 251, 2 },
  { 251, 4 },
  { 251, 5 },
  { 251, 4 },
  { 251, 5 },
  { 251, 4 },
  { 251, 6 },
  { 251, 1 },
  { 251, 3 },
  { 251, 5 },
  { 251, 3 },
  { 251, 6 },
  { 251, 1 },
  { 251, 1 },
  { 251, 3 },
  { 251, 1 },
  { 251, 1 },
  { 251, 3 },
  { 251, 5 },
  { 251, 1 },
  { 251, 3 },
  { 251, 6 },
  { 251, 5 },
  { 251, 4 },
  { 251, 3 },
  { 251, 3 },
  { 251, 3 },
  { 251, 3 },
  { 251, 3 },
  { 251, 3 },
  { 251, 3 },
  { 251, 3 },
  { 251, 4 },
  { 251, 6 },
  { 251, 2 },
  { 251, 3 },
  { 251, 4 },
  { 251, 2 },
  { 251, 2 },
  { 251, 2 },
  { 251, 2 },
  { 251, 6 },
  { 251, 6 },
  { 251, 3 },
  { 251, 6 },
  { 251, 5 },
  { 251, 4 },
  { 251, 5 },
  { 251, 4 },
  { 251, 6 },
  { 199, 0 },
  { 199, 1 },
  { 252, 0 },
  { 252, 1 },
  { 256, 1 },
  { 254, 5 },
  { 254, 4 },
  { 255, 2 },
  { 255, 0 },
  { 253, 1 },
  { 253, 0 },
  { 233, 1 },
  { 233, 0 },
  { 232, 3 },
  { 232, 1 },
  { 169, 12 },
  { 169, 8 },
  { 169, 7 },
  { 169, 5 },
  { 257, 1 },
  { 257, 0 },
  { 203, 0 },
  { 203, 3 },
  { 212, 3 },
  { 212, 1 },
  { 258, 3 },
  { 258, 1 },
  { 259, 0 },
  { 259, 2 },
  { 259, 2 },
  { 169, 4 },
  { 169, 6 },
  { 169, 4 },
  { 169, 1 },
  { 169, 2 },
  { 169, 3 },
  { 169, 5 },
  { 169, 6 },
  { 169, 5 },
  { 169, 6 },
  { 169, 4 },
  { 169, 2 },
  { 260, 1 },
  { 260, 1 },
  { 260, 1 },
  { 260, 1 },
  { 260, 1 },
  { 195, 2 },
  { 195, 1 },
  { 196, 2 },
  { 261, 1 },
  { 261, 1 },
  { 169, 15 },
  { 169, 12 },
  { 169, 14 },
  { 169, 10 },
  { 169, 7 },
  { 169, 5 },
  { 262, 1 },
  { 262, 1 },
  { 262, 2 },
  { 262, 0 },
  { 263, 1 },
  { 263, 1 },
  { 263, 1 },
  { 263, 3 },
  { 264, 0 },
  { 264, 3 },
  { 265, 0 },
  { 265, 2 },
  { 266, 3 },
  { 266, 2 },
  { 266, 1 },
  { 267, 1 },
  { 267, 1 },
  { 267, 1 },
  { 267, 1 },
  { 216, 1 },
  { 169, 4 },
  { 169, 6 },
  { 169, 4 },
  { 169, 6 },
  { 169, 3 },
  { 269, 0 },
  { 269, 2 },
  { 268, 1 },
  { 268, 0 },
  { 169, 1 },
  { 169, 3 },
  { 169, 2 },
  { 169, 4 },
  { 169, 2 },
  { 169, 1 },
  { 169, 3 },
  { 169, 4 },
  { 169, 2 },
  { 169, 6 },
  { 169, 6 },
  { 169, 6 },
  { 169, 5 },
  { 169, 3 },
  { 270, 0 },
  { 270, 1 },
  { 169, 1 },
  { 271, 8 },
  { 271, 11 },
  { 271, 7 },
  { 271, 5 },
  { 272, 1 },
  { 272, 3 },
  { 273, 0 },
  { 273, 2 },
  { 274, 1 },
  { 274, 3 },
  { 275, 0 },
  { 275, 4 },
  { 275, 2 },
  { 219, 0 },
  { 219, 2 },
  { 219, 3 },
  { 276, 6 },
  { 276, 8 },
  { 276, 1 },
};

static void yy_accept(yyParser*);  /* Forward Declaration */

/*
** Perform a reduce action and the shift that must immediately
** follow the reduce.
*/
static void yy_reduce(
  yyParser *yypParser,         /* The parser */
  int yyruleno                 /* Number of the rule by which to reduce */
){
  int yygoto;                     /* The next state */
  int yyact;                      /* The next action */
  YYMINORTYPE yygotominor;        /* The LHS of the rule reduced */
  yyStackEntry *yymsp;            /* The top of the parser's stack */
  int yysize;                     /* Amount to pop the stack */
  sqlite3_parseARG_FETCH;
  SqliteStatement* objectForTokens = 0;
  QStringList noTokenInheritanceFields;
  yymsp = &yypParser->yystack[yypParser->yyidx];
#ifndef NDEBUG
  if( yyTraceFILE && yyruleno>=0
        && yyruleno<(int)(sizeof(yyRuleName)/sizeof(yyRuleName[0])) ){
    fprintf(yyTraceFILE, "%sReduce [%s].\n", yyTracePrompt,
      yyRuleName[yyruleno]);
  }
#endif /* NDEBUG */

  /* Silence complaints from purify about yygotominor being uninitialized
  ** in some cases when it is copied into the stack after the following
  ** switch.  yygotominor is uninitialized when a rule reduces that does
  ** not set the value of its left-hand side nonterminal.  Leaving the
  ** value of the nonterminal uninitialized is utterly harmless as long
  ** as the value is never used.  So really the only thing this code
  ** accomplishes is to quieten purify.
  **
  ** 2007-01-16:  The wireshark project (www.wireshark.org) reports that
  ** without this code, their parser segfaults.  I'm not sure what there
  ** parser is doing to make this happen.  This is the second bug report
  ** from wireshark this week.  Clearly they are stressing Lemon in ways
  ** that it has not been previously stressed...  (SQLite ticket #2172)
  */
  /*memset(&yygotominor, 0, sizeof(yygotominor));*/
  yygotominor = yyzerominor;


  if (parserContext->executeRules)
  {
      switch( yyruleno ){
      /* Beginning here are the reduction cases.  A typical example
      ** follows:
      **   case 0:
      **  #line <lineno> <grammarfile>
      **     { ... }           // User supplied code
      **  #line <lineno> <thisfile>
      **     break;
      */
      case 1: /* cmdlist ::= cmdlist ecmd */
{parserContext->addQuery(yymsp[0].minor.yy399); DONT_INHERIT_TOKENS("cmdlist");}
        break;
      case 2: /* cmdlist ::= ecmd */
{parserContext->addQuery(yymsp[0].minor.yy399);}
        break;
      case 3: /* ecmd ::= SEMI */
{yygotominor.yy399 = new SqliteEmptyQuery();}
        break;
      case 4: /* ecmd ::= explain cmdx SEMI */
{
                                                yygotominor.yy399 = yymsp[-1].minor.yy399;
                                                yygotominor.yy399->explain = yymsp[-2].minor.yy225->explain;
                                                yygotominor.yy399->queryPlan = yymsp[-2].minor.yy225->queryPlan;
                                                delete yymsp[-2].minor.yy225;
                                                objectForTokens = yygotominor.yy399;
                                            }
        break;
      case 5: /* explain ::= */
{yygotominor.yy225 = new ParserStubExplain(false, false);}
        break;
      case 6: /* explain ::= EXPLAIN */
{yygotominor.yy225 = new ParserStubExplain(true, false);}
        break;
      case 7: /* explain ::= EXPLAIN QUERY PLAN */
{yygotominor.yy225 = new ParserStubExplain(true, true);}
        break;
      case 8: /* cmdx ::= cmd */
      case 374: /* trigger_cmd ::= update_stmt */ yytestcase(yyruleno==374);
      case 375: /* trigger_cmd ::= insert_stmt */ yytestcase(yyruleno==375);
      case 376: /* trigger_cmd ::= delete_stmt */ yytestcase(yyruleno==376);
      case 377: /* trigger_cmd ::= select_stmt */ yytestcase(yyruleno==377);
      case 404: /* cmd ::= create_vtab */ yytestcase(yyruleno==404);
{yygotominor.yy399 = yymsp[0].minor.yy399;}
        break;
      case 9: /* cmd ::= BEGIN transtype trans_opt */
{
                                                yygotominor.yy399 = new SqliteBeginTrans(
                                                        yymsp[-1].minor.yy300->type,
                                                        yymsp[0].minor.yy300->transactionKw,
                                                        yymsp[0].minor.yy300->name
                                                    );
                                                delete yymsp[0].minor.yy300;
                                                delete yymsp[-1].minor.yy300;
                                                objectForTokens = yygotominor.yy399;
                                            }
        break;
      case 10: /* trans_opt ::= */
      case 14: /* transtype ::= */ yytestcase(yyruleno==14);
{yygotominor.yy300 = new ParserStubTransDetails();}
        break;
      case 11: /* trans_opt ::= TRANSACTION */
{
                                                yygotominor.yy300 = new ParserStubTransDetails();
                                                yygotominor.yy300->transactionKw = true;
                                            }
        break;
      case 12: /* trans_opt ::= TRANSACTION nm */
      case 13: /* trans_opt ::= TRANSACTION ID_TRANS */ yytestcase(yyruleno==13);
{
                                                yygotominor.yy300 = new ParserStubTransDetails();
                                                yygotominor.yy300->transactionKw = true;
                                                yygotominor.yy300->name = *(yymsp[0].minor.yy211);
                                                delete yymsp[0].minor.yy211;
                                            }
        break;
      case 15: /* transtype ::= DEFERRED */
{
                                                yygotominor.yy300 = new ParserStubTransDetails();
                                                yygotominor.yy300->type = SqliteBeginTrans::Type::DEFERRED;
                                            }
        break;
      case 16: /* transtype ::= IMMEDIATE */
{
                                                yygotominor.yy300 = new ParserStubTransDetails();
                                                yygotominor.yy300->type = SqliteBeginTrans::Type::IMMEDIATE;
                                            }
        break;
      case 17: /* transtype ::= EXCLUSIVE */
{
                                                yygotominor.yy300 = new ParserStubTransDetails();
                                                yygotominor.yy300->type = SqliteBeginTrans::Type::EXCLUSIVE;
                                            }
        break;
      case 18: /* cmd ::= COMMIT trans_opt */
{
                                                yygotominor.yy399 = new SqliteCommitTrans(
                                                        yymsp[0].minor.yy300->transactionKw,
                                                        yymsp[0].minor.yy300->name,
                                                        false
                                                    );
                                                delete yymsp[0].minor.yy300;
                                                objectForTokens = yygotominor.yy399;
                                            }
        break;
      case 19: /* cmd ::= END trans_opt */
{
                                                yygotominor.yy399 = new SqliteCommitTrans(
                                                        yymsp[0].minor.yy300->transactionKw,
                                                        yymsp[0].minor.yy300->name,
                                                        true
                                                    );
                                                delete yymsp[0].minor.yy300;
                                                objectForTokens = yygotominor.yy399;
                                            }
        break;
      case 20: /* cmd ::= ROLLBACK trans_opt */
{
                                                yygotominor.yy399 = new SqliteRollback(
                                                        yymsp[0].minor.yy300->transactionKw,
                                                        yymsp[0].minor.yy300->name
                                                    );
                                                delete yymsp[0].minor.yy300;
                                                objectForTokens = yygotominor.yy399;
                                            }
        break;
      case 21: /* savepoint_opt ::= SAVEPOINT */
      case 37: /* ifnotexists ::= IF NOT EXISTS */ yytestcase(yyruleno==37);
      case 86: /* autoinc ::= AUTOINCR */ yytestcase(yyruleno==86);
      case 108: /* tconscomma ::= COMMA */ yytestcase(yyruleno==108);
      case 130: /* ifexists ::= IF EXISTS */ yytestcase(yyruleno==130);
      case 304: /* not_opt ::= NOT */ yytestcase(yyruleno==304);
      case 320: /* uniqueflag ::= UNIQUE */ yytestcase(yyruleno==320);
      case 386: /* database_kw_opt ::= DATABASE */ yytestcase(yyruleno==386);
      case 402: /* kwcolumn_opt ::= */ yytestcase(yyruleno==402);
{yygotominor.yy237 = new bool(true);}
        break;
      case 22: /* savepoint_opt ::= */
      case 36: /* ifnotexists ::= */ yytestcase(yyruleno==36);
      case 85: /* autoinc ::= */ yytestcase(yyruleno==85);
      case 109: /* tconscomma ::= */ yytestcase(yyruleno==109);
      case 131: /* ifexists ::= */ yytestcase(yyruleno==131);
      case 303: /* not_opt ::= */ yytestcase(yyruleno==303);
      case 321: /* uniqueflag ::= */ yytestcase(yyruleno==321);
      case 387: /* database_kw_opt ::= */ yytestcase(yyruleno==387);
      case 403: /* kwcolumn_opt ::= COLUMNKW */ yytestcase(yyruleno==403);
{yygotominor.yy237 = new bool(false);}
        break;
      case 23: /* cmd ::= SAVEPOINT nm */
{
                                                yygotominor.yy399 = new SqliteSavepoint(*(yymsp[0].minor.yy211));
                                                delete yymsp[0].minor.yy211;
                                                objectForTokens = yygotominor.yy399;
                                            }
        break;
      case 24: /* cmd ::= RELEASE savepoint_opt nm */
{
                                                yygotominor.yy399 = new SqliteRelease(*(yymsp[-1].minor.yy237), *(yymsp[0].minor.yy211));
                                                delete yymsp[0].minor.yy211;
                                                objectForTokens = yygotominor.yy399;
                                            }
        break;
      case 25: /* cmd ::= ROLLBACK trans_opt TO savepoint_opt nm */
      case 26: /* cmd ::= SAVEPOINT ID_TRANS */ yytestcase(yyruleno==26);
{
                                                yygotominor.yy399 = new SqliteRollback(
                                                        yymsp[-3].minor.yy300->transactionKw,
                                                        *(yymsp[-1].minor.yy237),
                                                        *(yymsp[0].minor.yy211)
                                                    );
                                                delete yymsp[-1].minor.yy237;
                                                delete yymsp[-3].minor.yy300;
                                                objectForTokens = yygotominor.yy399;
                                            }
        break;
      case 27: /* cmd ::= RELEASE savepoint_opt ID_TRANS */
      case 28: /* cmd ::= ROLLBACK trans_opt TO savepoint_opt ID_TRANS */ yytestcase(yyruleno==28);
{  yy_destructor(yypParser,178,&yymsp[-1].minor);
}
        break;
      case 29: /* cmd ::= CREATE temp TABLE ifnotexists fullname LP columnlist conslist_opt RP table_options */
{
                                                yygotominor.yy399 = new SqliteCreateTable(
                                                        *(yymsp[-6].minor.yy237),
                                                        *(yymsp[-8].minor.yy376),
                                                        yymsp[-5].minor.yy66->name1,
                                                        yymsp[-5].minor.yy66->name2,
                                                        *(yymsp[-3].minor.yy118),
                                                        *(yymsp[-2].minor.yy87),
                                                        *(yymsp[0].minor.yy211)
                                                    );
                                                delete yymsp[-6].minor.yy237;
                                                delete yymsp[-8].minor.yy376;
                                                delete yymsp[-3].minor.yy118;
                                                delete yymsp[-2].minor.yy87;
                                                delete yymsp[-5].minor.yy66;
                                                delete yymsp[0].minor.yy211;
                                                objectForTokens = yygotominor.yy399;
                                            }
        break;
      case 30: /* cmd ::= CREATE temp TABLE ifnotexists fullname AS select */
{
                                                yygotominor.yy399 = new SqliteCreateTable(
                                                        *(yymsp[-3].minor.yy237),
                                                        *(yymsp[-5].minor.yy376),
                                                        yymsp[-2].minor.yy66->name1,
                                                        yymsp[-2].minor.yy66->name2,
                                                        yymsp[0].minor.yy123
                                                    );
                                                delete yymsp[-3].minor.yy237;
                                                delete yymsp[-5].minor.yy376;
                                                delete yymsp[-2].minor.yy66;
                                                objectForTokens = yygotominor.yy399;
                                            }
        break;
      case 31: /* cmd ::= CREATE temp TABLE ifnotexists nm DOT ID_TAB_NEW */
      case 133: /* cmd ::= CREATE temp VIEW ifnotexists nm DOT ID_VIEW_NEW */ yytestcase(yyruleno==133);
      case 357: /* cmd ::= CREATE temp TRIGGER ifnotexists nm DOT ID_TRIG_NEW */ yytestcase(yyruleno==357);
{  yy_destructor(yypParser,179,&yymsp[-5].minor);
  yy_destructor(yypParser,177,&yymsp[-2].minor);
}
        break;
      case 32: /* cmd ::= CREATE temp TABLE ifnotexists ID_DB|ID_TAB_NEW */
      case 134: /* cmd ::= CREATE temp VIEW ifnotexists ID_DB|ID_VIEW_NEW */ yytestcase(yyruleno==134);
      case 358: /* cmd ::= CREATE temp TRIGGER ifnotexists ID_DB|ID_TRIG_NEW */ yytestcase(yyruleno==358);
{  yy_destructor(yypParser,179,&yymsp[-3].minor);
}
        break;
      case 33: /* table_options ::= */
      case 185: /* dbnm ::= */ yytestcase(yyruleno==185);
      case 328: /* collate ::= */ yytestcase(yyruleno==328);
      case 411: /* vtabarg ::= */ yytestcase(yyruleno==411);
      case 415: /* anylist ::= */ yytestcase(yyruleno==415);
{yygotominor.yy211 = new QString();}
        break;
      case 34: /* table_options ::= WITHOUT nm */
      case 35: /* table_options ::= WITHOUT CTX_ROWID_KW */ yytestcase(yyruleno==35);
{
                                                if (yymsp[0].minor.yy211->toLower() != "rowid")
                                                    parserContext->errorAtToken(QString("Invalid table option: %1").arg(*(yymsp[0].minor.yy211)));

                                                yygotominor.yy211 = yymsp[0].minor.yy211;
                                            }
        break;
      case 38: /* temp ::= TEMP */
{yygotominor.yy376 = new int( (yymsp[0].minor.yy0->value.length() > 4) ? 2 : 1 );}
        break;
      case 39: /* temp ::= */
      case 154: /* distinct ::= */ yytestcase(yyruleno==154);
{yygotominor.yy376 = new int(0);}
        break;
      case 40: /* columnlist ::= columnlist COMMA column */
{
                                                yymsp[-2].minor.yy118->append(yymsp[0].minor.yy425);
                                                yygotominor.yy118 = yymsp[-2].minor.yy118;
                                                DONT_INHERIT_TOKENS("columnlist");
                                            }
        break;
      case 41: /* columnlist ::= column */
{
                                                yygotominor.yy118 = new ParserCreateTableColumnList();
                                                yygotominor.yy118->append(yymsp[0].minor.yy425);
                                            }
        break;
      case 42: /* column ::= columnid type carglist */
{
                                                yygotominor.yy425 = new SqliteCreateTable::Column(*(yymsp[-2].minor.yy211), yymsp[-1].minor.yy299, *(yymsp[0].minor.yy449));
                                                delete yymsp[-2].minor.yy211;
                                                delete yymsp[0].minor.yy449;
                                                objectForTokens = yygotominor.yy425;
                                            }
        break;
      case 43: /* columnid ::= nm */
      case 44: /* columnid ::= ID_COL_NEW */ yytestcase(yyruleno==44);
      case 47: /* nm ::= id */ yytestcase(yyruleno==47);
      case 55: /* typename ::= ids */ yytestcase(yyruleno==55);
      case 186: /* dbnm ::= DOT nm */ yytestcase(yyruleno==186);
      case 329: /* collate ::= COLLATE ids */ yytestcase(yyruleno==329);
      case 330: /* collate ::= COLLATE ID_COLLATE */ yytestcase(yyruleno==330);
{yygotominor.yy211 = yymsp[0].minor.yy211;}
        break;
      case 45: /* id ::= ID */
{
                                                yygotominor.yy211 = new QString(
                                                    stripObjName(
                                                        yymsp[0].minor.yy0->value,
                                                        parserContext->dialect
                                                    )
                                                );
                                            }
        break;
      case 46: /* ids ::= ID|STRING */
      case 49: /* nm ::= JOIN_KW */ yytestcase(yyruleno==49);
{yygotominor.yy211 = new QString(yymsp[0].minor.yy0->value);}
        break;
      case 48: /* nm ::= STRING */
{yygotominor.yy211 = new QString(stripString(yymsp[0].minor.yy0->value));}
        break;
      case 50: /* type ::= */
{yygotominor.yy299 = nullptr;}
        break;
      case 51: /* type ::= typetoken */
{yygotominor.yy299 = yymsp[0].minor.yy299;}
        break;
      case 52: /* typetoken ::= typename */
{
                                                yygotominor.yy299 = new SqliteColumnType(*(yymsp[0].minor.yy211));
                                                delete yymsp[0].minor.yy211;
                                                objectForTokens = yygotominor.yy299;
                                            }
        break;
      case 53: /* typetoken ::= typename LP signed RP */
{
                                                yygotominor.yy299 = new SqliteColumnType(*(yymsp[-3].minor.yy211), *(yymsp[-1].minor.yy21));
                                                delete yymsp[-3].minor.yy211;
                                                delete yymsp[-1].minor.yy21;
                                                objectForTokens = yygotominor.yy299;
                                            }
        break;
      case 54: /* typetoken ::= typename LP signed COMMA signed RP */
{
                                                yygotominor.yy299 = new SqliteColumnType(*(yymsp[-5].minor.yy211), *(yymsp[-3].minor.yy21), *(yymsp[-1].minor.yy21));
                                                delete yymsp[-5].minor.yy211;
                                                delete yymsp[-3].minor.yy21;
                                                delete yymsp[-1].minor.yy21;
                                                objectForTokens = yygotominor.yy299;
                                            }
        break;
      case 56: /* typename ::= typename ids */
      case 57: /* typename ::= ID_COL_TYPE */ yytestcase(yyruleno==57);
{
                                                yymsp[-1].minor.yy211->append(" " + *(yymsp[0].minor.yy211));
                                                delete yymsp[0].minor.yy211;
                                                yygotominor.yy211 = yymsp[-1].minor.yy211;
                                            }
        break;
      case 58: /* signed ::= plus_num */
      case 59: /* signed ::= minus_num */ yytestcase(yyruleno==59);
      case 343: /* nmnum ::= plus_num */ yytestcase(yyruleno==343);
      case 348: /* plus_num ::= PLUS number */ yytestcase(yyruleno==348);
      case 349: /* plus_num ::= number */ yytestcase(yyruleno==349);
{yygotominor.yy21 = yymsp[0].minor.yy21;}
        break;
      case 60: /* carglist ::= carglist ccons */
{
                                                yymsp[-1].minor.yy449->append(yymsp[0].minor.yy4);
                                                yygotominor.yy449 = yymsp[-1].minor.yy449;
                                                DONT_INHERIT_TOKENS("carglist");
                                            }
        break;
      case 61: /* carglist ::= */
{yygotominor.yy449 = new ParserCreateTableColumnConstraintList();}
        break;
      case 62: /* ccons ::= CONSTRAINT nm */
{
                                                yygotominor.yy4 = new SqliteCreateTable::Column::Constraint();
                                                yygotominor.yy4->initDefNameOnly(*(yymsp[0].minor.yy211));
                                                delete yymsp[0].minor.yy211;
                                                objectForTokens = yygotominor.yy4;
                                            }
        break;
      case 63: /* ccons ::= DEFAULT term */
{
                                                yygotominor.yy4 = new SqliteCreateTable::Column::Constraint();
                                                yygotominor.yy4->initDefTerm(*(yymsp[0].minor.yy21));
                                                delete yymsp[0].minor.yy21;
                                                objectForTokens = yygotominor.yy4;
                                            }
        break;
      case 64: /* ccons ::= DEFAULT LP expr RP */
{
                                                yygotominor.yy4 = new SqliteCreateTable::Column::Constraint();
                                                yygotominor.yy4->initDefExpr(yymsp[-1].minor.yy490);
                                                objectForTokens = yygotominor.yy4;
                                            }
        break;
      case 65: /* ccons ::= DEFAULT PLUS term */
{
                                                yygotominor.yy4 = new SqliteCreateTable::Column::Constraint();
                                                yygotominor.yy4->initDefTerm(*(yymsp[0].minor.yy21), false);
                                                delete yymsp[0].minor.yy21;
                                                objectForTokens = yygotominor.yy4;
                                            }
        break;
      case 66: /* ccons ::= DEFAULT MINUS term */
{
                                                yygotominor.yy4 = new SqliteCreateTable::Column::Constraint();
                                                yygotominor.yy4->initDefTerm(*(yymsp[0].minor.yy21), true);
                                                delete yymsp[0].minor.yy21;
                                                objectForTokens = yygotominor.yy4;
                                            }
        break;
      case 67: /* ccons ::= DEFAULT id */
{
                                                yygotominor.yy4 = new SqliteCreateTable::Column::Constraint();
                                                yygotominor.yy4->initDefId(*(yymsp[0].minor.yy211));
                                                delete yymsp[0].minor.yy211;
                                                objectForTokens = yygotominor.yy4;
                                            }
        break;
      case 68: /* ccons ::= DEFAULT CTIME_KW */
{
                                                yygotominor.yy4 = new SqliteCreateTable::Column::Constraint();
                                                yygotominor.yy4->initDefCTime(yymsp[0].minor.yy0->value);
                                                objectForTokens = yygotominor.yy4;
                                            }
        break;
      case 69: /* ccons ::= NULL onconf */
{
                                                yygotominor.yy4 = new SqliteCreateTable::Column::Constraint();
                                                yygotominor.yy4->initNull(*(yymsp[0].minor.yy30));
                                                delete yymsp[0].minor.yy30;
                                                objectForTokens = yygotominor.yy4;
                                            }
        break;
      case 70: /* ccons ::= NOT NULL onconf */
{
                                                yygotominor.yy4 = new SqliteCreateTable::Column::Constraint();
                                                yygotominor.yy4->initNotNull(*(yymsp[0].minor.yy30));
                                                delete yymsp[0].minor.yy30;
                                                objectForTokens = yygotominor.yy4;
                                            }
        break;
      case 71: /* ccons ::= PRIMARY KEY sortorder onconf autoinc */
{
                                                yygotominor.yy4 = new SqliteCreateTable::Column::Constraint();
                                                yygotominor.yy4->initPk(*(yymsp[-2].minor.yy226), *(yymsp[-1].minor.yy30), *(yymsp[0].minor.yy237));
                                                delete yymsp[-2].minor.yy226;
                                                delete yymsp[0].minor.yy237;
                                                delete yymsp[-1].minor.yy30;
                                                objectForTokens = yygotominor.yy4;
                                            }
        break;
      case 72: /* ccons ::= UNIQUE onconf */
{
                                                yygotominor.yy4 = new SqliteCreateTable::Column::Constraint();
                                                yygotominor.yy4->initUnique(*(yymsp[0].minor.yy30));
                                                delete yymsp[0].minor.yy30;
                                                objectForTokens = yygotominor.yy4;
                                            }
        break;
      case 73: /* ccons ::= CHECK LP expr RP */
{
                                                yygotominor.yy4 = new SqliteCreateTable::Column::Constraint();
                                                yygotominor.yy4->initCheck(yymsp[-1].minor.yy490);
                                                objectForTokens = yygotominor.yy4;
                                            }
        break;
      case 74: /* ccons ::= REFERENCES nm idxlist_opt refargs */
{
                                                yygotominor.yy4 = new SqliteCreateTable::Column::Constraint();
                                                yygotominor.yy4->initFk(*(yymsp[-2].minor.yy211), *(yymsp[-1].minor.yy139), *(yymsp[0].minor.yy108));
                                                delete yymsp[-2].minor.yy211;
                                                delete yymsp[0].minor.yy108;
                                                delete yymsp[-1].minor.yy139;
                                                objectForTokens = yygotominor.yy4;
                                            }
        break;
      case 75: /* ccons ::= defer_subclause */
{
                                                yygotominor.yy4 = new SqliteCreateTable::Column::Constraint();
                                                yygotominor.yy4->initDefer(yymsp[0].minor.yy131->initially, yymsp[0].minor.yy131->deferrable);
                                                delete yymsp[0].minor.yy131;
                                                objectForTokens = yygotominor.yy4;
                                            }
        break;
      case 76: /* ccons ::= COLLATE ids */
      case 77: /* ccons ::= CONSTRAINT ID_CONSTR */ yytestcase(yyruleno==77);
      case 78: /* ccons ::= COLLATE ID_COLLATE */ yytestcase(yyruleno==78);
      case 79: /* ccons ::= REFERENCES ID_TAB */ yytestcase(yyruleno==79);
{
                                                yygotominor.yy4 = new SqliteCreateTable::Column::Constraint();
                                                yygotominor.yy4->initColl(*(yymsp[0].minor.yy211));
                                                delete yymsp[0].minor.yy211;
                                                objectForTokens = yygotominor.yy4;
                                            }
        break;
      case 80: /* ccons ::= CHECK LP RP */
{
                                                yygotominor.yy4 = new SqliteCreateTable::Column::Constraint();
                                                yygotominor.yy4->initCheck();
                                                objectForTokens = yygotominor.yy4;
                                                parserContext->minorErrorAfterLastToken("Syntax error");
                                            }
        break;
      case 81: /* term ::= NULL */
{yygotominor.yy21 = new QVariant();}
        break;
      case 82: /* term ::= INTEGER */
      case 351: /* number ::= INTEGER */ yytestcase(yyruleno==351);
{yygotominor.yy21 = parserContext->handleNumberToken(yymsp[0].minor.yy0->value);}
        break;
      case 83: /* term ::= FLOAT */
      case 352: /* number ::= FLOAT */ yytestcase(yyruleno==352);
{yygotominor.yy21 = new QVariant(QVariant(yymsp[0].minor.yy0->value).toDouble());}
        break;
      case 84: /* term ::= STRING|BLOB */
      case 345: /* nmnum ::= ON */ yytestcase(yyruleno==345);
      case 346: /* nmnum ::= DELETE */ yytestcase(yyruleno==346);
      case 347: /* nmnum ::= DEFAULT */ yytestcase(yyruleno==347);
{yygotominor.yy21 = new QVariant(yymsp[0].minor.yy0->value);}
        break;
      case 87: /* refargs ::= */
{yygotominor.yy108 = new ParserFkConditionList();}
        break;
      case 88: /* refargs ::= refargs refarg */
{
                                                yymsp[-1].minor.yy108->append(yymsp[0].minor.yy271);
                                                yygotominor.yy108 = yymsp[-1].minor.yy108;
                                                DONT_INHERIT_TOKENS("refargs");
                                            }
        break;
      case 89: /* refarg ::= MATCH nm */
{
                                                yygotominor.yy271 = new SqliteForeignKey::Condition(*(yymsp[0].minor.yy211));
                                                delete yymsp[0].minor.yy211;
                                            }
        break;
      case 90: /* refarg ::= ON INSERT refact */
{yygotominor.yy271 = new SqliteForeignKey::Condition(SqliteForeignKey::Condition::INSERT, *(yymsp[0].minor.yy312)); delete yymsp[0].minor.yy312;}
        break;
      case 91: /* refarg ::= ON DELETE refact */
{yygotominor.yy271 = new SqliteForeignKey::Condition(SqliteForeignKey::Condition::DELETE, *(yymsp[0].minor.yy312)); delete yymsp[0].minor.yy312;}
        break;
      case 92: /* refarg ::= ON UPDATE refact */
      case 93: /* refarg ::= MATCH ID_FK_MATCH */ yytestcase(yyruleno==93);
{yygotominor.yy271 = new SqliteForeignKey::Condition(SqliteForeignKey::Condition::UPDATE, *(yymsp[0].minor.yy312)); delete yymsp[0].minor.yy312;}
        break;
      case 94: /* refact ::= SET NULL */
{yygotominor.yy312 = new SqliteForeignKey::Condition::Reaction(SqliteForeignKey::Condition::SET_NULL);}
        break;
      case 95: /* refact ::= SET DEFAULT */
{yygotominor.yy312 = new SqliteForeignKey::Condition::Reaction(SqliteForeignKey::Condition::SET_DEFAULT);}
        break;
      case 96: /* refact ::= CASCADE */
{yygotominor.yy312 = new SqliteForeignKey::Condition::Reaction(SqliteForeignKey::Condition::CASCADE);}
        break;
      case 97: /* refact ::= RESTRICT */
{yygotominor.yy312 = new SqliteForeignKey::Condition::Reaction(SqliteForeignKey::Condition::RESTRICT);}
        break;
      case 98: /* refact ::= NO ACTION */
{yygotominor.yy312 = new SqliteForeignKey::Condition::Reaction(SqliteForeignKey::Condition::NO_ACTION);}
        break;
      case 99: /* defer_subclause ::= NOT DEFERRABLE init_deferred_pred_opt */
{
                                                yygotominor.yy131 = new ParserDeferSubClause(SqliteDeferrable::NOT_DEFERRABLE, *(yymsp[0].minor.yy498));
                                                delete yymsp[0].minor.yy498;
                                            }
        break;
      case 100: /* defer_subclause ::= DEFERRABLE init_deferred_pred_opt */
{
                                                yygotominor.yy131 = new ParserDeferSubClause(SqliteDeferrable::DEFERRABLE, *(yymsp[0].minor.yy498));
                                                delete yymsp[0].minor.yy498;
                                            }
        break;
      case 101: /* init_deferred_pred_opt ::= */
{yygotominor.yy498 = new SqliteInitially(SqliteInitially::null);}
        break;
      case 102: /* init_deferred_pred_opt ::= INITIALLY DEFERRED */
{yygotominor.yy498 = new SqliteInitially(SqliteInitially::DEFERRED);}
        break;
      case 103: /* init_deferred_pred_opt ::= INITIALLY IMMEDIATE */
{yygotominor.yy498 = new SqliteInitially(SqliteInitially::IMMEDIATE);}
        break;
      case 104: /* conslist_opt ::= */
{yygotominor.yy87 = new ParserCreateTableConstraintList();}
        break;
      case 105: /* conslist_opt ::= COMMA conslist */
{yygotominor.yy87 = yymsp[0].minor.yy87;}
        break;
      case 106: /* conslist ::= conslist tconscomma tcons */
{
                                                yymsp[0].minor.yy8->afterComma = *(yymsp[-1].minor.yy237);
                                                yymsp[-2].minor.yy87->append(yymsp[0].minor.yy8);
                                                yygotominor.yy87 = yymsp[-2].minor.yy87;
                                                delete yymsp[-1].minor.yy237;
                                                DONT_INHERIT_TOKENS("conslist");
                                            }
        break;
      case 107: /* conslist ::= tcons */
{
                                                yygotominor.yy87 = new ParserCreateTableConstraintList();
                                                yygotominor.yy87->append(yymsp[0].minor.yy8);
                                            }
        break;
      case 110: /* tcons ::= CONSTRAINT nm */
{
                                                yygotominor.yy8 = new SqliteCreateTable::Constraint();
                                                yygotominor.yy8->initNameOnly(*(yymsp[0].minor.yy211));
                                                delete yymsp[0].minor.yy211;
                                                objectForTokens = yygotominor.yy8;
                                            }
        break;
      case 111: /* tcons ::= PRIMARY KEY LP idxlist autoinc RP onconf */
{
                                                yygotominor.yy8 = new SqliteCreateTable::Constraint();
                                                yygotominor.yy8->initPk(*(yymsp[-3].minor.yy139), *(yymsp[-2].minor.yy237), *(yymsp[0].minor.yy30));
                                                delete yymsp[-2].minor.yy237;
                                                delete yymsp[0].minor.yy30;
                                                delete yymsp[-3].minor.yy139;
                                                objectForTokens = yygotominor.yy8;
                                            }
        break;
      case 112: /* tcons ::= UNIQUE LP idxlist RP onconf */
{
                                                yygotominor.yy8 = new SqliteCreateTable::Constraint();
                                                yygotominor.yy8->initUnique(*(yymsp[-2].minor.yy139), *(yymsp[0].minor.yy30));
                                                delete yymsp[0].minor.yy30;
                                                delete yymsp[-2].minor.yy139;
                                                objectForTokens = yygotominor.yy8;
                                            }
        break;
      case 113: /* tcons ::= CHECK LP expr RP onconf */
{
                                                yygotominor.yy8 = new SqliteCreateTable::Constraint();
                                                yygotominor.yy8->initCheck(yymsp[-2].minor.yy490, *(yymsp[0].minor.yy30));
                                                objectForTokens = yygotominor.yy8;
                                            }
        break;
      case 114: /* tcons ::= FOREIGN KEY LP idxlist RP REFERENCES nm idxlist_opt refargs defer_subclause_opt */
      case 115: /* tcons ::= CONSTRAINT ID_CONSTR */ yytestcase(yyruleno==115);
      case 116: /* tcons ::= FOREIGN KEY LP idxlist RP REFERENCES ID_TAB */ yytestcase(yyruleno==116);
{
                                                yygotominor.yy8 = new SqliteCreateTable::Constraint();
                                                yygotominor.yy8->initFk(
                                                    *(yymsp[-6].minor.yy139),
                                                    *(yymsp[-3].minor.yy211),
                                                    *(yymsp[-2].minor.yy139),
                                                    *(yymsp[-1].minor.yy108),
                                                    yymsp[0].minor.yy131->initially,
                                                    yymsp[0].minor.yy131->deferrable
                                                );
                                                delete yymsp[-3].minor.yy211;
                                                delete yymsp[-1].minor.yy108;
                                                delete yymsp[0].minor.yy131;
                                                delete yymsp[-2].minor.yy139;
                                                delete yymsp[-6].minor.yy139;
                                                objectForTokens = yygotominor.yy8;
                                            }
        break;
      case 117: /* tcons ::= CHECK LP RP onconf */
{
                                                yygotominor.yy8 = new SqliteCreateTable::Constraint();
                                                yygotominor.yy8->initCheck();
                                                objectForTokens = yygotominor.yy8;
                                                parserContext->minorErrorAfterLastToken("Syntax error");
                                              yy_destructor(yypParser,200,&yymsp[0].minor);
}
        break;
      case 118: /* defer_subclause_opt ::= */
{yygotominor.yy131 = new ParserDeferSubClause(SqliteDeferrable::null, SqliteInitially::null);}
        break;
      case 119: /* defer_subclause_opt ::= defer_subclause */
{yygotominor.yy131 = yymsp[0].minor.yy131;}
        break;
      case 120: /* onconf ::= */
      case 122: /* orconf ::= */ yytestcase(yyruleno==122);
{yygotominor.yy30 = new SqliteConflictAlgo(SqliteConflictAlgo::null);}
        break;
      case 121: /* onconf ::= ON CONFLICT resolvetype */
      case 123: /* orconf ::= OR resolvetype */ yytestcase(yyruleno==123);
{yygotominor.yy30 = yymsp[0].minor.yy30;}
        break;
      case 124: /* resolvetype ::= raisetype */
      case 125: /* resolvetype ::= IGNORE */ yytestcase(yyruleno==125);
      case 126: /* resolvetype ::= REPLACE */ yytestcase(yyruleno==126);
{yygotominor.yy30 = new SqliteConflictAlgo(sqliteConflictAlgo(yymsp[0].minor.yy0->value));}
        break;
      case 127: /* cmd ::= DROP TABLE ifexists fullname */
{
                                                yygotominor.yy399 = new SqliteDropTable(*(yymsp[-1].minor.yy237), yymsp[0].minor.yy66->name1, yymsp[0].minor.yy66->name2);
                                                delete yymsp[-1].minor.yy237;
                                                delete yymsp[0].minor.yy66;
                                                objectForTokens = yygotominor.yy399;
                                            }
        break;
      case 128: /* cmd ::= DROP TABLE ifexists nm DOT ID_TAB */
      case 129: /* cmd ::= DROP TABLE ifexists ID_DB|ID_TAB */ yytestcase(yyruleno==129);
      case 136: /* cmd ::= DROP VIEW ifexists nm DOT ID_VIEW */ yytestcase(yyruleno==136);
      case 137: /* cmd ::= DROP VIEW ifexists ID_DB|ID_VIEW */ yytestcase(yyruleno==137);
      case 178: /* singlesrc ::= nm DOT ID_TAB */ yytestcase(yyruleno==178);
      case 179: /* singlesrc ::= ID_DB|ID_TAB */ yytestcase(yyruleno==179);
      case 180: /* singlesrc ::= nm DOT ID_VIEW */ yytestcase(yyruleno==180);
      case 181: /* singlesrc ::= ID_DB|ID_VIEW */ yytestcase(yyruleno==181);
      case 259: /* exprx ::= nm DOT ID_TAB|ID_COL */ yytestcase(yyruleno==259);
      case 318: /* cmd ::= CREATE uniqueflag INDEX ifnotexists nm DOT ID_IDX_NEW */ yytestcase(yyruleno==318);
      case 319: /* cmd ::= CREATE uniqueflag INDEX ifnotexists ID_DB|ID_IDX_NEW */ yytestcase(yyruleno==319);
      case 332: /* cmd ::= DROP INDEX ifexists nm DOT ID_IDX */ yytestcase(yyruleno==332);
      case 333: /* cmd ::= DROP INDEX ifexists ID_DB|ID_IDX */ yytestcase(yyruleno==333);
      case 341: /* cmd ::= PRAGMA nm DOT ID_PRAGMA */ yytestcase(yyruleno==341);
      case 342: /* cmd ::= PRAGMA ID_DB|ID_PRAGMA */ yytestcase(yyruleno==342);
      case 380: /* cmd ::= DROP TRIGGER ifexists nm DOT ID_TRIG */ yytestcase(yyruleno==380);
      case 381: /* cmd ::= DROP TRIGGER ifexists ID_DB|ID_TRIG */ yytestcase(yyruleno==381);
      case 391: /* cmd ::= REINDEX nm DOT ID_TAB|ID_IDX */ yytestcase(yyruleno==391);
      case 392: /* cmd ::= REINDEX ID_DB|ID_IDX|ID_TAB */ yytestcase(yyruleno==392);
      case 395: /* cmd ::= ANALYZE nm DOT ID_TAB|ID_IDX */ yytestcase(yyruleno==395);
      case 396: /* cmd ::= ANALYZE ID_DB|ID_IDX|ID_TAB */ yytestcase(yyruleno==396);
      case 400: /* cmd ::= ALTER TABLE nm DOT ID_TAB */ yytestcase(yyruleno==400);
      case 401: /* cmd ::= ALTER TABLE ID_DB|ID_TAB */ yytestcase(yyruleno==401);
      case 407: /* create_vtab ::= CREATE VIRTUAL TABLE ifnotexists nm DOT ID_TAB_NEW */ yytestcase(yyruleno==407);
      case 408: /* create_vtab ::= CREATE VIRTUAL TABLE ifnotexists ID_DB|ID_TAB_NEW */ yytestcase(yyruleno==408);
{  yy_destructor(yypParser,177,&yymsp[-2].minor);
}
        break;
      case 132: /* cmd ::= CREATE temp VIEW ifnotexists fullname idxlist_opt AS select */
{
                                                yygotominor.yy399 = new SqliteCreateView(*(yymsp[-6].minor.yy376), *(yymsp[-4].minor.yy237), yymsp[-3].minor.yy66->name1, yymsp[-3].minor.yy66->name2, yymsp[0].minor.yy123, *(yymsp[-2].minor.yy139));
                                                delete yymsp[-6].minor.yy376;
                                                delete yymsp[-4].minor.yy237;
                                                delete yymsp[-3].minor.yy66;
                                                delete yymsp[-2].minor.yy139;
                                                objectForTokens = yygotominor.yy399;
                                            }
        break;
      case 135: /* cmd ::= DROP VIEW ifexists fullname */
{
                                                yygotominor.yy399 = new SqliteDropView(*(yymsp[-1].minor.yy237), yymsp[0].minor.yy66->name1, yymsp[0].minor.yy66->name2);
                                                delete yymsp[-1].minor.yy237;
                                                delete yymsp[0].minor.yy66;
                                                objectForTokens = yygotominor.yy399;
                                            }
        break;
      case 138: /* cmd ::= select_stmt */
      case 214: /* cmd ::= delete_stmt */ yytestcase(yyruleno==214);
      case 223: /* cmd ::= update_stmt */ yytestcase(yyruleno==223);
      case 235: /* cmd ::= insert_stmt */ yytestcase(yyruleno==235);
{
                                                yygotominor.yy399 = yymsp[0].minor.yy399;
                                                objectForTokens = yygotominor.yy399;
                                            }
        break;
      case 139: /* select_stmt ::= select */
{
                                                yygotominor.yy399 = yymsp[0].minor.yy123;
                                                // since it's used in trigger:
                                                objectForTokens = yygotominor.yy399;
                                            }
        break;
      case 140: /* select ::= with selectnowith */
{
                                                yygotominor.yy123 = yymsp[0].minor.yy123;
                                                yymsp[0].minor.yy123->setWith(yymsp[-1].minor.yy367);
                                                objectForTokens = yygotominor.yy123;
                                            }
        break;
      case 141: /* selectnowith ::= oneselect */
{
                                                yygotominor.yy123 = SqliteSelect::append(yymsp[0].minor.yy468);
                                                objectForTokens = yygotominor.yy123;
                                            }
        break;
      case 142: /* selectnowith ::= selectnowith multiselect_op oneselect */
{
                                                yygotominor.yy123 = SqliteSelect::append(yymsp[-2].minor.yy123, *(yymsp[-1].minor.yy168), yymsp[0].minor.yy468);
                                                delete yymsp[-1].minor.yy168;
                                                objectForTokens = yygotominor.yy123;
                                            }
        break;
      case 143: /* selectnowith ::= values */
{
                                                yygotominor.yy123 = SqliteSelect::append(*(yymsp[0].minor.yy416));
                                                delete yymsp[0].minor.yy416;
                                                objectForTokens = yygotominor.yy123;
                                            }
        break;
      case 144: /* selectnowith ::= selectnowith COMMA values */
{
                                                yygotominor.yy123 = SqliteSelect::append(yymsp[-2].minor.yy123, SqliteSelect::CompoundOperator::UNION_ALL, *(yymsp[0].minor.yy416));
                                                delete yymsp[0].minor.yy416;
                                                objectForTokens = yygotominor.yy123;
                                            }
        break;
      case 145: /* multiselect_op ::= UNION */
{yygotominor.yy168 = new SqliteSelect::CompoundOperator(SqliteSelect::CompoundOperator::UNION);}
        break;
      case 146: /* multiselect_op ::= UNION ALL */
{yygotominor.yy168 = new SqliteSelect::CompoundOperator(SqliteSelect::CompoundOperator::UNION_ALL);}
        break;
      case 147: /* multiselect_op ::= EXCEPT */
{yygotominor.yy168 = new SqliteSelect::CompoundOperator(SqliteSelect::CompoundOperator::EXCEPT);}
        break;
      case 148: /* multiselect_op ::= INTERSECT */
{yygotominor.yy168 = new SqliteSelect::CompoundOperator(SqliteSelect::CompoundOperator::INTERSECT);}
        break;
      case 149: /* oneselect ::= SELECT distinct selcollist from where_opt groupby_opt having_opt orderby_opt limit_opt */
{
                                                yygotominor.yy468 = new SqliteSelect::Core(
                                                        *(yymsp[-7].minor.yy376),
                                                        *(yymsp[-6].minor.yy263),
                                                        yymsp[-5].minor.yy373,
                                                        yymsp[-4].minor.yy490,
                                                        *(yymsp[-3].minor.yy13),
                                                        yymsp[-2].minor.yy490,
                                                        *(yymsp[-1].minor.yy495),
                                                        yymsp[0].minor.yy128
                                                    );
                                                delete yymsp[-6].minor.yy263;
                                                delete yymsp[-7].minor.yy376;
                                                delete yymsp[-3].minor.yy13;
                                                delete yymsp[-1].minor.yy495;
                                                objectForTokens = yygotominor.yy468;
                                            }
        break;
      case 150: /* values ::= VALUES LP nexprlist RP */
{
                                                yygotominor.yy416 = new ParserExprNestedList();
                                                yygotominor.yy416->append(*(yymsp[-1].minor.yy13));
                                                delete yymsp[-1].minor.yy13;
                                            }
        break;
      case 151: /* values ::= values COMMA LP exprlist RP */
{
                                                yymsp[-4].minor.yy416->append(*(yymsp[-1].minor.yy13));
                                                yygotominor.yy416 = yymsp[-4].minor.yy416;
                                                delete yymsp[-1].minor.yy13;
                                                DONT_INHERIT_TOKENS("values");
                                            }
        break;
      case 152: /* distinct ::= DISTINCT */
{yygotominor.yy376 = new int(1);}
        break;
      case 153: /* distinct ::= ALL */
{yygotominor.yy376 = new int(2);}
        break;
      case 155: /* sclp ::= selcollist COMMA */
{yygotominor.yy263 = yymsp[-1].minor.yy263;}
        break;
      case 156: /* sclp ::= */
{yygotominor.yy263 = new ParserResultColumnList();}
        break;
      case 157: /* selcollist ::= sclp expr as */
{
                                                SqliteSelect::Core::ResultColumn* obj =
                                                    new SqliteSelect::Core::ResultColumn(
                                                        yymsp[-1].minor.yy490,
                                                        yymsp[0].minor.yy28 ? yymsp[0].minor.yy28->asKw : false,
                                                        yymsp[0].minor.yy28 ? yymsp[0].minor.yy28->name : QString::null
                                                    );

                                                yymsp[-2].minor.yy263->append(obj);
                                                yygotominor.yy263 = yymsp[-2].minor.yy263;
                                                delete yymsp[0].minor.yy28;
                                                objectForTokens = obj;
                                                DONT_INHERIT_TOKENS("sclp");
                                            }
        break;
      case 158: /* selcollist ::= sclp STAR */
{
                                                SqliteSelect::Core::ResultColumn* obj =
                                                    new SqliteSelect::Core::ResultColumn(true);

                                                yymsp[-1].minor.yy263->append(obj);
                                                yygotominor.yy263 = yymsp[-1].minor.yy263;
                                                objectForTokens = obj;
                                                DONT_INHERIT_TOKENS("sclp");
                                            }
        break;
      case 159: /* selcollist ::= sclp nm DOT STAR */
{
                                                SqliteSelect::Core::ResultColumn* obj =
                                                    new SqliteSelect::Core::ResultColumn(
                                                        true,
                                                        *(yymsp[-2].minor.yy211)
                                                    );
                                                yymsp[-3].minor.yy263->append(obj);
                                                yygotominor.yy263 = yymsp[-3].minor.yy263;
                                                delete yymsp[-2].minor.yy211;
                                                objectForTokens = obj;
                                                DONT_INHERIT_TOKENS("sclp");
                                            }
        break;
      case 160: /* selcollist ::= sclp */
      case 161: /* selcollist ::= sclp ID_TAB DOT STAR */ yytestcase(yyruleno==161);
{
                                                parserContext->minorErrorBeforeNextToken("Syntax error");
                                                yygotominor.yy263 = yymsp[0].minor.yy263;
                                            }
        break;
      case 162: /* as ::= AS nm */
{
                                                yygotominor.yy28 = new ParserStubAlias(*(yymsp[0].minor.yy211), true);
                                                delete yymsp[0].minor.yy211;
                                            }
        break;
      case 163: /* as ::= ids */
      case 164: /* as ::= AS ID_ALIAS */ yytestcase(yyruleno==164);
      case 165: /* as ::= ID_ALIAS */ yytestcase(yyruleno==165);
{
                                                yygotominor.yy28 = new ParserStubAlias(*(yymsp[0].minor.yy211), false);
                                                delete yymsp[0].minor.yy211;
                                            }
        break;
      case 166: /* as ::= */
{yygotominor.yy28 = nullptr;}
        break;
      case 167: /* from ::= */
{yygotominor.yy373 = nullptr;}
        break;
      case 168: /* from ::= FROM joinsrc */
{yygotominor.yy373 = yymsp[0].minor.yy373;}
        break;
      case 169: /* joinsrc ::= singlesrc seltablist */
{
                                                yygotominor.yy373 = new SqliteSelect::Core::JoinSource(
                                                        yymsp[-1].minor.yy173,
                                                        *(yymsp[0].minor.yy359)
                                                    );
                                                delete yymsp[0].minor.yy359;
                                                objectForTokens = yygotominor.yy373;
                                            }
        break;
      case 170: /* joinsrc ::= */
{
                                                parserContext->minorErrorBeforeNextToken("Syntax error");
                                                yygotominor.yy373 = new SqliteSelect::Core::JoinSource();
                                                objectForTokens = yygotominor.yy373;
                                            }
        break;
      case 171: /* seltablist ::= seltablist joinop singlesrc joinconstr_opt */
{
                                                SqliteSelect::Core::JoinSourceOther* src =
                                                    new SqliteSelect::Core::JoinSourceOther(yymsp[-2].minor.yy473, yymsp[-1].minor.yy173, yymsp[0].minor.yy117);

                                                yymsp[-3].minor.yy359->append(src);
                                                yygotominor.yy359 = yymsp[-3].minor.yy359;
                                                objectForTokens = src;
                                                DONT_INHERIT_TOKENS("seltablist");
                                            }
        break;
      case 172: /* seltablist ::= */
{
                                                yygotominor.yy359 = new ParserOtherSourceList();
                                            }
        break;
      case 173: /* singlesrc ::= nm dbnm as indexed_opt */
{
                                                yygotominor.yy173 = new SqliteSelect::Core::SingleSource(
                                                        *(yymsp[-3].minor.yy211),
                                                        *(yymsp[-2].minor.yy211),
                                                        yymsp[-1].minor.yy28 ? yymsp[-1].minor.yy28->asKw : false,
                                                        yymsp[-1].minor.yy28 ? yymsp[-1].minor.yy28->name : QString::null,
                                                        yymsp[0].minor.yy472 ? yymsp[0].minor.yy472->notIndexedKw : false,
                                                        yymsp[0].minor.yy472 ? yymsp[0].minor.yy472->indexedBy : QString::null
                                                    );
                                                delete yymsp[-3].minor.yy211;
                                                delete yymsp[-2].minor.yy211;
                                                delete yymsp[-1].minor.yy28;
                                                if (yymsp[0].minor.yy472)
                                                    delete yymsp[0].minor.yy472;
                                                objectForTokens = yygotominor.yy173;
                                            }
        break;
      case 174: /* singlesrc ::= LP select RP as */
{
                                                yygotominor.yy173 = new SqliteSelect::Core::SingleSource(
                                                        yymsp[-2].minor.yy123,
                                                        yymsp[0].minor.yy28 ? yymsp[0].minor.yy28->asKw : false,
                                                        yymsp[0].minor.yy28 ? yymsp[0].minor.yy28->name : QString::null
                                                    );
                                                delete yymsp[0].minor.yy28;
                                                objectForTokens = yygotominor.yy173;
                                            }
        break;
      case 175: /* singlesrc ::= LP joinsrc RP as */
{
                                                yygotominor.yy173 = new SqliteSelect::Core::SingleSource(
                                                        yymsp[-2].minor.yy373,
                                                        yymsp[0].minor.yy28 ? yymsp[0].minor.yy28->asKw : false,
                                                        yymsp[0].minor.yy28 ? yymsp[0].minor.yy28->name : QString::null
                                                    );
                                                delete yymsp[0].minor.yy28;
                                                objectForTokens = yygotominor.yy173;
                                            }
        break;
      case 176: /* singlesrc ::= */
{
                                                parserContext->minorErrorBeforeNextToken("Syntax error");
                                                yygotominor.yy173 = new SqliteSelect::Core::SingleSource();
                                                objectForTokens = yygotominor.yy173;
                                            }
        break;
      case 177: /* singlesrc ::= nm DOT */
{
                                                parserContext->minorErrorBeforeNextToken("Syntax error");
                                                yygotominor.yy173 = new SqliteSelect::Core::SingleSource();
                                                yygotominor.yy173->database = *(yymsp[-1].minor.yy211);
                                                delete yymsp[-1].minor.yy211;
                                                objectForTokens = yygotominor.yy173;
                                            }
        break;
      case 182: /* joinconstr_opt ::= ON expr */
{
                                                yygotominor.yy117 = new SqliteSelect::Core::JoinConstraint(yymsp[0].minor.yy490);
                                                objectForTokens = yygotominor.yy117;
                                            }
        break;
      case 183: /* joinconstr_opt ::= USING LP inscollist RP */
{
                                                yygotominor.yy117 = new SqliteSelect::Core::JoinConstraint(*(yymsp[-1].minor.yy445));
                                                delete yymsp[-1].minor.yy445;
                                                objectForTokens = yygotominor.yy117;
                                            }
        break;
      case 184: /* joinconstr_opt ::= */
{yygotominor.yy117 = nullptr;}
        break;
      case 187: /* fullname ::= nm dbnm */
{
                                                yygotominor.yy66 = new ParserFullName();
                                                yygotominor.yy66->name1 = *(yymsp[-1].minor.yy211);
                                                yygotominor.yy66->name2 = *(yymsp[0].minor.yy211);
                                                delete yymsp[-1].minor.yy211;
                                                delete yymsp[0].minor.yy211;
                                            }
        break;
      case 188: /* joinop ::= COMMA */
{
                                                yygotominor.yy473 = new SqliteSelect::Core::JoinOp(true);
                                                objectForTokens = yygotominor.yy473;
                                            }
        break;
      case 189: /* joinop ::= JOIN */
{
                                                yygotominor.yy473 = new SqliteSelect::Core::JoinOp(false);
                                                objectForTokens = yygotominor.yy473;
                                            }
        break;
      case 190: /* joinop ::= JOIN_KW JOIN */
{
                                                yygotominor.yy473 = new SqliteSelect::Core::JoinOp(yymsp[-1].minor.yy0->value);
                                                objectForTokens = yygotominor.yy473;
                                            }
        break;
      case 191: /* joinop ::= JOIN_KW nm JOIN */
{
                                                yygotominor.yy473 = new SqliteSelect::Core::JoinOp(yymsp[-2].minor.yy0->value, *(yymsp[-1].minor.yy211));
                                                delete yymsp[-1].minor.yy211;
                                                objectForTokens = yygotominor.yy473;
                                            }
        break;
      case 192: /* joinop ::= JOIN_KW nm nm JOIN */
      case 193: /* joinop ::= ID_JOIN_OPTS */ yytestcase(yyruleno==193);
{
                                                yygotominor.yy473 = new SqliteSelect::Core::JoinOp(yymsp[-3].minor.yy0->value, *(yymsp[-2].minor.yy211), *(yymsp[-1].minor.yy211));
                                                delete yymsp[-2].minor.yy211;
                                                delete yymsp[-2].minor.yy211;
                                                objectForTokens = yygotominor.yy473;
                                            }
        break;
      case 194: /* indexed_opt ::= */
{yygotominor.yy472 = nullptr;}
        break;
      case 195: /* indexed_opt ::= INDEXED BY nm */
{
                                                yygotominor.yy472 = new ParserIndexedBy(*(yymsp[0].minor.yy211));
                                                delete yymsp[0].minor.yy211;
                                            }
        break;
      case 196: /* indexed_opt ::= NOT INDEXED */
      case 197: /* indexed_opt ::= INDEXED BY ID_IDX */ yytestcase(yyruleno==197);
{yygotominor.yy472 = new ParserIndexedBy(true);}
        break;
      case 198: /* orderby_opt ::= */
{yygotominor.yy495 = new ParserOrderByList();}
        break;
      case 199: /* orderby_opt ::= ORDER BY sortlist */
{yygotominor.yy495 = yymsp[0].minor.yy495;}
        break;
      case 200: /* sortlist ::= sortlist COMMA expr sortorder */
{
                                                SqliteOrderBy* obj = new SqliteOrderBy(yymsp[-1].minor.yy490, *(yymsp[0].minor.yy226));
                                                yymsp[-3].minor.yy495->append(obj);
                                                yygotominor.yy495 = yymsp[-3].minor.yy495;
                                                delete yymsp[0].minor.yy226;
                                                objectForTokens = obj;
                                                DONT_INHERIT_TOKENS("sortlist");
                                            }
        break;
      case 201: /* sortlist ::= expr sortorder */
{
                                                SqliteOrderBy* obj = new SqliteOrderBy(yymsp[-1].minor.yy490, *(yymsp[0].minor.yy226));
                                                yygotominor.yy495 = new ParserOrderByList();
                                                yygotominor.yy495->append(obj);
                                                delete yymsp[0].minor.yy226;
                                                objectForTokens = obj;
                                            }
        break;
      case 202: /* sortorder ::= ASC */
{yygotominor.yy226 = new SqliteSortOrder(SqliteSortOrder::ASC);}
        break;
      case 203: /* sortorder ::= DESC */
{yygotominor.yy226 = new SqliteSortOrder(SqliteSortOrder::DESC);}
        break;
      case 204: /* sortorder ::= */
{yygotominor.yy226 = new SqliteSortOrder(SqliteSortOrder::null);}
        break;
      case 205: /* groupby_opt ::= */
      case 313: /* exprlist ::= */ yytestcase(yyruleno==313);
{yygotominor.yy13 = new ParserExprList();}
        break;
      case 206: /* groupby_opt ::= GROUP BY nexprlist */
      case 312: /* exprlist ::= nexprlist */ yytestcase(yyruleno==312);
{yygotominor.yy13 = yymsp[0].minor.yy13;}
        break;
      case 207: /* groupby_opt ::= GROUP BY */
{
                                                parserContext->minorErrorBeforeNextToken("Syntax error");
                                                yygotominor.yy13 = new ParserExprList();
                                            }
        break;
      case 208: /* having_opt ::= */
      case 220: /* where_opt ::= */ yytestcase(yyruleno==220);
      case 309: /* case_else ::= */ yytestcase(yyruleno==309);
      case 311: /* case_operand ::= */ yytestcase(yyruleno==311);
      case 369: /* when_clause ::= */ yytestcase(yyruleno==369);
      case 384: /* key_opt ::= */ yytestcase(yyruleno==384);
{yygotominor.yy490 = nullptr;}
        break;
      case 209: /* having_opt ::= HAVING expr */
      case 221: /* where_opt ::= WHERE expr */ yytestcase(yyruleno==221);
      case 302: /* expr ::= exprx */ yytestcase(yyruleno==302);
      case 308: /* case_else ::= ELSE expr */ yytestcase(yyruleno==308);
      case 310: /* case_operand ::= exprx */ yytestcase(yyruleno==310);
      case 370: /* when_clause ::= WHEN expr */ yytestcase(yyruleno==370);
      case 385: /* key_opt ::= KEY expr */ yytestcase(yyruleno==385);
{yygotominor.yy490 = yymsp[0].minor.yy490;}
        break;
      case 210: /* limit_opt ::= */
{yygotominor.yy128 = nullptr;}
        break;
      case 211: /* limit_opt ::= LIMIT expr */
{
                                                yygotominor.yy128 = new SqliteLimit(yymsp[0].minor.yy490);
                                                objectForTokens = yygotominor.yy128;
                                            }
        break;
      case 212: /* limit_opt ::= LIMIT expr OFFSET expr */
{
                                                yygotominor.yy128 = new SqliteLimit(yymsp[-2].minor.yy490, yymsp[0].minor.yy490, true);
                                                objectForTokens = yygotominor.yy128;
                                            }
        break;
      case 213: /* limit_opt ::= LIMIT expr COMMA expr */
{
                                                yygotominor.yy128 = new SqliteLimit(yymsp[-2].minor.yy490, yymsp[0].minor.yy490, false);
                                                objectForTokens = yygotominor.yy128;
                                            }
        break;
      case 215: /* delete_stmt ::= with DELETE FROM fullname indexed_opt where_opt */
{
                                                if (yymsp[-1].minor.yy472)
                                                {
                                                    if (!yymsp[-1].minor.yy472->indexedBy.isNull())
                                                    {
                                                        yygotominor.yy399 = new SqliteDelete(
                                                                yymsp[-2].minor.yy66->name1,
                                                                yymsp[-2].minor.yy66->name2,
                                                                yymsp[-1].minor.yy472->indexedBy,
                                                                yymsp[0].minor.yy490,
                                                                yymsp[-5].minor.yy367
                                                            );
                                                    }
                                                    else
                                                    {
                                                        yygotominor.yy399 = new SqliteDelete(
                                                                yymsp[-2].minor.yy66->name1,
                                                                yymsp[-2].minor.yy66->name2,
                                                                yymsp[-1].minor.yy472->notIndexedKw,
                                                                yymsp[0].minor.yy490,
                                                                yymsp[-5].minor.yy367
                                                            );
                                                    }
                                                    delete yymsp[-1].minor.yy472;
                                                }
                                                else
                                                {
                                                    yygotominor.yy399 = new SqliteDelete(
                                                            yymsp[-2].minor.yy66->name1,
                                                            yymsp[-2].minor.yy66->name2,
                                                            false,
                                                            yymsp[0].minor.yy490,
                                                            yymsp[-5].minor.yy367
                                                        );
                                                }
                                                delete yymsp[-2].minor.yy66;
                                                // since it's used in trigger:
                                                objectForTokens = yygotominor.yy399;
                                            }
        break;
      case 216: /* delete_stmt ::= with DELETE FROM */
{
                                                parserContext->minorErrorBeforeNextToken("Syntax error");
                                                SqliteDelete* q = new SqliteDelete();
                                                q->with = yymsp[-2].minor.yy367;
                                                yygotominor.yy399 = q;
                                                objectForTokens = yygotominor.yy399;
                                            }
        break;
      case 217: /* delete_stmt ::= with DELETE FROM nm DOT */
{
                                                parserContext->minorErrorBeforeNextToken("Syntax error");
                                                SqliteDelete* q = new SqliteDelete();
                                                q->with = yymsp[-4].minor.yy367;
                                                q->database = *(yymsp[-1].minor.yy211);
                                                yygotominor.yy399 = q;
                                                objectForTokens = yygotominor.yy399;
                                                delete yymsp[-1].minor.yy211;
                                            }
        break;
      case 218: /* delete_stmt ::= with DELETE FROM nm DOT ID_TAB */
      case 227: /* update_stmt ::= with UPDATE orconf nm DOT ID_TAB */ yytestcase(yyruleno==227);
{  yy_destructor(yypParser,219,&yymsp[-5].minor);
  yy_destructor(yypParser,177,&yymsp[-2].minor);
}
        break;
      case 219: /* delete_stmt ::= with DELETE FROM ID_DB|ID_TAB */
      case 228: /* update_stmt ::= with UPDATE orconf ID_DB|ID_TAB */ yytestcase(yyruleno==228);
{  yy_destructor(yypParser,219,&yymsp[-3].minor);
}
        break;
      case 222: /* where_opt ::= WHERE */
{
                                                parserContext->minorErrorBeforeNextToken("Syntax error");
                                                yygotominor.yy490 = new SqliteExpr();
                                            }
        break;
      case 224: /* update_stmt ::= with UPDATE orconf fullname indexed_opt SET setlist where_opt */
{
                                                yygotominor.yy399 = new SqliteUpdate(
                                                        *(yymsp[-5].minor.yy30),
                                                        yymsp[-4].minor.yy66->name1,
                                                        yymsp[-4].minor.yy66->name2,
                                                        yymsp[-3].minor.yy472 ? yymsp[-3].minor.yy472->notIndexedKw : false,
                                                        yymsp[-3].minor.yy472 ? yymsp[-3].minor.yy472->indexedBy : QString::null,
                                                        *(yymsp[-1].minor.yy381),
                                                        yymsp[0].minor.yy490,
                                                        yymsp[-7].minor.yy367
                                                    );
                                                delete yymsp[-5].minor.yy30;
                                                delete yymsp[-4].minor.yy66;
                                                delete yymsp[-1].minor.yy381;
                                                if (yymsp[-3].minor.yy472)
                                                    delete yymsp[-3].minor.yy472;
                                                // since it's used in trigger:
                                                objectForTokens = yygotominor.yy399;
                                            }
        break;
      case 225: /* update_stmt ::= with UPDATE orconf */
{
                                                parserContext->minorErrorBeforeNextToken("Syntax error");
                                                SqliteUpdate* q = new SqliteUpdate();
                                                q->with = yymsp[-2].minor.yy367;
                                                yygotominor.yy399 = q;
                                                objectForTokens = yygotominor.yy399;
                                                delete yymsp[0].minor.yy30;
                                            }
        break;
      case 226: /* update_stmt ::= with UPDATE orconf nm DOT */
{
                                                parserContext->minorErrorBeforeNextToken("Syntax error");
                                                SqliteUpdate* q = new SqliteUpdate();
                                                q->with = yymsp[-4].minor.yy367;
                                                q->database = *(yymsp[-1].minor.yy211);
                                                yygotominor.yy399 = q;
                                                objectForTokens = yygotominor.yy399;
                                                delete yymsp[-2].minor.yy30;
                                                delete yymsp[-1].minor.yy211;
                                            }
        break;
      case 229: /* setlist ::= setlist COMMA nm EQ expr */
{
                                                yymsp[-4].minor.yy381->append(ParserSetValue(*(yymsp[-2].minor.yy211), yymsp[0].minor.yy490));
                                                yygotominor.yy381 = yymsp[-4].minor.yy381;
                                                delete yymsp[-2].minor.yy211;
                                                DONT_INHERIT_TOKENS("setlist");
                                            }
        break;
      case 230: /* setlist ::= nm EQ expr */
{
                                                yygotominor.yy381 = new ParserSetValueList();
                                                yygotominor.yy381->append(ParserSetValue(*(yymsp[-2].minor.yy211), yymsp[0].minor.yy490));
                                                delete yymsp[-2].minor.yy211;
                                            }
        break;
      case 231: /* setlist ::= */
{
                                                parserContext->minorErrorBeforeNextToken("Syntax error");
                                                yygotominor.yy381 = new ParserSetValueList();
                                            }
        break;
      case 232: /* setlist ::= setlist COMMA */
{
                                                parserContext->minorErrorBeforeNextToken("Syntax error");
                                                yygotominor.yy381 = yymsp[-1].minor.yy381;
                                            }
        break;
      case 233: /* setlist ::= setlist COMMA ID_COL */
      case 234: /* setlist ::= ID_COL */ yytestcase(yyruleno==234);
{  yy_destructor(yypParser,247,&yymsp[-2].minor);
}
        break;
      case 236: /* insert_stmt ::= with insert_cmd INTO fullname inscollist_opt select */
{
                                                yygotominor.yy399 = new SqliteInsert(
                                                        yymsp[-4].minor.yy250->replace,
                                                        yymsp[-4].minor.yy250->orConflict,
                                                        yymsp[-2].minor.yy66->name1,
                                                        yymsp[-2].minor.yy66->name2,
                                                        *(yymsp[-1].minor.yy445),
                                                        yymsp[0].minor.yy123,
                                                        yymsp[-5].minor.yy367
                                                    );
                                                delete yymsp[-2].minor.yy66;
                                                delete yymsp[-4].minor.yy250;
                                                delete yymsp[-1].minor.yy445;
                                                // since it's used in trigger:
                                                objectForTokens = yygotominor.yy399;
                                            }
        break;
      case 237: /* insert_stmt ::= with insert_cmd INTO fullname inscollist_opt DEFAULT VALUES */
{
                                                yygotominor.yy399 = new SqliteInsert(
                                                        yymsp[-5].minor.yy250->replace,
                                                        yymsp[-5].minor.yy250->orConflict,
                                                        yymsp[-3].minor.yy66->name1,
                                                        yymsp[-3].minor.yy66->name2,
                                                        *(yymsp[-2].minor.yy445),
                                                        yymsp[-6].minor.yy367
                                                    );
                                                delete yymsp[-3].minor.yy66;
                                                delete yymsp[-5].minor.yy250;
                                                delete yymsp[-2].minor.yy445;
                                                // since it's used in trigger:
                                                objectForTokens = yygotominor.yy399;
                                            }
        break;
      case 238: /* insert_stmt ::= with insert_cmd INTO */
{
                                                parserContext->minorErrorBeforeNextToken("Syntax error");
                                                SqliteInsert* q = new SqliteInsert();
                                                q->replaceKw = yymsp[-1].minor.yy250->replace;
                                                q->onConflict = yymsp[-1].minor.yy250->orConflict;
                                                q->with = yymsp[-2].minor.yy367;
                                                yygotominor.yy399 = q;
                                                objectForTokens = yygotominor.yy399;
                                                delete yymsp[-1].minor.yy250;
                                            }
        break;
      case 239: /* insert_stmt ::= with insert_cmd INTO nm DOT */
{
                                                parserContext->minorErrorBeforeNextToken("Syntax error");
                                                SqliteInsert* q = new SqliteInsert();
                                                q->replaceKw = yymsp[-3].minor.yy250->replace;
                                                q->onConflict = yymsp[-3].minor.yy250->orConflict;
                                                q->with = yymsp[-4].minor.yy367;
                                                q->database = *(yymsp[-1].minor.yy211);
                                                yygotominor.yy399 = q;
                                                objectForTokens = yygotominor.yy399;
                                                delete yymsp[-3].minor.yy250;
                                                delete yymsp[-1].minor.yy211;
                                            }
        break;
      case 240: /* insert_stmt ::= with insert_cmd INTO ID_DB|ID_TAB */
{  yy_destructor(yypParser,219,&yymsp[-3].minor);
  yy_destructor(yypParser,249,&yymsp[-2].minor);
}
        break;
      case 241: /* insert_stmt ::= with insert_cmd INTO nm DOT ID_TAB */
{  yy_destructor(yypParser,219,&yymsp[-5].minor);
  yy_destructor(yypParser,249,&yymsp[-4].minor);
  yy_destructor(yypParser,177,&yymsp[-2].minor);
}
        break;
      case 242: /* insert_cmd ::= INSERT orconf */
{
                                                yygotominor.yy250 = new ParserStubInsertOrReplace(false, *(yymsp[0].minor.yy30));
                                                delete yymsp[0].minor.yy30;
                                            }
        break;
      case 243: /* insert_cmd ::= REPLACE */
{yygotominor.yy250 = new ParserStubInsertOrReplace(true);}
        break;
      case 244: /* inscollist_opt ::= */
{yygotominor.yy445 = new ParserStringList();}
        break;
      case 245: /* inscollist_opt ::= LP inscollist RP */
{yygotominor.yy445 = yymsp[-1].minor.yy445;}
        break;
      case 246: /* inscollist ::= inscollist COMMA nm */
{
                                                yymsp[-2].minor.yy445->append(*(yymsp[0].minor.yy211));
                                                yygotominor.yy445 = yymsp[-2].minor.yy445;
                                                delete yymsp[0].minor.yy211;
                                                DONT_INHERIT_TOKENS("inscollist");
                                            }
        break;
      case 247: /* inscollist ::= nm */
{
                                                yygotominor.yy445 = new ParserStringList();
                                                yygotominor.yy445->append(*(yymsp[0].minor.yy211));
                                                delete yymsp[0].minor.yy211;
                                            }
        break;
      case 248: /* inscollist ::= */
{
                                                parserContext->minorErrorBeforeNextToken("Syntax error");
                                                yygotominor.yy445 = new ParserStringList();
                                            }
        break;
      case 249: /* inscollist ::= inscollist COMMA ID_COL */
      case 250: /* inscollist ::= ID_COL */ yytestcase(yyruleno==250);
{  yy_destructor(yypParser,243,&yymsp[-2].minor);
}
        break;
      case 251: /* exprx ::= nm DOT */
{
                                                yygotominor.yy490 = new SqliteExpr();
                                                yygotominor.yy490->initId(*(yymsp[-1].minor.yy211), QString::null, QString::null);
                                                delete yymsp[-1].minor.yy211;
                                                objectForTokens = yygotominor.yy490;
                                                parserContext->minorErrorBeforeNextToken("Syntax error <exprx: nm.>");
                                            }
        break;
      case 252: /* exprx ::= nm DOT nm DOT */
{
                                                yygotominor.yy490 = new SqliteExpr();
                                                yygotominor.yy490->initId(*(yymsp[-3].minor.yy211), *(yymsp[-1].minor.yy211), QString::null);
                                                delete yymsp[-3].minor.yy211;
                                                delete yymsp[-1].minor.yy211;
                                                objectForTokens = yygotominor.yy490;
                                                parserContext->minorErrorBeforeNextToken("Syntax error <exprx: nm.nm.>");
                                            }
        break;
      case 253: /* exprx ::= expr not_opt BETWEEN expr AND */
{
                                                yygotominor.yy490 = new SqliteExpr();
                                                delete yymsp[-3].minor.yy237;
                                                delete yymsp[-4].minor.yy490;
                                                delete yymsp[-1].minor.yy490;
                                                objectForTokens = yygotominor.yy490;
                                                parserContext->minorErrorBeforeNextToken("Syntax error <exprx: expr not_opt BETWEEN expr AND>");
                                            }
        break;
      case 254: /* exprx ::= CASE case_operand case_exprlist case_else */
{
                                                yygotominor.yy490 = new SqliteExpr();
                                                delete yymsp[-1].minor.yy13;
                                                delete yymsp[-2].minor.yy490;
                                                delete yymsp[0].minor.yy490;
                                                objectForTokens = yygotominor.yy490;
                                                parserContext->minorErrorBeforeNextToken("Syntax error <exprx: CASE operand exprlist else>");
                                            }
        break;
      case 255: /* exprx ::= expr not_opt IN LP exprlist */
{
                                                yygotominor.yy490 = new SqliteExpr();
                                                delete yymsp[-3].minor.yy237;
                                                delete yymsp[0].minor.yy13;
                                                delete yymsp[-4].minor.yy490;
                                                objectForTokens = yygotominor.yy490;
                                                parserContext->minorErrorBeforeNextToken("Syntax error <exprx: expr not_opt IN LP exprlist>");
                                            }
        break;
      case 256: /* exprx ::= expr not_opt IN ID_DB */
{  yy_destructor(yypParser,199,&yymsp[-3].minor);
}
        break;
      case 257: /* exprx ::= expr not_opt IN nm DOT ID_TAB */
      case 258: /* exprx ::= ID_DB|ID_TAB|ID_COL|ID_FN */ yytestcase(yyruleno==258);
{  yy_destructor(yypParser,199,&yymsp[-5].minor);
  yy_destructor(yypParser,177,&yymsp[-2].minor);
}
        break;
      case 260: /* exprx ::= nm DOT nm DOT ID_COL */
{  yy_destructor(yypParser,177,&yymsp[-4].minor);
  yy_destructor(yypParser,177,&yymsp[-2].minor);
}
        break;
      case 261: /* exprx ::= expr COLLATE ID_COLLATE */
      case 262: /* exprx ::= RAISE LP raisetype COMMA ID_ERR_MSG RP */ yytestcase(yyruleno==262);
{  yy_destructor(yypParser,199,&yymsp[-2].minor);
}
        break;
      case 263: /* exprx ::= term */
{
                                                yygotominor.yy490 = new SqliteExpr();
                                                yygotominor.yy490->initLiteral(*(yymsp[0].minor.yy21));
                                                delete yymsp[0].minor.yy21;
                                                objectForTokens = yygotominor.yy490;
                                            }
        break;
      case 264: /* exprx ::= CTIME_KW */
{
                                                yygotominor.yy490 = new SqliteExpr();
                                                yygotominor.yy490->initCTime(yymsp[0].minor.yy0->value);
                                                objectForTokens = yygotominor.yy490;
                                            }
        break;
      case 265: /* exprx ::= LP nexprlist RP */
{
                                                yygotominor.yy490 = new SqliteExpr();
                                                yygotominor.yy490->initRowValue(*(yymsp[-1].minor.yy13));
                                                delete yymsp[-1].minor.yy13;
                                                objectForTokens = yygotominor.yy490;
                                            }
        break;
      case 266: /* exprx ::= id */
{
                                                yygotominor.yy490 = new SqliteExpr();
                                                yygotominor.yy490->initId(*(yymsp[0].minor.yy211));
                                                delete yymsp[0].minor.yy211;
                                                objectForTokens = yygotominor.yy490;
                                            }
        break;
      case 267: /* exprx ::= JOIN_KW */
{
                                                yygotominor.yy490 = new SqliteExpr();
                                                yygotominor.yy490->initId(yymsp[0].minor.yy0->value);
                                                objectForTokens = yygotominor.yy490;
                                            }
        break;
      case 268: /* exprx ::= nm DOT nm */
{
                                                yygotominor.yy490 = new SqliteExpr();
                                                yygotominor.yy490->initId(*(yymsp[-2].minor.yy211), *(yymsp[0].minor.yy211));
                                                delete yymsp[-2].minor.yy211;
                                                delete yymsp[0].minor.yy211;
                                                objectForTokens = yygotominor.yy490;
                                            }
        break;
      case 269: /* exprx ::= nm DOT nm DOT nm */
{
                                                yygotominor.yy490 = new SqliteExpr();
                                                yygotominor.yy490->initId(*(yymsp[-4].minor.yy211), *(yymsp[-2].minor.yy211), *(yymsp[0].minor.yy211));
                                                delete yymsp[-4].minor.yy211;
                                                delete yymsp[-2].minor.yy211;
                                                delete yymsp[0].minor.yy211;
                                                objectForTokens = yygotominor.yy490;
                                            }
        break;
      case 270: /* exprx ::= VARIABLE */
{
                                                yygotominor.yy490 = new SqliteExpr();
                                                yygotominor.yy490->initBindParam(yymsp[0].minor.yy0->value);
                                                objectForTokens = yygotominor.yy490;
                                            }
        break;
      case 271: /* exprx ::= expr COLLATE ids */
{
                                                yygotominor.yy490 = new SqliteExpr();
                                                yygotominor.yy490->initCollate(yymsp[-2].minor.yy490, *(yymsp[0].minor.yy211));
                                                delete yymsp[0].minor.yy211;
                                                objectForTokens = yygotominor.yy490;
                                            }
        break;
      case 272: /* exprx ::= CAST LP expr AS typetoken RP */
{
                                                yygotominor.yy490 = new SqliteExpr();
                                                yygotominor.yy490->initCast(yymsp[-3].minor.yy490, yymsp[-1].minor.yy299);
                                                objectForTokens = yygotominor.yy490;
                                            }
        break;
      case 273: /* exprx ::= ID LP distinct exprlist RP */
{
                                                yygotominor.yy490 = new SqliteExpr();
                                                yygotominor.yy490->initFunction(yymsp[-4].minor.yy0->value, *(yymsp[-2].minor.yy376), *(yymsp[-1].minor.yy13));
                                                delete yymsp[-2].minor.yy376;
                                                delete yymsp[-1].minor.yy13;
                                                objectForTokens = yygotominor.yy490;
                                            }
        break;
      case 274: /* exprx ::= ID LP STAR RP */
{
                                                yygotominor.yy490 = new SqliteExpr();
                                                yygotominor.yy490->initFunction(yymsp[-3].minor.yy0->value, true);
                                                objectForTokens = yygotominor.yy490;
                                            }
        break;
      case 275: /* exprx ::= expr AND expr */
      case 276: /* exprx ::= expr OR expr */ yytestcase(yyruleno==276);
      case 277: /* exprx ::= expr LT|GT|GE|LE expr */ yytestcase(yyruleno==277);
      case 278: /* exprx ::= expr EQ|NE expr */ yytestcase(yyruleno==278);
      case 279: /* exprx ::= expr BITAND|BITOR|LSHIFT|RSHIFT expr */ yytestcase(yyruleno==279);
      case 280: /* exprx ::= expr PLUS|MINUS expr */ yytestcase(yyruleno==280);
      case 281: /* exprx ::= expr STAR|SLASH|REM expr */ yytestcase(yyruleno==281);
      case 282: /* exprx ::= expr CONCAT expr */ yytestcase(yyruleno==282);
{
                                                yygotominor.yy490 = new SqliteExpr();
                                                yygotominor.yy490->initBinOp(yymsp[-2].minor.yy490, yymsp[-1].minor.yy0->value, yymsp[0].minor.yy490);
                                                objectForTokens = yygotominor.yy490;
                                            }
        break;
      case 283: /* exprx ::= expr not_opt likeop expr */
{
                                                yygotominor.yy490 = new SqliteExpr();
                                                yygotominor.yy490->initLike(yymsp[-3].minor.yy490, *(yymsp[-2].minor.yy237), *(yymsp[-1].minor.yy374), yymsp[0].minor.yy490);
                                                delete yymsp[-2].minor.yy237;
                                                delete yymsp[-1].minor.yy374;
                                                objectForTokens = yygotominor.yy490;
                                            }
        break;
      case 284: /* exprx ::= expr not_opt likeop expr ESCAPE expr */
{
                                                yygotominor.yy490 = new SqliteExpr();
                                                yygotominor.yy490->initLike(yymsp[-5].minor.yy490, *(yymsp[-4].minor.yy237), *(yymsp[-3].minor.yy374), yymsp[-2].minor.yy490, yymsp[0].minor.yy490);
                                                delete yymsp[-4].minor.yy237;
                                                delete yymsp[-3].minor.yy374;
                                                objectForTokens = yygotominor.yy490;
                                            }
        break;
      case 285: /* exprx ::= expr ISNULL|NOTNULL */
{
                                                yygotominor.yy490 = new SqliteExpr();
                                                yygotominor.yy490->initNull(yymsp[-1].minor.yy490, yymsp[0].minor.yy0->value);
                                                objectForTokens = yygotominor.yy490;
                                            }
        break;
      case 286: /* exprx ::= expr NOT NULL */
{
                                                yygotominor.yy490 = new SqliteExpr();
                                                yygotominor.yy490->initNull(yymsp[-2].minor.yy490, "NOT NULL");
                                                objectForTokens = yygotominor.yy490;
                                            }
        break;
      case 287: /* exprx ::= expr IS not_opt expr */
{
                                                yygotominor.yy490 = new SqliteExpr();
                                                yygotominor.yy490->initIs(yymsp[-3].minor.yy490, *(yymsp[-1].minor.yy237), yymsp[0].minor.yy490);
                                                delete yymsp[-1].minor.yy237;
                                                objectForTokens = yygotominor.yy490;
                                            }
        break;
      case 288: /* exprx ::= NOT expr */
{
                                                yygotominor.yy490 = new SqliteExpr();
                                                yygotominor.yy490->initUnaryOp(yymsp[0].minor.yy490, yymsp[-1].minor.yy0->value);
                                            }
        break;
      case 289: /* exprx ::= BITNOT expr */
      case 291: /* exprx ::= PLUS expr */ yytestcase(yyruleno==291);
{
                                                yygotominor.yy490 = new SqliteExpr();
                                                yygotominor.yy490->initUnaryOp(yymsp[0].minor.yy490, yymsp[-1].minor.yy0->value);
                                                objectForTokens = yygotominor.yy490;
                                            }
        break;
      case 290: /* exprx ::= MINUS expr */
{
                                                yygotominor.yy490 = new SqliteExpr();
                                                if (yymsp[0].minor.yy490->mode == SqliteExpr::Mode::LITERAL_VALUE &&
                                                    parserContext->isCandidateForMaxNegativeNumber() &&
                                                    yymsp[0].minor.yy490->literalValue == static_cast<qint64>(0L))
                                                {
                                                    yygotominor.yy490->initLiteral(std::numeric_limits<qint64>::min());
                                                    delete yymsp[0].minor.yy490;
                                                }
                                                else
                                                {
                                                    yygotominor.yy490->initUnaryOp(yymsp[0].minor.yy490, yymsp[-1].minor.yy0->value);
                                                }
                                                objectForTokens = yygotominor.yy490;
                                            }
        break;
      case 292: /* exprx ::= expr not_opt BETWEEN expr AND expr */
{
                                                yygotominor.yy490 = new SqliteExpr();
                                                yygotominor.yy490->initBetween(yymsp[-5].minor.yy490, *(yymsp[-4].minor.yy237), yymsp[-2].minor.yy490, yymsp[0].minor.yy490);
                                                delete yymsp[-4].minor.yy237;
                                                objectForTokens = yygotominor.yy490;
                                            }
        break;
      case 293: /* exprx ::= expr not_opt IN LP exprlist RP */
{
                                                yygotominor.yy490 = new SqliteExpr();
                                                yygotominor.yy490->initIn(yymsp[-5].minor.yy490, *(yymsp[-4].minor.yy237), *(yymsp[-1].minor.yy13));
                                                delete yymsp[-4].minor.yy237;
                                                delete yymsp[-1].minor.yy13;
                                                objectForTokens = yygotominor.yy490;
                                            }
        break;
      case 294: /* exprx ::= LP select RP */
{
                                                yygotominor.yy490 = new SqliteExpr();
                                                yygotominor.yy490->initSubSelect(yymsp[-1].minor.yy123);
                                                objectForTokens = yygotominor.yy490;
                                            }
        break;
      case 295: /* exprx ::= expr not_opt IN LP select RP */
{
                                                yygotominor.yy490 = new SqliteExpr();
                                                yygotominor.yy490->initIn(yymsp[-5].minor.yy490, *(yymsp[-4].minor.yy237), yymsp[-1].minor.yy123);
                                                delete yymsp[-4].minor.yy237;
                                                objectForTokens = yygotominor.yy490;
                                            }
        break;
      case 296: /* exprx ::= expr not_opt IN nm dbnm */
{
                                                yygotominor.yy490 = new SqliteExpr();
                                                yygotominor.yy490->initIn(yymsp[-4].minor.yy490, *(yymsp[-3].minor.yy237), *(yymsp[-1].minor.yy211), *(yymsp[0].minor.yy211));
                                                delete yymsp[-3].minor.yy237;
                                                delete yymsp[-1].minor.yy211;
                                                objectForTokens = yygotominor.yy490;
                                            }
        break;
      case 297: /* exprx ::= EXISTS LP select RP */
{
                                                yygotominor.yy490 = new SqliteExpr();
                                                yygotominor.yy490->initExists(yymsp[-1].minor.yy123);
                                                objectForTokens = yygotominor.yy490;
                                            }
        break;
      case 298: /* exprx ::= CASE case_operand case_exprlist case_else END */
{
                                                yygotominor.yy490 = new SqliteExpr();
                                                yygotominor.yy490->initCase(yymsp[-3].minor.yy490, *(yymsp[-2].minor.yy13), yymsp[-1].minor.yy490);
                                                delete yymsp[-2].minor.yy13;
                                                objectForTokens = yygotominor.yy490;
                                            }
        break;
      case 299: /* exprx ::= RAISE LP IGNORE RP */
{
                                                yygotominor.yy490 = new SqliteExpr();
                                                yygotominor.yy490->initRaise(yymsp[-1].minor.yy0->value);
                                                objectForTokens = yygotominor.yy490;
                                            }
        break;
      case 300: /* exprx ::= RAISE LP raisetype COMMA nm RP */
{
                                                yygotominor.yy490 = new SqliteExpr();
                                                yygotominor.yy490->initRaise(yymsp[-3].minor.yy0->value, *(yymsp[-1].minor.yy211));
                                                delete yymsp[-1].minor.yy211;
                                                objectForTokens = yygotominor.yy490;
                                            }
        break;
      case 301: /* expr ::= */
{
                                                yygotominor.yy490 = new SqliteExpr();
                                                objectForTokens = yygotominor.yy490;
                                                parserContext->minorErrorAfterLastToken("Syntax error <expr>");
                                            }
        break;
      case 305: /* likeop ::= LIKE_KW|MATCH */
{yygotominor.yy374 = new SqliteExpr::LikeOp(SqliteExpr::likeOp(yymsp[0].minor.yy0->value));}
        break;
      case 306: /* case_exprlist ::= case_exprlist WHEN expr THEN expr */
{
                                                yymsp[-4].minor.yy13->append(yymsp[-2].minor.yy490);
                                                yymsp[-4].minor.yy13->append(yymsp[0].minor.yy490);
                                                yygotominor.yy13 = yymsp[-4].minor.yy13;
                                            }
        break;
      case 307: /* case_exprlist ::= WHEN expr THEN expr */
{
                                                yygotominor.yy13 = new ParserExprList();
                                                yygotominor.yy13->append(yymsp[-2].minor.yy490);
                                                yygotominor.yy13->append(yymsp[0].minor.yy490);
                                            }
        break;
      case 314: /* nexprlist ::= nexprlist COMMA expr */
{
                                                yymsp[-2].minor.yy13->append(yymsp[0].minor.yy490);
                                                yygotominor.yy13 = yymsp[-2].minor.yy13;
                                                DONT_INHERIT_TOKENS("nexprlist");
                                            }
        break;
      case 315: /* nexprlist ::= exprx */
{
                                                yygotominor.yy13 = new ParserExprList();
                                                yygotominor.yy13->append(yymsp[0].minor.yy490);
                                            }
        break;
      case 316: /* cmd ::= CREATE uniqueflag INDEX ifnotexists nm dbnm ON nm LP sortlist RP where_opt */
{
                                                yygotominor.yy399 = new SqliteCreateIndex(
                                                        *(yymsp[-10].minor.yy237),
                                                        *(yymsp[-8].minor.yy237),
                                                        *(yymsp[-7].minor.yy211),
                                                        *(yymsp[-6].minor.yy211),
                                                        *(yymsp[-4].minor.yy211),
                                                        *(yymsp[-2].minor.yy495),
                                                        yymsp[0].minor.yy490
                                                    );
                                                delete yymsp[-8].minor.yy237;
                                                delete yymsp[-10].minor.yy237;
                                                delete yymsp[-7].minor.yy211;
                                                delete yymsp[-6].minor.yy211;
                                                delete yymsp[-4].minor.yy211;
                                                delete yymsp[-2].minor.yy495;
                                                objectForTokens = yygotominor.yy399;
                                            }
        break;
      case 317: /* cmd ::= CREATE uniqueflag INDEX ifnotexists nm dbnm ON ID_TAB */
{  yy_destructor(yypParser,177,&yymsp[-3].minor);
}
        break;
      case 322: /* idxlist_opt ::= */
{yygotominor.yy139 = new ParserIndexedColumnList();}
        break;
      case 323: /* idxlist_opt ::= LP idxlist RP */
{yygotominor.yy139 = yymsp[-1].minor.yy139;}
        break;
      case 324: /* idxlist ::= idxlist COMMA idxlist_single */
{
                                                yymsp[-2].minor.yy139->append(yymsp[0].minor.yy90);
                                                yygotominor.yy139 = yymsp[-2].minor.yy139;
                                                DONT_INHERIT_TOKENS("idxlist");
                                            }
        break;
      case 325: /* idxlist ::= idxlist_single */
{
                                                yygotominor.yy139 = new ParserIndexedColumnList();
                                                yygotominor.yy139->append(yymsp[0].minor.yy90);
                                            }
        break;
      case 326: /* idxlist_single ::= nm collate sortorder */
      case 327: /* idxlist_single ::= ID_COL */ yytestcase(yyruleno==327);
{
                                                SqliteIndexedColumn* obj =
                                                    new SqliteIndexedColumn(
                                                        *(yymsp[-2].minor.yy211),
                                                        *(yymsp[-1].minor.yy211),
                                                        *(yymsp[0].minor.yy226)
                                                    );
                                                yygotominor.yy90 = obj;
                                                delete yymsp[0].minor.yy226;
                                                delete yymsp[-2].minor.yy211;
                                                delete yymsp[-1].minor.yy211;
                                                objectForTokens = yygotominor.yy90;
                                            }
        break;
      case 331: /* cmd ::= DROP INDEX ifexists fullname */
{
                                                yygotominor.yy399 = new SqliteDropIndex(*(yymsp[-1].minor.yy237), yymsp[0].minor.yy66->name1, yymsp[0].minor.yy66->name2);
                                                delete yymsp[-1].minor.yy237;
                                                delete yymsp[0].minor.yy66;
                                                objectForTokens = yygotominor.yy399;
                                            }
        break;
      case 334: /* cmd ::= VACUUM */
{
                                                yygotominor.yy399 = new SqliteVacuum();
                                                objectForTokens = yygotominor.yy399;
                                            }
        break;
      case 335: /* cmd ::= VACUUM nm */
{
                                                yygotominor.yy399 = new SqliteVacuum(*(yymsp[0].minor.yy211));
                                                delete yymsp[0].minor.yy211;
                                                objectForTokens = yygotominor.yy399;
                                            }
        break;
      case 336: /* cmd ::= PRAGMA nm dbnm */
{
                                                yygotominor.yy399 = new SqlitePragma(*(yymsp[-1].minor.yy211), *(yymsp[0].minor.yy211));
                                                delete yymsp[-1].minor.yy211;
                                                delete yymsp[0].minor.yy211;
                                                objectForTokens = yygotominor.yy399;
                                            }
        break;
      case 337: /* cmd ::= PRAGMA nm dbnm EQ nmnum */
      case 339: /* cmd ::= PRAGMA nm dbnm EQ minus_num */ yytestcase(yyruleno==339);
{
                                                yygotominor.yy399 = new SqlitePragma(*(yymsp[-3].minor.yy211), *(yymsp[-2].minor.yy211), *(yymsp[0].minor.yy21), true);
                                                delete yymsp[-3].minor.yy211;
                                                delete yymsp[-2].minor.yy211;
                                                delete yymsp[0].minor.yy21;
                                                objectForTokens = yygotominor.yy399;
                                            }
        break;
      case 338: /* cmd ::= PRAGMA nm dbnm LP nmnum RP */
      case 340: /* cmd ::= PRAGMA nm dbnm LP minus_num RP */ yytestcase(yyruleno==340);
{
                                                yygotominor.yy399 = new SqlitePragma(*(yymsp[-4].minor.yy211), *(yymsp[-3].minor.yy211), *(yymsp[-1].minor.yy21), false);
                                                delete yymsp[-4].minor.yy211;
                                                delete yymsp[-3].minor.yy211;
                                                delete yymsp[-1].minor.yy21;
                                                objectForTokens = yygotominor.yy399;
                                            }
        break;
      case 344: /* nmnum ::= nm */
{
                                                yygotominor.yy21 = new QVariant(*(yymsp[0].minor.yy211));
                                                delete yymsp[0].minor.yy211;
                                            }
        break;
      case 350: /* minus_num ::= MINUS number */
{
                                                if (yymsp[0].minor.yy21->type() == QVariant::Double)
                                                    *(yymsp[0].minor.yy21) = -(yymsp[0].minor.yy21->toDouble());
                                                else if (yymsp[0].minor.yy21->type() == QVariant::LongLong)
                                                {
                                                    if (parserContext->isCandidateForMaxNegativeNumber())
                                                        *(yymsp[0].minor.yy21) = std::numeric_limits<qint64>::min();
                                                    else
                                                        *(yymsp[0].minor.yy21) = -(yymsp[0].minor.yy21->toLongLong());
                                                }
                                                else
                                                    Q_ASSERT_X(true, "producing minus number", "QVariant is neither of Double or LongLong.");

                                                yygotominor.yy21 = yymsp[0].minor.yy21;
                                            }
        break;
      case 353: /* cmd ::= CREATE temp TRIGGER ifnotexists nm dbnm trigger_time trigger_event ON nm foreach_clause when_clause BEGIN trigger_cmd_list END */
{
                                                yygotominor.yy399 = new SqliteCreateTrigger(
                                                        *(yymsp[-13].minor.yy376),
                                                        *(yymsp[-11].minor.yy237),
                                                        *(yymsp[-10].minor.yy211),
                                                        *(yymsp[-9].minor.yy211),
                                                        *(yymsp[-5].minor.yy211),
                                                        *(yymsp[-8].minor.yy152),
                                                        yymsp[-7].minor.yy309,
                                                        *(yymsp[-4].minor.yy409),
                                                        yymsp[-3].minor.yy490,
                                                        *(yymsp[-1].minor.yy214),
                                                        3
                                                    );
                                                delete yymsp[-11].minor.yy237;
                                                delete yymsp[-13].minor.yy376;
                                                delete yymsp[-8].minor.yy152;
                                                delete yymsp[-4].minor.yy409;
                                                delete yymsp[-10].minor.yy211;
                                                delete yymsp[-5].minor.yy211;
                                                delete yymsp[-9].minor.yy211;
                                                delete yymsp[-1].minor.yy214;
                                                objectForTokens = yygotominor.yy399;
                                            }
        break;
      case 354: /* cmd ::= CREATE temp TRIGGER ifnotexists nm dbnm trigger_time trigger_event ON nm foreach_clause when_clause */
{
                                                QList<SqliteQuery *> CL;

                                                yygotominor.yy399 = new SqliteCreateTrigger(
                                                        *(yymsp[-10].minor.yy376),
                                                        *(yymsp[-8].minor.yy237),
                                                        *(yymsp[-7].minor.yy211),
                                                        *(yymsp[-6].minor.yy211),
                                                        *(yymsp[-2].minor.yy211),
                                                        *(yymsp[-5].minor.yy152),
                                                        yymsp[-4].minor.yy309,
                                                        *(yymsp[-1].minor.yy409),
                                                        yymsp[0].minor.yy490,
                                                        CL,
                                                        3
                                                    );
                                                delete yymsp[-8].minor.yy237;
                                                delete yymsp[-10].minor.yy376;
                                                delete yymsp[-5].minor.yy152;
                                                delete yymsp[-1].minor.yy409;
                                                delete yymsp[-7].minor.yy211;
                                                delete yymsp[-2].minor.yy211;
                                                delete yymsp[-6].minor.yy211;
                                                objectForTokens = yygotominor.yy399;
                                                parserContext->minorErrorAfterLastToken("Syntax error");
                                            }
        break;
      case 355: /* cmd ::= CREATE temp TRIGGER ifnotexists nm dbnm trigger_time trigger_event ON nm foreach_clause when_clause BEGIN trigger_cmd_list */
{
                                                yygotominor.yy399 = new SqliteCreateTrigger(
                                                *(yymsp[-12].minor.yy376),
                                                *(yymsp[-10].minor.yy237),
                                                *(yymsp[-9].minor.yy211),
                                                *(yymsp[-8].minor.yy211),
                                                *(yymsp[-4].minor.yy211),
                                                *(yymsp[-7].minor.yy152),
                                                yymsp[-6].minor.yy309,
                                                *(yymsp[-3].minor.yy409),
                                                yymsp[-2].minor.yy490,
                                                *(yymsp[0].minor.yy214),
                                                3
                                                );
                                                delete yymsp[-10].minor.yy237;
                                                delete yymsp[-12].minor.yy376;
                                                delete yymsp[-7].minor.yy152;
                                                delete yymsp[-3].minor.yy409;
                                                delete yymsp[-9].minor.yy211;
                                                delete yymsp[-4].minor.yy211;
                                                delete yymsp[-8].minor.yy211;
                                                delete yymsp[0].minor.yy214;
                                                objectForTokens = yygotominor.yy399;
                                                parserContext->minorErrorAfterLastToken("Syntax error");
                                            }
        break;
      case 356: /* cmd ::= CREATE temp TRIGGER ifnotexists nm dbnm trigger_time trigger_event ON ID_TAB */
{  yy_destructor(yypParser,179,&yymsp[-8].minor);
  yy_destructor(yypParser,177,&yymsp[-5].minor);
  yy_destructor(yypParser,262,&yymsp[-3].minor);
  yy_destructor(yypParser,263,&yymsp[-2].minor);
}
        break;
      case 359: /* trigger_time ::= BEFORE */
{yygotominor.yy152 = new SqliteCreateTrigger::Time(SqliteCreateTrigger::Time::BEFORE);}
        break;
      case 360: /* trigger_time ::= AFTER */
{yygotominor.yy152 = new SqliteCreateTrigger::Time(SqliteCreateTrigger::Time::AFTER);}
        break;
      case 361: /* trigger_time ::= INSTEAD OF */
{yygotominor.yy152 = new SqliteCreateTrigger::Time(SqliteCreateTrigger::Time::INSTEAD_OF);}
        break;
      case 362: /* trigger_time ::= */
{yygotominor.yy152 = new SqliteCreateTrigger::Time(SqliteCreateTrigger::Time::null);}
        break;
      case 363: /* trigger_event ::= DELETE */
{
                                                yygotominor.yy309 = new SqliteCreateTrigger::Event(SqliteCreateTrigger::Event::DELETE);
                                                objectForTokens = yygotominor.yy309;
                                            }
        break;
      case 364: /* trigger_event ::= INSERT */
{
                                                yygotominor.yy309 = new SqliteCreateTrigger::Event(SqliteCreateTrigger::Event::INSERT);
                                                objectForTokens = yygotominor.yy309;
                                            }
        break;
      case 365: /* trigger_event ::= UPDATE */
{
                                                yygotominor.yy309 = new SqliteCreateTrigger::Event(SqliteCreateTrigger::Event::UPDATE);
                                                objectForTokens = yygotominor.yy309;
                                            }
        break;
      case 366: /* trigger_event ::= UPDATE OF inscollist */
{
                                                yygotominor.yy309 = new SqliteCreateTrigger::Event(*(yymsp[0].minor.yy445));
                                                delete yymsp[0].minor.yy445;
                                                objectForTokens = yygotominor.yy309;
                                            }
        break;
      case 367: /* foreach_clause ::= */
{yygotominor.yy409 = new SqliteCreateTrigger::Scope(SqliteCreateTrigger::Scope::null);}
        break;
      case 368: /* foreach_clause ::= FOR EACH ROW */
{yygotominor.yy409 = new SqliteCreateTrigger::Scope(SqliteCreateTrigger::Scope::FOR_EACH_ROW);}
        break;
      case 371: /* trigger_cmd_list ::= trigger_cmd_list trigger_cmd SEMI */
{
                                                yymsp[-2].minor.yy214->append(yymsp[-1].minor.yy399);
                                                yygotominor.yy214 = yymsp[-2].minor.yy214;
                                                DONT_INHERIT_TOKENS("trigger_cmd_list");
                                            }
        break;
      case 372: /* trigger_cmd_list ::= trigger_cmd SEMI */
{
                                                yygotominor.yy214 = new ParserQueryList();
                                                yygotominor.yy214->append(yymsp[-1].minor.yy399);
                                            }
        break;
      case 373: /* trigger_cmd_list ::= SEMI */
{
                                                yygotominor.yy214 = new ParserQueryList();
                                                parserContext->minorErrorAfterLastToken("Syntax error");
                                            }
        break;
      case 378: /* raisetype ::= ROLLBACK|ABORT|FAIL */
{yygotominor.yy0 = yymsp[0].minor.yy0;}
        break;
      case 379: /* cmd ::= DROP TRIGGER ifexists fullname */
{
                                                yygotominor.yy399 = new SqliteDropTrigger(*(yymsp[-1].minor.yy237), yymsp[0].minor.yy66->name1, yymsp[0].minor.yy66->name2);
                                                delete yymsp[-1].minor.yy237;
                                                delete yymsp[0].minor.yy66;
                                                objectForTokens = yygotominor.yy399;
                                            }
        break;
      case 382: /* cmd ::= ATTACH database_kw_opt expr AS expr key_opt */
{
                                                yygotominor.yy399 = new SqliteAttach(*(yymsp[-4].minor.yy237), yymsp[-3].minor.yy490, yymsp[-1].minor.yy490, yymsp[0].minor.yy490);
                                                delete yymsp[-4].minor.yy237;
                                                objectForTokens = yygotominor.yy399;
                                            }
        break;
      case 383: /* cmd ::= DETACH database_kw_opt expr */
{
                                                yygotominor.yy399 = new SqliteDetach(*(yymsp[-1].minor.yy237), yymsp[0].minor.yy490);
                                                delete yymsp[-1].minor.yy237;
                                                objectForTokens = yygotominor.yy399;
                                            }
        break;
      case 388: /* cmd ::= REINDEX */
{yygotominor.yy399 = new SqliteReindex();}
        break;
      case 389: /* cmd ::= REINDEX nm dbnm */
      case 390: /* cmd ::= REINDEX ID_COLLATE */ yytestcase(yyruleno==390);
{
                                                yygotominor.yy399 = new SqliteReindex(*(yymsp[-1].minor.yy211), *(yymsp[0].minor.yy211));
                                                delete yymsp[-1].minor.yy211;
                                                delete yymsp[0].minor.yy211;
                                                objectForTokens = yygotominor.yy399;
                                            }
        break;
      case 393: /* cmd ::= ANALYZE */
{
                                                yygotominor.yy399 = new SqliteAnalyze();
                                                objectForTokens = yygotominor.yy399;
                                            }
        break;
      case 394: /* cmd ::= ANALYZE nm dbnm */
{
                                                yygotominor.yy399 = new SqliteAnalyze(*(yymsp[-1].minor.yy211), *(yymsp[0].minor.yy211));
                                                delete yymsp[-1].minor.yy211;
                                                delete yymsp[0].minor.yy211;
                                                objectForTokens = yygotominor.yy399;
                                            }
        break;
      case 397: /* cmd ::= ALTER TABLE fullname RENAME TO nm */
{
                                                yygotominor.yy399 = new SqliteAlterTable(
                                                        yymsp[-3].minor.yy66->name1,
                                                        yymsp[-3].minor.yy66->name2,
                                                        *(yymsp[0].minor.yy211)
                                                    );
                                                delete yymsp[0].minor.yy211;
                                                delete yymsp[-3].minor.yy66;
                                                objectForTokens = yygotominor.yy399;
                                            }
        break;
      case 398: /* cmd ::= ALTER TABLE fullname ADD kwcolumn_opt column */
{
                                                yygotominor.yy399 = new SqliteAlterTable(
                                                        yymsp[-3].minor.yy66->name1,
                                                        yymsp[-3].minor.yy66->name2,
                                                        *(yymsp[-1].minor.yy237),
                                                        yymsp[0].minor.yy425
                                                    );
                                                delete yymsp[-1].minor.yy237;
                                                delete yymsp[-3].minor.yy66;
                                                objectForTokens = yygotominor.yy399;
                                            }
        break;
      case 399: /* cmd ::= ALTER TABLE fullname RENAME TO ID_TAB_NEW */
{  yy_destructor(yypParser,181,&yymsp[-3].minor);
}
        break;
      case 405: /* create_vtab ::= CREATE VIRTUAL TABLE ifnotexists nm dbnm USING nm */
{
                                                yygotominor.yy399 = new SqliteCreateVirtualTable(
                                                        *(yymsp[-4].minor.yy237),
                                                        *(yymsp[-3].minor.yy211),
                                                        *(yymsp[-2].minor.yy211),
                                                        *(yymsp[0].minor.yy211)
                                                    );
                                                delete yymsp[-4].minor.yy237;
                                                delete yymsp[-3].minor.yy211;
                                                delete yymsp[-2].minor.yy211;
                                                delete yymsp[0].minor.yy211;
                                                objectForTokens = yygotominor.yy399;
                                            }
        break;
      case 406: /* create_vtab ::= CREATE VIRTUAL TABLE ifnotexists nm dbnm USING nm LP vtabarglist RP */
{
                                                yygotominor.yy399 = new SqliteCreateVirtualTable(
                                                        *(yymsp[-7].minor.yy237),
                                                        *(yymsp[-6].minor.yy211),
                                                        *(yymsp[-5].minor.yy211),
                                                        *(yymsp[-3].minor.yy211),
                                                        *(yymsp[-1].minor.yy445)
                                                    );
                                                delete yymsp[-6].minor.yy211;
                                                delete yymsp[-5].minor.yy211;
                                                delete yymsp[-3].minor.yy211;
                                                delete yymsp[-7].minor.yy237;
                                                delete yymsp[-1].minor.yy445;
                                                objectForTokens = yygotominor.yy399;
                                            }
        break;
      case 409: /* vtabarglist ::= vtabarg */
{
                                                yygotominor.yy445 = new ParserStringList();
                                                yygotominor.yy445->append((yymsp[0].minor.yy211)->mid(1)); // mid(1) to skip the first whitespace added in vtabarg
                                                delete yymsp[0].minor.yy211;
                                            }
        break;
      case 410: /* vtabarglist ::= vtabarglist COMMA vtabarg */
{
                                                yymsp[-2].minor.yy445->append((yymsp[0].minor.yy211)->mid(1)); // mid(1) to skip the first whitespace added in vtabarg
                                                yygotominor.yy445 = yymsp[-2].minor.yy445;
                                                delete yymsp[0].minor.yy211;
                                                DONT_INHERIT_TOKENS("vtabarglist");
                                            }
        break;
      case 412: /* vtabarg ::= vtabarg vtabargtoken */
{
                                                yymsp[-1].minor.yy211->append(" "+ *(yymsp[0].minor.yy211));
                                                yygotominor.yy211 = yymsp[-1].minor.yy211;
                                                delete yymsp[0].minor.yy211;
                                            }
        break;
      case 413: /* vtabargtoken ::= ANY */
{
                                                yygotominor.yy211 = new QString(yymsp[0].minor.yy0->value);
                                            }
        break;
      case 414: /* vtabargtoken ::= LP anylist RP */
{
                                                yygotominor.yy211 = new QString("(");
                                                yygotominor.yy211->append(*(yymsp[-1].minor.yy211));
                                                yygotominor.yy211->append(")");
                                                delete yymsp[-1].minor.yy211;
                                            }
        break;
      case 416: /* anylist ::= anylist LP anylist RP */
{
                                                yygotominor.yy211 = yymsp[-3].minor.yy211;
                                                yygotominor.yy211->append("(");
                                                yygotominor.yy211->append(*(yymsp[-1].minor.yy211));
                                                yygotominor.yy211->append(")");
                                                delete yymsp[-1].minor.yy211;
                                                DONT_INHERIT_TOKENS("anylist");
                                            }
        break;
      case 417: /* anylist ::= anylist ANY */
{
                                                yygotominor.yy211 = yymsp[-1].minor.yy211;
                                                yygotominor.yy211->append(yymsp[0].minor.yy0->value);
                                                DONT_INHERIT_TOKENS("anylist");
                                            }
        break;
      case 418: /* with ::= */
{yygotominor.yy367 = nullptr;}
        break;
      case 419: /* with ::= WITH wqlist */
{
                                                yygotominor.yy367 = yymsp[0].minor.yy367;
                                                objectForTokens = yygotominor.yy367;
                                            }
        break;
      case 420: /* with ::= WITH RECURSIVE wqlist */
{
                                                yygotominor.yy367 = yymsp[0].minor.yy367;
                                                yygotominor.yy367->recursive = true;
                                                objectForTokens = yygotominor.yy367;
                                            }
        break;
      case 421: /* wqlist ::= nm idxlist_opt AS LP select RP */
{
                                                yygotominor.yy367 = SqliteWith::append(*(yymsp[-5].minor.yy211), *(yymsp[-4].minor.yy139), yymsp[-1].minor.yy123);
                                                delete yymsp[-5].minor.yy211;
                                                delete yymsp[-4].minor.yy139;
                                            }
        break;
      case 422: /* wqlist ::= wqlist COMMA nm idxlist_opt AS LP select RP */
{
                                                yygotominor.yy367 = SqliteWith::append(yymsp[-7].minor.yy367, *(yymsp[-5].minor.yy211), *(yymsp[-4].minor.yy139), yymsp[-1].minor.yy123);
                                                delete yymsp[-5].minor.yy211;
                                                delete yymsp[-4].minor.yy139;
                                                DONT_INHERIT_TOKENS("wqlist");
                                            }
        break;
      case 423: /* wqlist ::= ID_TAB_NEW */
{
                                                parserContext->minorErrorBeforeNextToken("Syntax error");
                                                yygotominor.yy367 = new SqliteWith();
                                            }
        break;
      default:
      /* (0) input ::= cmdlist */ yytestcase(yyruleno==0);
        break;
      };
  }
  assert( yyruleno>=0 && yyruleno<(int)(sizeof(yyRuleInfo)/sizeof(yyRuleInfo[0])) );
  yygoto = yyRuleInfo[yyruleno].lhs;
  yysize = yyRuleInfo[yyruleno].nrhs;

  // Store tokens for the rule in parser context
  QList<Token*> allTokens;
  QList<Token*> allTokensWithAllInherited;
  QString keyForTokensMap;
  int tokensMapKeyCnt;
  if (parserContext->setupTokens)
  {
      if (objectForTokens)
      {
          // In case this is a list with recurrent references we need
          // to clear tokens before adding the new and extended list.
          objectForTokens->tokens.clear();
      }

      QList<Token*> tokens;
      for (int i = yypParser->yyidx - yysize + 1; i <= yypParser->yyidx; i++)
      {
          tokens.clear();
          const char* fieldName = yyTokenName[yypParser->yystack[i].major];

          // Adding token being subject of this reduction. It's usually not includes in the inherited tokens,
          // although if inheriting from simple statements, like "FAIL" or "ROLLBACK", this tends to be redundant with the inherited tokens.
          // That's why we're checking if it's not contained in the inherited tokens and add it only then.
          if (parserContext->isManagedToken(yypParser->yystack[i].minor.yy0) && !yypParser->yystack[i].tokens->contains(yypParser->yystack[i].minor.yy0))
              tokens += yypParser->yystack[i].minor.yy0;

          tokens += *(yypParser->yystack[i].tokens);

          if (!noTokenInheritanceFields.contains(fieldName))
          {
              if (objectForTokens)
              {
                  keyForTokensMap = fieldName;
                  tokensMapKeyCnt = 2;
                  while (objectForTokens->tokensMap.contains(keyForTokensMap))
                      keyForTokensMap = fieldName + QString::number(tokensMapKeyCnt++);

                  objectForTokens->tokensMap[keyForTokensMap] = parserContext->getTokenPtrList(tokens);
              }

              allTokens += tokens;
          }
          else
          {
              // If field is mentioned only once, then only one occurance of it will be ignored.
              // Second one should be inherited. See "anylist" definition for explanation why.
              noTokenInheritanceFields.removeOne(fieldName);
          }
          allTokensWithAllInherited += tokens;
      }
      if (objectForTokens)
      {
          objectForTokens->tokens += parserContext->getTokenPtrList(allTokens);
      }
  }

  // Clear token lists
  for (int i = yypParser->yyidx - yysize + 1; i <= yypParser->yyidx; i++)
  {
      delete yypParser->yystack[i].tokens;
      yypParser->yystack[i].tokens = nullptr;
  }

  yypParser->yyidx -= yysize;
  yyact = yy_find_reduce_action(yymsp[-yysize].stateno,(YYCODETYPE)yygoto);
  if( yyact < YYNSTATE ){
#ifdef NDEBUG
    /* If we are not debugging and the reduce action popped at least
    ** one element off the stack, then we can push the new element back
    ** onto the stack here, and skip the stack overflow test in yy_shift().
    ** That gives a significant speed improvement. */
    if( yysize ){
      yypParser->yyidx++;
      yymsp -= yysize-1;
      yymsp->stateno = (YYACTIONTYPE)yyact;
      yymsp->major = (YYCODETYPE)yygoto;
      yymsp->minor = yygotominor;
      if (parserContext->setupTokens)
          *(yypParser->yystack[yypParser->yyidx].tokens) = allTokens;
    }else
#endif
    {
      yy_shift(yypParser,yyact,yygoto,&yygotominor);
      if (parserContext->setupTokens)
      {
          QList<Token*>* tokensPtr = yypParser->yystack[yypParser->yyidx].tokens;
          *tokensPtr = allTokensWithAllInherited + *tokensPtr;
      }
    }
  }else{
    assert( yyact == YYNSTATE + YYNRULE + 1 );
    yy_accept(yypParser);
  }
}

/*
** The following code executes when the parse fails
*/
#ifndef YYNOERRORRECOVERY
static void yy_parse_failed(
  yyParser *yypParser           /* The parser */
){
  sqlite3_parseARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sFail!\n",yyTracePrompt);
  }
#endif
  while( yypParser->yyidx>=0 ) yy_pop_parser_stack(yypParser);
  /* Here code is inserted which will be executed whenever the
  ** parser fails */
  sqlite3_parseARG_STORE; /* Suppress warning about unused %extra_argument variable */
}
#endif /* YYNOERRORRECOVERY */

/*
** The following code executes when a syntax error first occurs.
*/
static void yy_syntax_error(
  yyParser *yypParser,           /* The parser */
  int yymajor,                   /* The major type of the error token */
  YYMINORTYPE yyminor            /* The minor type of the error token */
){
  sqlite3_parseARG_FETCH;
#define TOKEN (yyminor.yy0)

    UNUSED_PARAMETER(yymajor);
    parserContext->error(TOKEN, QObject::tr("Syntax error"));
    //qDebug() << "near " << TOKEN->toString() << ": syntax error";
  sqlite3_parseARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/*
** The following is executed when the parser accepts
*/
static void yy_accept(
  yyParser *yypParser           /* The parser */
){
  sqlite3_parseARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sAccept!\n",yyTracePrompt);
  }
#endif
  while( yypParser->yyidx>=0 ) yy_pop_parser_stack(yypParser);
  /* Here code is inserted which will be executed whenever the
  ** parser accepts */
  sqlite3_parseARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/* The main parser program.
** The first argument is a pointer to a structure obtained from
** "sqlite3_parseAlloc" which describes the current state of the parser.
** The second argument is the major token number.  The third is
** the minor token.  The fourth optional argument is whatever the
** user wants (and specified in the grammar) and is available for
** use by the action routines.
**
** Inputs:
** <ul>
** <li> A pointer to the parser (an opaque structure.)
** <li> The major token number.
** <li> The minor token number.
** <li> An option argument of a grammar-specified type.
** </ul>
**
** Outputs:
** None.
*/
void sqlite3_parse(
  void *yyp,                   /* The parser */
  int yymajor,                 /* The major token code number */
  sqlite3_parseTOKENTYPE yyminor       /* The value for the token */
  sqlite3_parseARG_PDECL               /* Optional %extra_argument parameter */
){
  YYMINORTYPE yyminorunion;
  int yyact;            /* The parser action. */
#if !defined(YYERRORSYMBOL) && !defined(YYNOERRORRECOVERY)
  int yyendofinput;     /* True if we are at the end of input */
#endif
#ifdef YYERRORSYMBOL
  int yyerrorhit = 0;   /* True if yymajor has invoked an error */
#endif
  yyParser *yypParser;  /* The parser */

  /* (re)initialize the parser, if necessary */
  yypParser = (yyParser*)yyp;
  if( yypParser->yyidx<0 ){
#if YYSTACKDEPTH<=0
    if( yypParser->yystksz <=0 ){
      /*memset(&yyminorunion, 0, sizeof(yyminorunion));*/
      yyminorunion = yyzerominor;
      yyStackOverflow(yypParser, &yyminorunion);
      return;
    }
#endif
    yypParser->yyidx = 0;
    yypParser->yyerrcnt = -1;
    yypParser->yystack[0].stateno = 0;
    yypParser->yystack[0].major = 0;
    yypParser->yystack[0].tokens = new QList<Token*>();
  }
  yyminorunion.yy0 = yyminor;
#if !defined(YYERRORSYMBOL) && !defined(YYNOERRORRECOVERY)
  yyendofinput = (yymajor==0);
#endif
  sqlite3_parseARG_STORE;

#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sInput %s [%s] (lemon type: %s)\n",
            yyTracePrompt,
            yyminor->value.toLatin1().data(),
            yyminor->typeString().toLatin1().data(),
            yyTokenName[yymajor]);  }
#endif

  do{
    yyact = yy_find_shift_action(yypParser,(YYCODETYPE)yymajor);
    if( yyact<YYNSTATE ){
      yy_shift(yypParser,yyact,yymajor,&yyminorunion);
      yypParser->yyerrcnt--;
      yymajor = YYNOCODE;
    }else if( yyact < YYNSTATE + YYNRULE ){
      yy_reduce(yypParser,yyact-YYNSTATE);
    }else{
      assert( yyact == YY_ERROR_ACTION );
#ifdef YYERRORSYMBOL
      int yymx;
#endif
#ifndef NDEBUG
      if( yyTraceFILE ){
        fprintf(yyTraceFILE,"%sSyntax Error!\n",yyTracePrompt);
      }
#endif
#ifdef YYERRORSYMBOL
      /* A syntax error has occurred.
      ** The response to an error depends upon whether or not the
      ** grammar defines an error token "ERROR".
      **
      ** This is what we do if the grammar does define ERROR:
      **
      **  * Call the %syntax_error function.
      **
      **  * Begin popping the stack until we enter a state where
      **    it is legal to shift the error symbol, then shift
      **    the error symbol.
      **
      **  * Set the error count to three.
      **
      **  * Begin accepting and shifting new tokens.  No new error
      **    processing will occur until three tokens have been
      **    shifted successfully.
      **
      */
      if( yypParser->yyerrcnt<0 ){
        yy_syntax_error(yypParser,yymajor,yyminorunion);
      }
      yymx = yypParser->yystack[yypParser->yyidx].major;
      if( yymx==YYERRORSYMBOL || yyerrorhit ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE,"%sDiscard input token %s\n",
             yyTracePrompt,yyTokenName[yymajor]);
        }
#endif
        yy_destructor(yypParser, (YYCODETYPE)yymajor,&yyminorunion);
        yymajor = YYNOCODE;
      }else{
         while(
          yypParser->yyidx >= 0 &&
          yymx != YYERRORSYMBOL &&
          (yyact = yy_find_reduce_action(
                        yypParser->yystack[yypParser->yyidx].stateno,
                        YYERRORSYMBOL)) >= YYNSTATE
        ){
          yy_pop_parser_stack(yypParser);
        }
        if( yypParser->yyidx < 0 || yymajor==0 ){
          yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
          yy_parse_failed(yypParser);
          yymajor = YYNOCODE;
        }else if( yymx!=YYERRORSYMBOL ){
          YYMINORTYPE u2;
          u2.YYERRSYMDT = 0;
          yy_shift(yypParser,yyact,YYERRORSYMBOL,&u2);
        }
      }
      yypParser->yyerrcnt = 1; // not 3 valid tokens, but 1
      yyerrorhit = 1;
#elif defined(YYNOERRORRECOVERY)
      /* If the YYNOERRORRECOVERY macro is defined, then do not attempt to
      ** do any kind of error recovery.  Instead, simply invoke the syntax
      ** error routine and continue going as if nothing had happened.
      **
      ** Applications can set this macro (for example inside %include) if
      ** they intend to abandon the parse upon the first syntax error seen.
      */
      yy_syntax_error(yypParser,yymajor,yyminorunion);
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      yymajor = YYNOCODE;

#else  /* YYERRORSYMBOL is not defined */
      /* This is what we do if the grammar does not define ERROR:
      **
      **  * Report an error message, and throw away the input token.
      **
      **  * If the input token is $, then fail the parse.
      **
      ** As before, subsequent error messages are suppressed until
      ** three input tokens have been successfully shifted.
      */
      if( yypParser->yyerrcnt<=0 ){
        yy_syntax_error(yypParser,yymajor,yyminorunion);
      }
      yypParser->yyerrcnt = 1; // not 3 valid tokens, but 1
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      if( yyendofinput ){
        yy_parse_failed(yypParser);
      }
      yymajor = YYNOCODE;
#endif
    }
  }while( yymajor!=YYNOCODE && yypParser->yyidx>=0 );
  return;
}
